@@ -37,6 +37,7 @@
 #include "polyxmass-ui-mz-ratio.h"
 
 
+
 GtkWidget *
 polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
 {
@@ -70,7 +71,7 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
   
   if (xml == NULL)
     {
-      g_critical (_("%s@%d: failed loading the interface\n"),
+      g_critical (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -81,12 +82,18 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
 
   if (calcctxt->calculator_wnd == NULL)
     {
-      g_critical (_("%s@%d: failed creating the polymer mass calculator window\n"),
+      g_critical (_("%s@%d: failed to create the polymer mass calculator window\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
     }
   
+  /* We will have to access the calcctxt from the pointer to _this_
+     window.
+   */
+  g_object_set_data (G_OBJECT (calcctxt->calculator_wnd),
+		     "calcctxt", calcctxt);
+ 
   /* The polymer chemistry definition entry which tells the user
      what definition is currently loaded.
   */
@@ -157,22 +164,22 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
      calcctxt);
 
   
-  /* UNIVERSAL CHEMICAL ELEMENTS
+  /* UNIVERSAL CHEMICAL ENTITIES
    */
-  widget = glade_xml_get_widget (xml, "univ_chem_elem_checkbutton");
+  widget = glade_xml_get_widget (xml, "univ_chem_entities_checkbutton");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (calcctxt->calculator_wnd),
-		     "univ_chem_elem_checkbutton", widget);
+		     "univ_chem_entities_checkbutton", widget);
   g_signal_connect
     (GTK_OBJECT (widget),
      "toggled",
-     G_CALLBACK (polyxcalc_ui_calculator_wnd_univ_chem_elem_checkbutton),
+     G_CALLBACK (polyxcalc_ui_calculator_wnd_univ_chem_entities_checkbutton),
      calcctxt);
   
-  widget = glade_xml_get_widget (xml, "univ_chem_elem_vbox");
+  widget = glade_xml_get_widget (xml, "univ_chem_entities_vbox");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (calcctxt->calculator_wnd),
-		     "univ_chem_elem_vbox", widget);
+		     "univ_chem_entities_vbox", widget);
   
   
   /* ATOMS
@@ -223,7 +230,7 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
   gtk_box_reorder_child (GTK_BOX (vbox), combo, 0);
   
   if (-1 == polyxcalc_ui_calculator_wnd_fill_atoms_combobox (calcctxt))
-    g_critical (_("%s@%d: could not set the atoms to the combobox\n"),
+    g_critical (_("%s@%d: failed to set the atoms to the combobox\n"),
 	   __FILE__, __LINE__);
   
   widget = GTK_WIDGET (GTK_ENTRY (GTK_BIN (combo)->child));
@@ -270,25 +277,25 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
 		     "actform_count_entry", widget);
 
 
-  /* POLYMER DEFINITION-RELATED ELEMENTS: ONLY HANDLE THEM IF THE
-     valid_polchemdef VARIABLE IS SET TO TRUE.
+  /* POLYMER CHEMISTRY DEFINITION-RELATED ENTITIES: ONLY HANDLE THEM
+     IF THE valid_polchemdef VARIABLE IS SET TO TRUE.
   */
   widget = glade_xml_get_widget (xml, 
-				 "polchemdef_spec_elements_checkbutton");
+				 "polchemdef_spec_entities_checkbutton");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (calcctxt->calculator_wnd),
-		     "polchemdef_spec_elements_checkbutton", widget);
+		     "polchemdef_spec_entities_checkbutton", widget);
 
   g_signal_connect
     (GTK_OBJECT (widget),
      "toggled",
-     G_CALLBACK (polyxcalc_ui_calculator_wnd_polchemdefspec_elem_checkbutton),
+     G_CALLBACK (polyxcalc_ui_calculator_wnd_polchemdefspec_entities_checkbutton),
      calcctxt);
   
-  widget = glade_xml_get_widget (xml, "polchemdef_spec_elem_vbox");
+  widget = glade_xml_get_widget (xml, "polchemdef_spec_entities_vbox");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (calcctxt->calculator_wnd),
-		     "polchemdef_spec_elem_vbox", widget);
+		     "polchemdef_spec_entities_vbox", widget);
   
   
   /* MONOMERS
@@ -348,7 +355,7 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
     {
       if (-1 == 
 	  polyxcalc_ui_calculator_wnd_fill_monomers_combobox (calcctxt))
-	g_critical (_("%s@%d: could not set the monomers to the combo list\n"),
+	g_critical (_("%s@%d: failed to set the monomers to the combo list\n"),
 	       __FILE__, __LINE__);
     }
   
@@ -420,7 +427,7 @@ polyxcalc_ui_calculator_wnd_setup_window (PxmCalcCtxt *calcctxt)
   if (calcctxt->polchemdefctxt != NULL)
     {
       if (-1 == polyxcalc_ui_calculator_wnd_fill_modifs_combobox (calcctxt))
-	g_critical (_("%s@%d: could not set the modifs to the combo list\n"),
+	g_critical (_("%s@%d: failed to set the modifs to the combo list\n"),
 	       __FILE__, __LINE__);
     }
   
@@ -835,7 +842,7 @@ polyxcalc_ui_calculator_wnd_apply_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  return ;
@@ -866,7 +873,7 @@ polyxcalc_ui_calculator_wnd_apply_button (GtkWidget *button,
 	      libpolyxmass_globals_strtod ((gchar *) help,
 					   &(calcctxt->masspair_temp->mono)))
 	    {
-	      g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	      g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		     __FILE__, __LINE__, help);
 
 	      return ;
@@ -900,7 +907,7 @@ polyxcalc_ui_calculator_wnd_apply_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  return ;
@@ -931,7 +938,7 @@ polyxcalc_ui_calculator_wnd_apply_button (GtkWidget *button,
 	      libpolyxmass_globals_strtod ((gchar *) help,
 					   &(calcctxt->masspair_temp->avg)))
 	    {
-	      g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	      g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		     __FILE__, __LINE__, help);
 
 	      return ;
@@ -1008,7 +1015,7 @@ polyxcalc_ui_calculator_wnd_apply_button (GtkWidget *button,
 
 
 void 
-polyxcalc_ui_calculator_wnd_univ_chem_elem_checkbutton (GtkWidget *widget,
+polyxcalc_ui_calculator_wnd_univ_chem_entities_checkbutton (GtkWidget *widget,
 							gpointer data)
 {
   PxmCalcCtxt *calcctxt = data;
@@ -1022,11 +1029,11 @@ polyxcalc_ui_calculator_wnd_univ_chem_elem_checkbutton (GtkWidget *widget,
   calculator_wnd = calcctxt->calculator_wnd;
   g_assert (calculator_wnd != NULL);
 
-  box = g_object_get_data (G_OBJECT (calculator_wnd), "univ_chem_elem_vbox");
+  box = g_object_get_data (G_OBJECT (calculator_wnd), "univ_chem_entities_vbox");
   g_assert (box != NULL);
   
   checkbutton = g_object_get_data (G_OBJECT (calculator_wnd), 
-				   "univ_chem_elem_checkbutton");
+				   "univ_chem_entities_checkbutton");
   g_assert (checkbutton != NULL);
 
   if (TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
@@ -1062,7 +1069,7 @@ polyxcalc_ui_calculator_wnd_atoms_checkbutton (GtkWidget *widget,
   g_assert (box != NULL);
   
   /* This function might be called by another function, like
-     polyxcalc_ui_calculator_wnd_universal_chem_elements_checkbutton
+     polyxcalc_ui_calculator_wnd_universal_chem_entities_checkbutton
      (), for example, with a NULL first argument. But since we know
      that we are working on a known checkbutton that is of no concern,
      we just get the checkbutton from the object data.
@@ -1099,7 +1106,7 @@ polyxcalc_ui_calculator_wnd_formula_actform_checkbutton (GtkWidget *widget,
   g_assert (box != NULL);
   
   /* This function might be called by another function, like
-     polyxcalc_ui_calculator_wnd_universal_chem_elements_checkbutton
+     polyxcalc_ui_calculator_wnd_universal_chem_entities_checkbutton
      (), for example, with a NULL first argument. But since we know
      that we are working on a known checkbutton that is of no concern,
      we just get the checkbutton from the object data.
@@ -1118,7 +1125,7 @@ polyxcalc_ui_calculator_wnd_formula_actform_checkbutton (GtkWidget *widget,
 
 
 void 
-polyxcalc_ui_calculator_wnd_polchemdefspec_elem_checkbutton (GtkWidget *widget,
+polyxcalc_ui_calculator_wnd_polchemdefspec_entities_checkbutton (GtkWidget *widget,
 							     gpointer data)
 {
   PxmCalcCtxt *calcctxt = data;
@@ -1133,11 +1140,11 @@ polyxcalc_ui_calculator_wnd_polchemdefspec_elem_checkbutton (GtkWidget *widget,
   g_assert (calculator_wnd != NULL);
 
   box = g_object_get_data (G_OBJECT (calculator_wnd), 
-			   "polchemdef_spec_elem_vbox");
+			   "polchemdef_spec_entities_vbox");
   g_assert (box != NULL);
   
   checkbutton = g_object_get_data (G_OBJECT (calculator_wnd), 
-				   "polchemdef_spec_elements_checkbutton");
+				   "polchemdef_spec_entities_checkbutton");
   g_assert (checkbutton != NULL);
 
   if (TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
@@ -1175,7 +1182,7 @@ polyxcalc_ui_calculator_wnd_monomers_checkbutton (GtkWidget *widget,
   g_assert (box != NULL);
   
   /* This function might be called by another function, like
-     polyxcalc_ui_calculator_wnd_polchemdef_spec_elements_checkbutton
+     polyxcalc_ui_calculator_wnd_polchemdef_spec_entities_checkbutton
      (), for example, with a NULL first argument. But since we know
      that we are working on a known checkbutton that is of no concern,
      we just get the checkbutton from the object data.
@@ -1359,7 +1366,7 @@ polyxcalc_ui_calculator_wnd_init_masses_add_to_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1387,7 +1394,7 @@ polyxcalc_ui_calculator_wnd_init_masses_add_to_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -1421,7 +1428,7 @@ polyxcalc_ui_calculator_wnd_init_masses_add_to_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1449,7 +1456,7 @@ polyxcalc_ui_calculator_wnd_init_masses_add_to_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -1470,12 +1477,12 @@ polyxcalc_ui_calculator_wnd_init_masses_add_to_res_button (GtkWidget *button,
 			  calcctxt->masspair_init->avg);
 
 
-  /* Make the MONO computation per se:
+  /* Make the MONO calculation per se:
    */
   libpolyxmass_masspair_set_mono (calcctxt->masspair_temp, 
 				  calcctxt->masspair_init->mono 
 				  + calcctxt->masspair_temp->mono);
-  /* Make the AVG computation per se:
+  /* Make the AVG calculation per se:
    */
   libpolyxmass_masspair_set_avg (calcctxt->masspair_temp, 
 				 calcctxt->masspair_init->avg 
@@ -1585,7 +1592,7 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1613,7 +1620,7 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -1646,7 +1653,7 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1674,7 +1681,7 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -1686,7 +1693,7 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
     libpolyxmass_masspair_set_avg (calcctxt->masspair_temp, 0);
   
   /* Start making the log for the initial conditions, prior to
-     actually computing the difference.
+     actually calculating the difference.
   */
   g_string_append_printf (gs, 
 			  _("Removed initial (mono: %f ; avg: %f)\n"
@@ -1696,16 +1703,16 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
 			  calcctxt->masspair_init->mono, 
 			  calcctxt->masspair_init->avg);
 
-  /* Now we can perform the computation.
+  /* Now we can perform the calculation.
    */
 
-  /* Make the MONO computation per se:
+  /* Make the MONO calculation per se:
    */
   libpolyxmass_masspair_set_mono (calcctxt->masspair_temp, 
 				  calcctxt->masspair_init->mono 
 				  - calcctxt->masspair_temp->mono);
 
-  /* Make the AVG computation per se:
+  /* Make the AVG calculation per se:
    */
   libpolyxmass_masspair_set_avg (calcctxt->masspair_temp, 
 				 calcctxt->masspair_init->avg 
@@ -1749,7 +1756,7 @@ polyxcalc_ui_calculator_wnd_init_masses_rem_from_res_button (GtkWidget *button,
   /* Finally conclude the operation's log.
    */
   g_string_append_printf (gs, 
-			  _("\t\t==> mono: %f ; avg: %f\n"), 
+			  "\t\t==> mono: %f ; avg: %f\n", 
 			  calcctxt->masspair_temp->mono, 
 			  calcctxt->masspair_temp->avg);
   
@@ -1816,7 +1823,7 @@ polyxcalc_ui_calculator_wnd_init_masses_send_to_res_button(GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1854,7 +1861,7 @@ polyxcalc_ui_calculator_wnd_init_masses_send_to_res_button(GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1887,7 +1894,7 @@ polyxcalc_ui_calculator_wnd_init_masses_send_to_res_button(GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -1925,7 +1932,7 @@ polyxcalc_ui_calculator_wnd_init_masses_send_to_res_button(GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2003,7 +2010,7 @@ polyxcalc_ui_calculator_wnd_init_masses_clear_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2033,7 +2040,7 @@ polyxcalc_ui_calculator_wnd_init_masses_clear_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2047,7 +2054,7 @@ polyxcalc_ui_calculator_wnd_init_masses_clear_button (GtkWidget *button,
   gtk_entry_set_text (GTK_ENTRY (entry), "");
 
   g_string_append_printf (gs, 
-			  _("Cleared initial (were mono: %f ; avg: %f\n"),
+			  _("Cleared initial (was mono: %f ; avg: %f)\n"),
 			  calcctxt->masspair_init->mono, 
 			  calcctxt->masspair_init->avg);
     
@@ -2114,7 +2121,7 @@ polyxcalc_ui_calculator_wnd_res_masses_add_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2142,7 +2149,7 @@ polyxcalc_ui_calculator_wnd_res_masses_add_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2175,7 +2182,7 @@ polyxcalc_ui_calculator_wnd_res_masses_add_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2203,7 +2210,7 @@ polyxcalc_ui_calculator_wnd_res_masses_add_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2225,16 +2232,16 @@ polyxcalc_ui_calculator_wnd_res_masses_add_to_init_button (GtkWidget *button,
 			  calcctxt->masspair_init->avg);
 
 
-  /* Now we can perform the computation.
+  /* Now we can perform the calculation.
    */
 
-  /* Make the MONO computation per se:
+  /* Make the MONO calculation per se:
    */
   libpolyxmass_masspair_set_mono (calcctxt->masspair_init, 
 				  calcctxt->masspair_init->mono 
 				  + calcctxt->masspair_temp->mono);
   
-  /* Make the AVG computation per se:
+  /* Make the AVG calculation per se:
    */
   libpolyxmass_masspair_set_avg (calcctxt->masspair_init, 
 				 calcctxt->masspair_init->avg 
@@ -2329,7 +2336,7 @@ polyxcalc_ui_calculator_wnd_res_masses_rem_from_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2357,7 +2364,7 @@ polyxcalc_ui_calculator_wnd_res_masses_rem_from_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2390,7 +2397,7 @@ polyxcalc_ui_calculator_wnd_res_masses_rem_from_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2418,7 +2425,7 @@ polyxcalc_ui_calculator_wnd_res_masses_rem_from_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2440,16 +2447,16 @@ polyxcalc_ui_calculator_wnd_res_masses_rem_from_init_button (GtkWidget *button,
 			  calcctxt->masspair_init->avg);
 
 
-  /* Now we can perform the computation.
+  /* Now we can perform the calculation.
    */
 
-  /* Make the MONO computation per se:
+  /* Make the MONO calculation per se:
    */
   libpolyxmass_masspair_set_mono (calcctxt->masspair_init, 
 				  calcctxt->masspair_init->mono 
 				  - calcctxt->masspair_temp->mono);
   
-  /* Make the AVG computation per se:
+  /* Make the AVG calculation per se:
    */
   libpolyxmass_masspair_set_avg (calcctxt->masspair_init, 
 				 calcctxt->masspair_init->avg 
@@ -2543,7 +2550,7 @@ polyxcalc_ui_calculator_wnd_res_masses_send_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2581,7 +2588,7 @@ polyxcalc_ui_calculator_wnd_res_masses_send_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2614,7 +2621,7 @@ polyxcalc_ui_calculator_wnd_res_masses_send_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2651,7 +2658,7 @@ polyxcalc_ui_calculator_wnd_res_masses_send_to_init_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  g_string_free (gs, TRUE);
@@ -2730,7 +2737,7 @@ polyxcalc_ui_calculator_wnd_res_masses_clear_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2760,7 +2767,7 @@ polyxcalc_ui_calculator_wnd_res_masses_clear_button (GtkWidget *button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_init->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  g_string_free (gs, TRUE);
@@ -2774,7 +2781,7 @@ polyxcalc_ui_calculator_wnd_res_masses_clear_button (GtkWidget *button,
   gtk_entry_set_text (GTK_ENTRY (entry), "");
 
   g_string_append_printf (gs, 
-			  _("Cleared result (were mono: %f ; avg: %f\n"),
+			  _("Cleared result (was mono: %f ; avg: %f)\n"),
 			  calcctxt->masspair_init->mono, 
 			  calcctxt->masspair_init->avg);
     
@@ -2876,21 +2883,24 @@ void
 polyxcalc_ui_calculator_wnd_mz_ratio_calculator_button (GtkWidget *button,
 							gpointer data)
 {
+  GtkWidget *parent_wnd = NULL;
+  GtkWidget *window = NULL;
+  
   PxmCalcCtxt *calcctxt = data;
   
   GPtrArray *atomGPA = NULL;
   
-  GtkWindow *parent_wnd = NULL;
 
   PxmIonizerule *ionizerule = NULL;
   
 
   g_assert (calcctxt != NULL);
-  
+
+
   atomGPA = calcctxt->atomGPA;
   g_assert (atomGPA != NULL);
 
-  parent_wnd = (GtkWindow *) calcctxt->calculator_wnd;
+  parent_wnd = calcctxt->calculator_wnd;
   g_assert (parent_wnd != NULL);
   
   ionizerule = pxmchem_ionizerule_new ();
@@ -2906,11 +2916,32 @@ polyxcalc_ui_calculator_wnd_mz_ratio_calculator_button (GtkWidget *button,
      parameters and not simply the calcctxt pointer, because that same
      window might be called through the polyxedit module.
   */
-  if (NULL == polyxmass_mz_ratio_wnd_setup (atomGPA, 
-					    ionizerule,
-					    parent_wnd))
-    g_critical (_("%s@%d: failed opening the mz ratio calculator window\n"),
-	   __FILE__, __LINE__);
+  window = polyxmass_mz_ratio_wnd_setup (atomGPA, 
+					 ionizerule,
+					 parent_wnd,
+					 "POLYXCALC");
+  if (window == NULL)
+    {
+      g_critical (_("%s@%d: failed to open the m/z ratio calculator window\n"),
+		  __FILE__, __LINE__);
+      
+      return;
+    }
+  
+  /* Register this results' window !
+   */
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXCALC",
+       window,
+       parent_wnd,
+       NULL,
+       _("Results of m/z Calculations"),
+       NULL,
+       TRUE,
+       polyxmass_mz_ratio_wnd_make_report))
+    g_critical (_("%s@%d: failed to register the m/z calculations "
+		  "results' window\n"),
+		__FILE__, __LINE__);
   
   return;
 }
@@ -2931,7 +2962,7 @@ polyxcalc_ui_calculator_wnd_delete_event (GtkWidget *widget,
   if (FALSE == g_ptr_array_remove (polyxcalc_calcctxtGPA, 
 				   (PxmCalcCtxt *) data))
     {
-      g_critical (_("%s@%d: failed removing context from array.\n"),
+      g_critical (_("%s@%d: failed to remove context from array.\n"),
 	     __FILE__, __LINE__);
     }
   
