@@ -225,8 +225,7 @@ polyxcalc_ui_chempad_wnd_setup_window (PxmCalcCtxt *calcctxt)
 
   if (xml == NULL)
     {
-      g_critical (
-	     _("%s@%d: failed loading the interface\n"),
+      g_critical (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -237,7 +236,7 @@ polyxcalc_ui_chempad_wnd_setup_window (PxmCalcCtxt *calcctxt)
 
   if (calcctxt->chempad_wnd == NULL)
     {
-      g_critical (_("%s@%d: could not create the chempad window\n"),
+      g_critical (_("%s@%d: failed to create the chempad window\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -256,7 +255,7 @@ polyxcalc_ui_chempad_wnd_setup_window (PxmCalcCtxt *calcctxt)
   
   /* Now that we have the calcctxt->chempad_wnd skeleton, we should
      fill it with the buttons. But to know what chempad keys we have
-     to create, we need to know what polymer definition is currently
+     to create, we need to know what polymer chemistry definition is currently
      loaded (if any). When setting up the calculator window, we did
      load the polymer chemistry definition, if any. And thus we did
      set the directory of that polymer chemistry definition data.
@@ -430,7 +429,7 @@ polyxcalc_ui_chempad_wnd_fill_layout (PxmCalcCtxt *calcctxt, gchar *file)
   if (FALSE == polyxcalc_chempad_parse_file (file, cpkGPA, cpg, 
 					     calcctxt->atomGPA))
     {
-      g_critical (_("%s@%d: failed parsing the chempad file: '%s'\n"),
+      g_critical (_("%s@%d: failed to parse the chempad file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
       polyxcalc_chempadkey_GPA_free (cpkGPA);
@@ -478,7 +477,7 @@ polyxcalc_ui_chempad_wnd_fill_layout (PxmCalcCtxt *calcctxt, gchar *file)
     {
       cpg->cols = 3;
       
-      /* We should compute the number of rows, given the fact that we
+      /* We should calculate the number of rows, given the fact that we
 	 have arbitrarily decided that we would lay out the chempad in
 	 three columns.
       */
@@ -495,7 +494,7 @@ polyxcalc_ui_chempad_wnd_fill_layout (PxmCalcCtxt *calcctxt, gchar *file)
       
   else if (cpg->rows <= 0)
     {
-      /* We should compute the number of rows, knowing that the user
+      /* We should calculate the number of rows, knowing that the user
 	 has asked that the chempad be laid out using cpg->cols.
       */
       ratio = count/cpg->cols;
@@ -517,7 +516,7 @@ polyxcalc_ui_chempad_wnd_fill_layout (PxmCalcCtxt *calcctxt, gchar *file)
 
   else if (cpg->cols <= 0)
     {
-      /* We should compute the number of cols, knowing that the user
+      /* We should calculate the number of cols, knowing that the user
 	 has asked that the chempad be laid out using cpg->rows.
       */
       ratio = (gfloat) count/(gfloat) cpg->rows;
@@ -680,8 +679,8 @@ polyxcalc_chempad_parse_file (gchar *file,
   
   if (FALSE == g_file_test (file, G_FILE_TEST_EXISTS))
     {
-      g_critical (_("%s@%d: polymer definition file does"
-	       " not exist: %s\n"),
+      g_critical (_("%s@%d: polymer chemistry definition file does"
+	       " not exist: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return FALSE;
@@ -692,7 +691,7 @@ polyxcalc_chempad_parse_file (gchar *file,
   
   if (NULL == stream)
     {
-      g_critical (_("%s@%d: could not open the chempad configuration"
+      g_critical (_("%s@%d: failed to open the chempad configuration"
 	       " file: '%s'\n"),
 	     __FILE__, __LINE__, file);
 
@@ -841,7 +840,7 @@ polyxcalc_chempad_parse_geometry (gchar *line, PxmChempadgeo *cpg)
    */
   if (strlen (gs->str) <= 0)
     {
-        g_critical (_("%s@%d: error while parsing line: '%s'\n"),
+        g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 	 __FILE__, __LINE__, line);
 
 	g_string_free (gs, TRUE);
@@ -853,7 +852,7 @@ polyxcalc_chempad_parse_geometry (gchar *line, PxmChempadgeo *cpg)
    */
   if (FALSE == libpolyxmass_globals_strtoi (gs->str, &val, 10))
     {
-      g_critical (_("%s@%d: failed converting string to integer: '%s'\n"),
+      g_critical (_("%s@%d: failed to convert from '%s' to gint\n"),
 	     __FILE__, __LINE__, gs->str);
       
       g_string_free (gs, TRUE);
@@ -871,7 +870,7 @@ polyxcalc_chempad_parse_geometry (gchar *line, PxmChempadgeo *cpg)
     polyxcalc_chempadgeo_set_cols (cpg, val);
   else
     {
-      g_critical (_("%s@%d: error while parsing line: '%s'\n"),
+      g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       g_string_free (gs, TRUE);
@@ -927,7 +926,7 @@ polyxcalc_chempad_parse_chempadkey (gchar *line, PxmChempadkey *cpk,
 	       */
 	      if (strlen (gs->str) <= 0)
 		{
-		  g_critical (_("%s@%d: error while parsing line '%s'\n"),
+		  g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 			 __FILE__, __LINE__, line);
 		  
 		  g_string_free (gs, TRUE);
@@ -949,7 +948,7 @@ polyxcalc_chempad_parse_chempadkey (gchar *line, PxmChempadkey *cpk,
 	       */
 	      if (strlen (gs->str) <= 0)
 		{
-		  g_critical (_("%s@%d: error while parsing line '%s'\n"),
+		  g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 			 __FILE__, __LINE__, line);
 		  
 		  g_string_free (gs, TRUE);
@@ -961,7 +960,7 @@ polyxcalc_chempad_parse_chempadkey (gchar *line, PxmChempadkey *cpk,
 	       */
 	      if (FALSE == pxmchem_actform_check (gs->str, atom_refGPA))
 		{
-		  g_critical (_("%s@%d: error while parsing line '%s'\n"),
+		  g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 			 __FILE__, __LINE__, line);
 		  
 		  g_string_free (gs, TRUE);
@@ -996,7 +995,7 @@ polyxcalc_chempad_parse_chempadkey (gchar *line, PxmChempadkey *cpk,
        */
       if (strlen (gs->str) <= 0)
 	{
-	  g_critical (_("%s@%d: error while parsing line '%s'\n"),
+	  g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 		 __FILE__, __LINE__, line);
 	  
 	  g_string_free (gs, TRUE);
@@ -1017,7 +1016,7 @@ polyxcalc_chempad_parse_chempadkey (gchar *line, PxmChempadkey *cpk,
       || FALSE == actform_done 
       || FALSE == tooltip_done)
     {
-      g_critical (_("%s@%d: error while parsing line '%s'\n"),
+      g_critical (_("%s@%d: failed to parse line: '%s'\n"),
 	     __FILE__, __LINE__, line);
       
       return FALSE;
@@ -1074,7 +1073,7 @@ polyxcalc_ui_chempad_wnd_chempadkey_button (GtkWidget * button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->mono)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 	  
 	  return 0;
@@ -1105,7 +1104,7 @@ polyxcalc_ui_chempad_wnd_chempadkey_button (GtkWidget * button,
 	  libpolyxmass_globals_strtod ((gchar *) help,
 				       &(calcctxt->masspair_temp->avg)))
 	{
-	  g_critical (_("%s@%d: failed conversion from '%s' to gdouble\n"),
+	  g_critical (_("%s@%d: failed to convert from '%s' to gdouble\n"),
 		 __FILE__, __LINE__, help);
 
 	  return 0;
@@ -1144,18 +1143,18 @@ polyxcalc_ui_chempad_wnd_chempadkey_button (GtkWidget * button,
   if (FALSE == pxmchem_actform_account_mass (actform, calcctxt->atomGPA,
 					     1, calcctxt->masspair_temp))
     {
-      g_critical (_("%s@%d: failed accounting actform chempad key: '%s'\n"),
+      g_critical (_("%s@%d: failed to account for actform chempad key: '%s'\n"),
 	     __FILE__, __LINE__, actform);
       
       g_string_append_printf (gs, 
-			      _("Failed accounting actform chempad key:"
+			      _("Failed to account for actform chempad key:"
 				" '%s'\n"), actform);
       
       error = 0;
     }
   else
     g_string_append_printf (gs, 
-			    _("Accounted actform chempad key: '%s' ==>"
+			    _("Account for actform chempad key: '%s' ==>"
 			      " mono: %f ; avg: %f\n"),
 			    actform, calcctxt->masspair_temp->mono, 
 			    calcctxt->masspair_temp->avg);
