@@ -78,7 +78,7 @@ polyxdef_ui_atomdef_wnd_setup_window (PxmDefCtxt *defctxt)
   
   if (xml == NULL)
     {
-      g_critical (_("%s@%d: failed loading the interface\n"),
+      g_critical (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -89,7 +89,7 @@ polyxdef_ui_atomdef_wnd_setup_window (PxmDefCtxt *defctxt)
   
   if (defctxt->definition_wnd == NULL)
     {
-      g_critical (_("%s@%d: failed creating the atom definition window\n"),
+      g_critical (_("%s@%d: failed to create the atom definition window\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -332,7 +332,7 @@ polyxdef_ui_atomdef_wnd_check_syntax_button (GtkWidget *widget,
 	  
 	  if (defctxt->syntax_check_wnd == NULL)
 	    {
-	      g_message (_("%s@%d: failed setting up the syntax-checking "
+	      g_message (_("%s@%d: failed to set up the syntax-checking "
 		       "window for the following errors: '%s'\n\n"),
 		     __FILE__, __LINE__, valid);
 	      
@@ -617,7 +617,7 @@ polyxdef_ui_atomdef_wnd_create_atoms_treeview (PxmDefCtxt *defctxt)
 		     (gint *) COLUMN_ATOM_AVG_MASS);
 
   /* Note that we do not want that the user changes the average mass
-     manually, as this mass has to be computed from the isotopes each
+     manually, as this mass has to be calculated from the isotopes each
      time an atom definition file is read from disk.
   */
 
@@ -798,8 +798,8 @@ polyxdef_ui_atomdef_wnd_atom_name_cell_edited (GtkCellRendererText *cell,
 	
   if (-1 != result)
     {
-      help = g_strdup_printf (_("error, an atom by the same name"
-				" exists already: %s"),
+      help = g_strdup_printf (_("An atom by the same name"
+				" exists already: '%s'"),
 			      new_text);
 
       polyxmass_timeoutmsg_message_set 
@@ -896,8 +896,8 @@ polyxdef_ui_atomdef_wnd_atom_symbol_cell_edited (GtkCellRendererText *cell,
 	
   if (-1 != result)
     {
-      help = g_strdup_printf (_("error, an atom by the same symbol"
-				" exists already: %s"),
+      help = g_strdup_printf (_("An atom by the same symbol"
+				" exists already: '%s'"),
 			      new_text);
 	    
       polyxmass_timeoutmsg_message_set 
@@ -915,7 +915,7 @@ polyxdef_ui_atomdef_wnd_atom_symbol_cell_edited (GtkCellRendererText *cell,
   */
   if (FALSE == pxmchem_atom_check_symbol_syntax ((gchar *) new_text))
     {
-      help = g_strdup_printf (_("error, bad syntax for atom symbol: %s"),
+      help = g_strdup_printf (_("Incorrect syntax for atom symbol: '%s'"),
 			      new_text);
 	    
       polyxmass_timeoutmsg_message_set 
@@ -1026,7 +1026,7 @@ polyxdef_ui_atomdef_wnd_isotope_mass_cell_edited (GtkCellRendererText *cell,
   */
   if (FALSE == libpolyxmass_globals_strtod ((gchar *) new_text, &value))
     {
-      help = g_strdup_printf (_("error, bad syntax for isotope mass: %s"),
+      help = g_strdup_printf (_("Incorrect syntax for isotope mass: '%s'"),
 			      new_text);
       
       polyxmass_timeoutmsg_message_set 
@@ -1150,8 +1150,8 @@ polyxdef_ui_atomdef_wnd_isotope_abund_cell_edited (GtkCellRendererText *cell,
   */
   if (FALSE == libpolyxmass_globals_strtod ((gchar *) new_text, &value))
     {
-      help = g_strdup_printf (_("error, bad syntax for isotope "
-				"abundance: %s"),
+      help = g_strdup_printf (_("Incorrect syntax for isotope "
+				"abundance: '%s'"),
 			      new_text);
       
       polyxmass_timeoutmsg_message_set 
@@ -1307,8 +1307,8 @@ polyxdef_ui_atomdef_wnd_add_atom_button (GtkWidget *widget,
       */
       atom = pxmchem_atom_new ();
 
-      pxmchem_atom_set_name (atom, "name here");
-      pxmchem_atom_set_symbol (atom, "symbol here");
+      pxmchem_atom_set_name (atom, _("enter name here"));
+      pxmchem_atom_set_symbol (atom, _("enter symbol here"));
       
       g_ptr_array_add (defctxt->atomGPA, atom);
 
@@ -1377,7 +1377,7 @@ polyxdef_ui_atomdef_wnd_add_atom_button (GtkWidget *widget,
   
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) defctxt->definition_wnd,
-	 _("added new atom:"
+	 _("Added new atom;"
 	   " please, set its data!"), 
 	 POLYXMASS_LONG_MSG_TIMEOUT); 
       
@@ -1450,8 +1450,8 @@ polyxdef_ui_atomdef_wnd_add_atom_button (GtkWidget *widget,
   */
   atom = pxmchem_atom_new ();
   
-  pxmchem_atom_set_name (atom, "name here");
-  pxmchem_atom_set_symbol (atom, "symbol here");
+  pxmchem_atom_set_name (atom, _("enter name here"));
+  pxmchem_atom_set_symbol (atom, _("enter symbol here"));
 
   path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), 
 				  &tree_iter);
@@ -1480,7 +1480,7 @@ polyxdef_ui_atomdef_wnd_add_atom_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add atom item to array\n"),
+      g_error (_("%s@%d: failed to insert/add atom item to array\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -1546,7 +1546,7 @@ polyxdef_ui_atomdef_wnd_add_atom_button (GtkWidget *widget,
   gtk_tree_path_free (path);
   
   polyxmass_timeoutmsg_message_set ((GtkWindow *) defctxt->definition_wnd,
-				    _("added new atom:"
+				    _("Added new atom;"
 				      " please, set its data!"), 
 				    POLYXMASS_LONG_MSG_TIMEOUT); 
   return;
@@ -1710,7 +1710,7 @@ polyxdef_ui_atomdef_wnd_add_isotope_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add mass/abund "
+      g_error (_("%s@%d: failed to insert/add mass/abund "
 		 "pair to atom treeview\n"),
 	       __FILE__, __LINE__);
     }
@@ -1810,8 +1810,8 @@ polyxdef_ui_atomdef_wnd_add_isotope_button (GtkWidget *widget,
 	}
       else
 	{
-	  g_error (_("%s@%d: could not insert/add mass/abund "
-		   "pair to arrays\n"),
+	  g_error (_("%s@%d: failed to insert/add mass/abund "
+		   "pair to array\n"),
 		 __FILE__, __LINE__);
 	}
     }
@@ -1881,7 +1881,7 @@ polyxdef_ui_atomdef_wnd_add_isotope_button (GtkWidget *widget,
   polyxdef_ui_atomdef_wnd_atom_avg_mass_cell_update (defctxt, idx_atom);
 
   polyxmass_timeoutmsg_message_set ((GtkWindow *) defctxt->definition_wnd,
-				    _("added new isotope:"
+				    _("Added new isotope;"
 				      " please, set its data!"), 
 				    POLYXMASS_LONG_MSG_TIMEOUT); 
   return;
@@ -2028,7 +2028,7 @@ polyxdef_ui_atomdef_wnd_remove_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not remove item from treeview\n"),
+      g_error (_("%s@%d: failed to remove item from treeview\n"),
 	       __FILE__, __LINE__);
     }
 
@@ -2037,7 +2037,7 @@ polyxdef_ui_atomdef_wnd_remove_button (GtkWidget *widget,
   gtk_tree_path_free (path);
 
   polyxmass_timeoutmsg_message_set ((GtkWindow *) defctxt->definition_wnd,
-				    _("successfully removed item"), 
+				    _("Successfully removed item"), 
 				    POLYXMASS_NORM_MSG_TIMEOUT); 
   return;
 }
@@ -2093,8 +2093,8 @@ polyxdef_ui_atomdef_wnd_save_button (GtkWidget *widget,
 	  
 	  if (defctxt->syntax_check_wnd == NULL)
 	    {
-	      g_message (_("%s@%d: failed setting up the syntax-checking "
-		       "window for the followingerrors: '%s'\n\n"),
+	      g_message (_("%s@%d: failed to set up the syntax-checking "
+		       "window for the following errors: '%s'\n\n"),
 		     __FILE__, __LINE__, valid);
 	      
 	      g_free (valid);
@@ -2147,7 +2147,7 @@ polyxdef_ui_atomdef_wnd_save_button (GtkWidget *widget,
 
   if (filep == NULL)
     {
-      g_critical (_("%s@%d: error with opening file '%s'\n"),
+      g_critical (_("%s@%d: failed to open file: '%s'\n"),
 	     __FILE__, __LINE__, defctxt->filename);
       
       return;
@@ -2170,7 +2170,7 @@ polyxdef_ui_atomdef_wnd_save_button (GtkWidget *widget,
   
   if (result == EOF || result < 0)
     {
-      g_critical (_("%s@%d: error with saving atom array to file '%s'\n"),
+      g_critical (_("%s@%d: failed to save atom array to file: '%s'\n"),
 	     __FILE__, __LINE__, defctxt->filename);
       
       return;
@@ -2237,8 +2237,8 @@ polyxdef_ui_atomdef_wnd_saveas_button (GtkWidget *widget,
 	  
 	  if (defctxt->syntax_check_wnd == NULL)
 	    {
-	      g_message (_("%s@%d: failed validating the atom "
-		       "definition:\n\n %s.\n"),
+	      g_message (_("%s@%d: failed to validate the atom "
+		       "definition with the following errors:\n\n %s.\n"),
 		     __FILE__, __LINE__, valid);
 	      
 	      g_free (valid);
@@ -2270,7 +2270,7 @@ polyxdef_ui_atomdef_wnd_saveas_button (GtkWidget *widget,
   
 
   dialog = 
-    gtk_file_chooser_dialog_new ("Save Atom Definition File",
+    gtk_file_chooser_dialog_new (_("Save Atom Definition File"),
 				 GTK_WINDOW (defctxt->definition_wnd),
 				 GTK_FILE_CHOOSER_ACTION_SAVE,
 				 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -2283,7 +2283,7 @@ polyxdef_ui_atomdef_wnd_saveas_button (GtkWidget *widget,
       
       if (TRUE == g_file_test (filename, G_FILE_TEST_EXISTS))
 	{
-	  g_critical ("%s@%d: file does exist already: '%s'\n",
+	  g_critical (_("%s@%d: file does exist already: '%s'\n"),
 		 __FILE__, __LINE__, filename);
 	  
 	  g_free (filename);
@@ -2319,7 +2319,7 @@ polyxdef_ui_atomdef_wnd_saveas_button (GtkWidget *widget,
   
   if (filep == NULL)
     {
-      g_critical (_("%s@%d: error with opening file %s\n"),
+      g_critical (_("%s@%d: failed to open file: '%s'\n"),
 	     __FILE__, __LINE__, filename);
       
       g_free (filename);
@@ -2344,7 +2344,7 @@ polyxdef_ui_atomdef_wnd_saveas_button (GtkWidget *widget,
   
   if (result == EOF || result < 0)
     {
-      g_critical (_("%s@%d: error with saving atom array to file '%s'\n"),
+      g_critical (_("%s@%d: failed to save atom array to file: '%s'\n"),
 	     __FILE__, __LINE__, filename);
       
       return;
@@ -2411,7 +2411,7 @@ polyxdef_ui_atomdef_wnd_atom_avg_mass_cell_update (PxmDefCtxt *defctxt,
 
   
   /* An isotope mass or an isotope abundance have been changed. We
-     thus have to recompute the average mass of the atom. Next, we have
+     thus have to recalculate the average mass of the atom. Next, we have
      to display that new value in the correct cell of the atoms treeview.
   */
   g_assert (defctxt != NULL);
@@ -2449,12 +2449,12 @@ polyxdef_ui_atomdef_wnd_atom_avg_mass_cell_update (PxmDefCtxt *defctxt,
   
   gtk_tree_model_get_iter (model, &tree_iter, path);
 
-  /* Time has come to make the computation of the average mass...
+  /* Time has come to make the calculation of the average mass...
    */
 
   if (FALSE == pxmchem_atom_calc_avg_in_atom (atom))
     {
-      help = g_strdup_printf (_("error, failed computing average mass"));
+      help = g_strdup_printf (_("Failed to calculate average mass"));
       
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) defctxt->definition_wnd, 
@@ -2523,7 +2523,7 @@ polyxdef_ui_atomdef_wnd_delete_event (GtkWidget *window,
       if (FALSE == g_ptr_array_remove (polyxdef_defctxtGPA, 
 				       defctxt))
 	{
-	  g_critical (_("%s@%d: failed removing context from array.\n"),
+	  g_critical (_("%s@%d: failed to remove context from array.\n"),
 		 __FILE__, __LINE__);
 	}
 
@@ -2535,7 +2535,7 @@ polyxdef_ui_atomdef_wnd_delete_event (GtkWidget *window,
   /* The polyxdef context associated with this widget is modified, we
    * should ask if it should be saved before.
    */
-  help = g_strdup_printf ("The atom definition is modified, save it?\n");
+  help = g_strdup_printf (_("The atom definition is modified, save it?\n"));
   
   dialog = gtk_message_dialog_new (GTK_WINDOW (defctxt->definition_wnd),
 				   GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -2574,7 +2574,7 @@ polyxdef_ui_atomdef_wnd_delete_event (GtkWidget *window,
 	  if (FALSE == g_ptr_array_remove (polyxdef_defctxtGPA, 
 					   defctxt))
 	    {
-	      g_critical (_("%s@%d: failed removing context from array.\n"),
+	      g_critical (_("%s@%d: failed to remove context from array.\n"),
 		     __FILE__, __LINE__);
 	    }
 	  
@@ -2594,7 +2594,7 @@ polyxdef_ui_atomdef_wnd_delete_event (GtkWidget *window,
       if (FALSE == g_ptr_array_remove (polyxdef_defctxtGPA, 
 				       defctxt))
 	{
-	  g_critical (_("%s@%d: failed removing context from array.\n"),
+	  g_critical (_("%s@%d: failed to remove context from array.\n"),
 		 __FILE__, __LINE__);
 	}
       
