@@ -56,7 +56,7 @@ polyxdef_ui_polchemdef_wnd_setup_cleavespecs_notebook_page (PxmDefCtxt *defctxt,
   if (FALSE == 
       polyxdef_ui_polchemdef_wnd_setup_cleavespecs_treeview (defctxt))
     {
-      g_critical (_("%s@%d: failed setting up the cleavespecs' material\n"),
+      g_critical (_("%s@%d: failed to set up the cleavage specifications\n"),
 	     __FILE__, __LINE__);
       
       return FALSE;
@@ -547,7 +547,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	if (depth > 1)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a cleavespec first"));
+	      g_strdup_printf (_("Select or create a cleavespec first"));
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
@@ -569,8 +569,8 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 
 	if (-1 != result)
 	  {
-	    help = g_strdup_printf (_("error, a cleavespec by the same name"
-				      " exists already: %s"),
+	    help = g_strdup_printf (_("A cleavespec by the same name"
+				      " exists already: '%s'"),
 				    new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -616,7 +616,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	if (depth > 1)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a cleavespec first"));
+	      g_strdup_printf (_("Select or create a cleavespec first"));
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
@@ -657,8 +657,8 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 						     codelen))
 	  {
 	    help = 
-	      g_strdup_printf (_("error, the cleavespec pattern "
-				 "is wrong: %s"), new_text);
+	      g_strdup_printf (_("Cleavespec pattern "
+				 "is wrong: '%s'"), new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd, 
@@ -701,7 +701,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	if (depth != 2)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a cleaverule first"));
+	      g_strdup_printf (_("Select or create a cleaverule first"));
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
@@ -714,7 +714,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	  }
 	
 	/* But first yet, verify that the monomer code is existing 
-	 * in the polymer definition ! This ONLY if the new_text is 
+	 * in the polymer chemistry definition ! This ONLY if the new_text is 
 	 * of non-0 length, because the DTD stipulates that this
 	 * monomer code may be empty if no corresponding actform is
 	 * found. This translates into: "no cleaverule is required,
@@ -730,7 +730,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	  {
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
-	       _("error: code unknown"), 
+	       _("Code is unknown"), 
 	       POLYXMASS_MEDI_MSG_TIMEOUT);
 	    return ;
 	  }
@@ -774,7 +774,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	if (depth != 2)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a cleaverule first"));
+	      g_strdup_printf (_("Select or create a cleaverule first"));
 	    
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -828,7 +828,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 		
 		polyxmass_timeoutmsg_message_set 
 		  ((GtkWindow *) defctxt->definition_wnd,
-		   _("error: related code is unknown"), 
+		   _("Related code is unknown"), 
 		   POLYXMASS_MEDI_MSG_TIMEOUT);
 
 		g_free (help);
@@ -846,8 +846,8 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 		
 		if (FALSE == result)
 		  {
-		    help = g_strdup_printf (_("error, the new actform"
-					      " is invalid: %s"),
+		    help = g_strdup_printf (_("The new actform"
+					      " is invalid: '%s'"),
 					    new_text);
 		    
 		    polyxmass_timeoutmsg_message_set 
@@ -870,7 +870,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	      {
 		polyxmass_timeoutmsg_message_set 
 		  ((GtkWindow *) defctxt->definition_wnd,
-		   _("error: remove related code, first"), 
+		   _("Remove related code, first"), 
 		   POLYXMASS_MEDI_MSG_TIMEOUT);
 		
 		g_free (help);
@@ -932,7 +932,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	if (depth != 2)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a cleaverule first"));
+	      g_strdup_printf (_("Select or create a cleaverule first"));
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd, 
@@ -944,13 +944,13 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	    return ;
 	  }
 	
-	/* But first yet, verify that the monomer code is existing 
-	 * in the polymer definition ! This ONLY if the new_text is 
-	 * of non-0 length, because the DTD stipulates that this
-	 * monomer code may be empty if no corresponding actform is
-	 * found. This translates into: "no cleaverule is required,
-	 * but if there it must be complete with monomer code and
-	 * actform".
+	/* But first yet, verify that the monomer code is existing in
+	 * the polymer chemistry definition ! This ONLY if the
+	 * new_text is of non-0 length, because the DTD stipulates
+	 * that this monomer code may be empty if no corresponding
+	 * actform is found. This translates into: "no cleaverule is
+	 * required, but if there it must be complete with monomer
+	 * code and actform".
 	 */
 	if (strlen (new_text) > 0 
 	    &&
@@ -961,7 +961,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	  {
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd, 
-	       _("error: code unknown"), 
+	       _("Code is unknown"), 
 	       POLYXMASS_MEDI_MSG_TIMEOUT);
 	    
 	    return ;
@@ -1005,7 +1005,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	if (depth != 2)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a cleaverule first"));
+	      g_strdup_printf (_("Select or create a cleaverule first"));
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
@@ -1057,7 +1057,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	      {
 		polyxmass_timeoutmsg_message_set 
 		  ((GtkWindow *) defctxt->definition_wnd,
-		   _("error: related code is unknown"), 
+		   _("Related code is unknown"), 
 		   POLYXMASS_MEDI_MSG_TIMEOUT);
 		
 		g_free (help);
@@ -1075,8 +1075,8 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 		
 		if (FALSE == result)
 		  {
-		    help = g_strdup_printf (_("error, the new actform"
-					      " is invalid: %s"),
+		    help = g_strdup_printf (_("The new actform"
+					      " is invalid: '%s'"),
 					    new_text);
 		    
 		    polyxmass_timeoutmsg_message_set 
@@ -1099,7 +1099,7 @@ polyxdef_ui_polchemdef_wnd_cleavespecs_treeview_cell_edited (GtkCellRendererText
 	      {
 		polyxmass_timeoutmsg_message_set 
 		  ((GtkWindow *) defctxt->definition_wnd,
-		   _("error: remove related code, first"), 
+		   _("Remove related code, first"), 
 		   POLYXMASS_MEDI_MSG_TIMEOUT);
 		
 		g_free (help);
@@ -1254,8 +1254,8 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_cls_button (GtkWidget *widget,
       */
       cls = pxmchem_cleavespec_new ();
       
-      pxmchem_cleavespec_set_name (cls, "name here");
-      pxmchem_cleavespec_set_pattern (cls, "pattern here");
+      pxmchem_cleavespec_set_name (cls, _("enter name here"));
+      pxmchem_cleavespec_set_pattern (cls, _("enter pattern here"));
       
       g_ptr_array_add (cleavespecGPA, cls);
 
@@ -1326,7 +1326,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_cls_button (GtkWidget *widget,
       
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) defctxt->definition_wnd, 
-	 _("added new cleavespec;"
+	 _("Added new cleavespec;"
 	   " set its data!"), 
 	 POLYXMASS_LONG_MSG_TIMEOUT); 
       
@@ -1401,8 +1401,8 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_cls_button (GtkWidget *widget,
   */
   cls = pxmchem_cleavespec_new ();
   
-  pxmchem_cleavespec_set_name (cls, "name here!");
-  pxmchem_cleavespec_set_pattern (cls, "pattern here!");
+  pxmchem_cleavespec_set_name (cls, _("enter name here"));
+  pxmchem_cleavespec_set_pattern (cls, _("enter pattern here"));
 
   path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), 
 				  &tree_iter);
@@ -1431,7 +1431,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_cls_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add cleavespec item to array\n"),
+      g_error (_("%s@%d: failed to insert/add cleavespec item to array\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -1508,7 +1508,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_cls_button (GtkWidget *widget,
   
   polyxmass_timeoutmsg_message_set 
     ((GtkWindow *) defctxt->definition_wnd, 
-     _("added new cleavespec;"
+     _("Added new cleavespec;"
        " set its data!"), 
      POLYXMASS_LONG_MSG_TIMEOUT); 
   return;
@@ -1679,7 +1679,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_clr_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add cleaverule to treeview\n"),
+      g_error (_("%s@%d: failed to insert/add cleaverule to treeview\n"),
 	     __FILE__, __LINE__);
     }
 
@@ -1697,10 +1697,10 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_clr_button (GtkWidget *widget,
 
   clr = pxmchem_cleaverule_new ();
 
-  pxmchem_cleaverule_set_left_code (clr, "left code here!");
-  pxmchem_cleaverule_set_left_actform (clr, "left actform here!");
-  pxmchem_cleaverule_set_right_code (clr, "right code here!");
-  pxmchem_cleaverule_set_right_actform (clr, "right actform here!");
+  pxmchem_cleaverule_set_left_code (clr, _("enter left code here"));
+  pxmchem_cleaverule_set_left_actform (clr, _("enter left actform here"));
+  pxmchem_cleaverule_set_right_code (clr, _("enter right code here"));
+  pxmchem_cleaverule_set_right_actform (clr, _("enter right actform here"));
 
   /* But where do we have to put that stuff in cls->clrGPA? If a
      cleaverule was selected (depth == 2) we had determined the
@@ -1756,7 +1756,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_clr_button (GtkWidget *widget,
 	}
       else
 	{
-	  g_error (_("%s@%d: could not insert/add cleaverule to array\n"),
+	  g_error (_("%s@%d: failed to insert/add cleaverule to array\n"),
 		 __FILE__, __LINE__);
 	}
     }
@@ -1826,7 +1826,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_add_clr_button (GtkWidget *widget,
   
   polyxmass_timeoutmsg_message_set 
     ((GtkWindow *) defctxt->definition_wnd, 
-     _("added new cleaverule;"
+     _("Added new cleaverule;"
        " set its data!"), 
      POLYXMASS_LONG_MSG_TIMEOUT); 
   return;
@@ -1956,7 +1956,7 @@ polyxdef_ui_polchemdef_wnd_cleavespec_remove_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not remove item from treeview\n"),
+      g_error (_("%s@%d: failed to remove item from treeview\n"),
 	     __FILE__, __LINE__);
     }
 
