@@ -56,7 +56,7 @@ polyxdef_ui_polchemdef_wnd_setup_fragspecs_notebook_page (PxmDefCtxt *defctxt,
   if (FALSE == 
       polyxdef_ui_polchemdef_wnd_setup_fragspecs_treeview (defctxt))
     {
-      g_critical (_("%s@%d: failed setting up the fragspecs' treeview\n"),
+      g_critical (_("%s@%d: failed to set up the fragspecs' treeview\n"),
 	     __FILE__, __LINE__);
       
       return FALSE;
@@ -588,7 +588,7 @@ polyxdef_ui_polchemdef_wnd_create_fragspecs_treeview_model (GPtrArray *fragspecG
       else if (fgs->end == PXM_FRAG_END_NONE)
 	help = g_strdup ("NE");
       else
-	g_critical (_("%s@%d: fragspec has a bad end.\n"),
+	g_critical (_("%s@%d: incorrect fragspec 'end' member\n"),
 	       __FILE__, __LINE__);
 
       gtk_tree_store_set 
@@ -712,7 +712,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	if (depth > 1)
 	  {
 	    help = 
-	      g_strdup_printf (_("select or create a fragspec first"));
+	      g_strdup_printf (_("Select or create a fragspec first"));
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
@@ -734,8 +734,8 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	
 	if (-1 != result)
 	  {
-	    help = g_strdup_printf (_("error, a fragspec by the same name"
-				      " exists already: %s"),
+	    help = g_strdup_printf (_("A fragspec by the same name"
+				      " exists already: '%s'"),
 				    new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -789,8 +789,8 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	  {
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
-	       _("error, the End should be"
-		 " one of 'LE','RE','NE'"),
+	       _("The 'End' datum must be"
+		 " in: 'LE','RE','NE'"),
 	       POLYXMASS_MEDI_MSG_TIMEOUT);
 	   
 	    return ;
@@ -850,8 +850,8 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	
 	if (FALSE == result)
 	  {
-	    help = g_strdup_printf (_("error, the new actform"
-				      " is invalid: %s"),
+	    help = g_strdup_printf (_("The new actform"
+				      " is invalid: '%s'"),
 				    new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -951,8 +951,8 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	
 	if (-1 != result)
 	  {
-	    help = g_strdup_printf (_("error, a fragrule by the same name"
-				      " exists already: %s"),
+	    help = g_strdup_printf (_("A fragrule by the same name"
+				      " exists already: '%s'"),
 				    new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -1001,7 +1001,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	  }
 	
 	/* But first yet, verify that the monomer code is existing in
-	 * the polymer definition ! The DTD stipulates that the
+	 * the polymer chemistry definition ! The DTD stipulates that the
 	 * monomer code for PREV, like for THIS and NEXT may be empty!
 	 */
 	if (strlen (new_text) > 0 
@@ -1013,7 +1013,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd, 
-	       _("error: code unknown"), 
+	       _("Code unknown"), 
 	       POLYXMASS_MEDI_MSG_TIMEOUT);
 	    return ;
 	  }
@@ -1058,7 +1058,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	  }
 	
 	/* But first yet, verify that the monomer code is existing in
-	 * the polymer definition ! The DTD stipulates that the
+	 * the polymer chemistry definition ! The DTD stipulates that the
 	 * monomer code for PREV, like for THIS and NEXT may be empty!
 	 */
 	if (strlen (new_text) > 0 
@@ -1070,7 +1070,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
-	       _("error: code unknown"), 
+	       _("Code unknown"), 
 	       POLYXMASS_MEDI_MSG_TIMEOUT);
 	    return ;
 	  }
@@ -1115,7 +1115,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	  }
 	
 	/* But first yet, verify that the monomer code is existing in
-	 * the polymer definition ! The DTD stipulates that the
+	 * the polymer chemistry definition ! The DTD stipulates that the
 	 * monomer code for PREV, like for THIS and NEXT may be empty!
 	 */
 	if (strlen (new_text) > 0 
@@ -1127,7 +1127,7 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 	    
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
-	       _("error: code unknown"), 
+	       _("Code unknown"), 
 	       POLYXMASS_MEDI_MSG_TIMEOUT);
 	    return ;
 	  }
@@ -1176,8 +1176,8 @@ polyxdef_ui_polchemdef_wnd_fragspecs_cell_edited (GtkCellRendererText *cell,
 
 	if (FALSE == result)
 	  {
-	    help = g_strdup_printf (_("error, the new actform"
-				      " is invalid: %s"),
+	    help = g_strdup_printf (_("The new actform"
+				      " is invalid: '%s'"),
 				    new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -1358,10 +1358,10 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgs_button (GtkWidget *widget,
        */
       fgs = pxmchem_fragspec_new ();
       
-      pxmchem_fragspec_set_name (fgs, "name here");
+      pxmchem_fragspec_set_name (fgs, _("enter name here"));
       pxmchem_fragspec_set_end (fgs, PXM_FRAG_END_NONE);
-      pxmchem_fragspec_set_actform (fgs, "actform here");
-      pxmchem_fragspec_set_comment (fgs, "comment here");
+      pxmchem_fragspec_set_actform (fgs, _("enter actform here"));
+      pxmchem_fragspec_set_comment (fgs, _("enter comment here"));
       
       g_ptr_array_add (fragspecGPA, fgs);
 
@@ -1436,7 +1436,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgs_button (GtkWidget *widget,
       
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) defctxt->definition_wnd,
-	 _("added new fragspec;"
+	 _("Added new fragspec;"
 	   " set its data!"), 
 	 POLYXMASS_LONG_MSG_TIMEOUT); 
       return;
@@ -1509,10 +1509,10 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgs_button (GtkWidget *widget,
   */
   fgs = pxmchem_fragspec_new ();
   
-  pxmchem_fragspec_set_name (fgs, "name here");
+  pxmchem_fragspec_set_name (fgs, _("enter name here"));
   pxmchem_fragspec_set_end (fgs, PXM_FRAG_END_NONE);
-  pxmchem_fragspec_set_actform (fgs, "actform here");
-  pxmchem_fragspec_set_comment (fgs, "comment here");
+  pxmchem_fragspec_set_actform (fgs, _("enter actform here"));
+  pxmchem_fragspec_set_comment (fgs, _("enter comment here"));
 
   path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), 
 				  &tree_iter);
@@ -1541,7 +1541,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgs_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add fragspec item to array\n"),
+      g_error (_("%s@%d: failed to insert/add fragspec item to array\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -1623,7 +1623,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgs_button (GtkWidget *widget,
   
   polyxmass_timeoutmsg_message_set 
     ((GtkWindow *) defctxt->definition_wnd,
-     _("added new fragspec;"
+     _("Added new fragspec;"
        " set its data!"), 
      POLYXMASS_LONG_MSG_TIMEOUT); 
   return;
@@ -1792,7 +1792,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgr_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add fragrule to treeview\n"),
+      g_error (_("%s@%d: failed to insert/add fragrule to treeview\n"),
 	     __FILE__, __LINE__);
     }
 
@@ -1810,12 +1810,12 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgr_button (GtkWidget *widget,
 
   fgr = pxmchem_fragrule_new ();
 
-  pxmchem_fragrule_set_name (fgr, "name here!");
-  pxmchem_fragrule_set_prev (fgr, "prev here!");
-  pxmchem_fragrule_set_this (fgr, "this here!");
-  pxmchem_fragrule_set_next (fgr, "next here!");
-  pxmchem_fragrule_set_actform (fgr, "actform here!");
-  pxmchem_fragrule_set_comment (fgr, "comment here!");
+  pxmchem_fragrule_set_name (fgr, _("enter name here"));
+  pxmchem_fragrule_set_prev (fgr, _("enter prev here"));
+  pxmchem_fragrule_set_this (fgr, _("enter this here"));
+  pxmchem_fragrule_set_next (fgr, _("enter next here"));
+  pxmchem_fragrule_set_actform (fgr, _("enter actform here"));
+  pxmchem_fragrule_set_comment (fgr, _("enter comment here"));
 
   /* But where do we have to put that stuff in fgs->fgrGPA? If a
      fragrule was selected (depth == 2) we had determined the idx_fgr
@@ -1871,7 +1871,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgr_button (GtkWidget *widget,
 	}
       else
 	{
-	  g_error (_("%s@%d: could not insert/add fragrule to array\n"),
+	  g_error (_("%s@%d: failed to insert/add fragrule to array\n"),
 		 __FILE__, __LINE__);
 	}
     }
@@ -1945,7 +1945,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_add_fgr_button (GtkWidget *widget,
   
   polyxmass_timeoutmsg_message_set 
     ((GtkWindow *) defctxt->definition_wnd, 
-     _("added new fragrule;"
+     _("Added new fragrule;"
        " set its data!"), 
      POLYXMASS_LONG_MSG_TIMEOUT); 
   return;
@@ -2078,7 +2078,7 @@ polyxdef_ui_polchemdef_wnd_fragspec_remove_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not remove item from treeview\n"),
+      g_error (_("%s@%d: failed to remove item from treeview\n"),
 	     __FILE__, __LINE__);
     }
 
