@@ -55,14 +55,14 @@ polyxdef_ui_polchemdef_wnd_setup_monomers_notebook_page (PxmDefCtxt *defctxt,
   if (FALSE == 
       polyxdef_ui_polchemdef_wnd_setup_monomers_treeview (defctxt))
     {
-      g_critical (_("%s@%d: failed setting up the monomers' treeview\n"),
+      g_critical (_("%s@%d: failed to set up the monomers' treeview\n"),
 	     __FILE__, __LINE__);
       
       return FALSE;
     }
   
-  /* Each polymer definition knows how may authorized letters it
-   * can handle to describe a monomer code.
+  /* Each polymer chemistry definition knows how may authorized
+   * letters it can handle to describe a monomer code.
    */
   widget = glade_xml_get_widget (xml, "monomers_codelen_spinbutton");
   g_object_set_data (G_OBJECT (defctxt->definition_wnd),
@@ -316,6 +316,8 @@ polyxdef_ui_polchemdef_wnd_monomers_treeview_cell_edited (GtkCellRendererText *c
   gint *column;
   gint idx;
   
+  gsize size = 0;
+  
   gint result = 0;
   gint codelen = -1;
   
@@ -356,8 +358,8 @@ polyxdef_ui_polchemdef_wnd_monomers_treeview_cell_edited (GtkCellRendererText *c
 
 	if (-1 != result)
 	  {
-	    help = g_strdup_printf (_("error, a monomer by the same name"
-				      " exists already: %s"),
+	    help = g_strdup_printf (_("A monomer by the same name"
+				      " exists already: '%s'"),
 				    new_text);
 	    
 	    polyxmass_timeoutmsg_message_set 
@@ -395,20 +397,23 @@ polyxdef_ui_polchemdef_wnd_monomers_treeview_cell_edited (GtkCellRendererText *c
 
     case COLUMN_MNM_CODE:
       {
-	/* Before proceeding and accepting the new text, we should 
+	/* Before proceeding and accepting the new text, we should
 	 * make sure that no other monomer already exists by the same
 	 * code. But first yet, verify that the length of the new code
-	 * is not greater than authorized for _this_ polymer definition.
+	 * is not greater than authorized for _this_ polymer chemistry
+	 * definition.
 	 */
-	codelen = strlen ((gchar *) new_text);
-	
+	size = strlen ((gchar *) new_text);
+	g_assert (size < G_MAXINT) ;
+	codelen = (gint) size ;
+
 	if (codelen > defctxt->polchemdef->codelen)
 	  {
 	    gdk_beep ();
 
 	    polyxmass_timeoutmsg_message_set 
 	      ((GtkWindow *) defctxt->definition_wnd,
-					      _("error: code too long"), 
+					      _("Code too long"), 
 					      POLYXMASS_MEDI_MSG_TIMEOUT);
 	    return ;
 	  }
@@ -418,8 +423,8 @@ polyxdef_ui_polchemdef_wnd_monomers_treeview_cell_edited (GtkCellRendererText *c
 	
 	if (-1 != result)
 	  {
-	    help = g_strdup_printf (_("error, a monomer by the same code"
-				      " exists already: %s"),
+	    help = g_strdup_printf (_("A monomer by the same code"
+				      " exists already: '%s'"),
 				    new_text);
 	        
 	    polyxmass_timeoutmsg_message_set 
@@ -477,8 +482,8 @@ polyxdef_ui_polchemdef_wnd_monomers_treeview_cell_edited (GtkCellRendererText *c
 	
 	if (FALSE == (gboolean) result)
 	  {
-	    help = g_strdup_printf (_("error, the new formula"
-				      " is invalid: %s"),
+	    help = g_strdup_printf (_("The new formula"
+				      " is invalid: '%s'"),
 				    new_text);
 
 	    polyxmass_timeoutmsg_message_set 
@@ -546,7 +551,7 @@ polyxdef_ui_polchemdef_wnd_monomer_codelen_value_changed  (GtkSpinButton *
     {
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) defctxt->definition_wnd, 
-	 _("the code length must be > 0"), 
+	 _("The code length must be > 0"), 
 	 POLYXMASS_MEDI_MSG_TIMEOUT); 
       return ;
     }
@@ -558,7 +563,7 @@ polyxdef_ui_polchemdef_wnd_monomer_codelen_value_changed  (GtkSpinButton *
       defctxt->is_modified = TRUE;
       polyxdef_ui_polchemdef_wnd_update_status_label (defctxt);
 
-      help = g_strdup_printf (_("new code length: %d"), 
+      help = g_strdup_printf (_("New code length: '%d'"), 
 			      defctxt->polchemdef->codelen);
       
       polyxmass_timeoutmsg_message_set 
@@ -671,9 +676,9 @@ polyxdef_ui_polchemdef_wnd_monomer_add_button (GtkWidget *widget,
    */
   monomer = pxmchem_monomer_new ();
   
-  monomer->name = g_strdup ("name here");
-  monomer->code = g_strdup ("code here");
-  monomer->formula = g_strdup ("formula here");
+  monomer->name = g_strdup (_("enter name here"));
+  monomer->code = g_strdup (_("enter code here"));
+  monomer->formula = g_strdup (_("enter formula here"));
 
   if (idx_mnm + 1 >= monomerGPA->len)
     {
@@ -692,7 +697,7 @@ polyxdef_ui_polchemdef_wnd_monomer_add_button (GtkWidget *widget,
     }
   else
     {
-      g_error (_("%s@%d: could not insert/add monomer item to array\n"),
+      g_error (_("%s@%d: failed to insert/add monomer item to array\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -740,7 +745,7 @@ polyxdef_ui_polchemdef_wnd_monomer_add_button (GtkWidget *widget,
   gtk_tree_path_free (path);
   
   polyxmass_timeoutmsg_message_set ((GtkWindow *) defctxt->definition_wnd,
-				    _("added new monomer; set its data!"), 
+				    _("Added new monomer; set its data!"), 
 				    POLYXMASS_LONG_MSG_TIMEOUT); 
 
   return;
@@ -805,7 +810,7 @@ polyxdef_ui_polchemdef_wnd_monomer_remove_button (GtkWidget *widget,
       monomer = g_ptr_array_remove_index (monomerGPA, idx);
       g_assert (monomer != NULL);
       
-      help = g_strdup_printf (_("removed monomer '%s'"), monomer->name);
+      help = g_strdup_printf (_("Removed monomer: '%s'"), monomer->name);
       
       pxmchem_monomer_free (monomer);
       
