@@ -73,8 +73,8 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
 
   g_assert (defctxt->polchemdef->atomGPA != NULL);
   
-  /* Create the window into which a polymer definition is going to 
-   * be handled, be it new or loaded from an xml file.
+  /* Create the window into which a polymer chemistry definition is
+   * going to be handled, be it new or loaded from an xml file.
    */  
   gui_file = 
     g_strdup_printf ("%s/polyxdef.glade", userspec->gladedir);
@@ -87,7 +87,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
 
   if (xml == NULL)
     {
-      g_critical (_("%s@%d: failed loading the interface\n"),
+      g_critical (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -98,7 +98,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
   
   if (defctxt->definition_wnd == NULL)
     {
-      g_critical (_("%s@%d: failed creating the polymer chemistry "
+      g_critical (_("%s@%d: failed to create the polymer chemistry "
 	       "definition window\n"),
 	     __FILE__, __LINE__);
 
@@ -185,7 +185,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
 
 
   /* The combo/entry where the user will select the atom definition
-     suitable for use with the polymer definition.
+     suitable for use with the polymer chemistry definition.
   */
   widget = glade_xml_get_widget (xml, "atom_def_vbox");
   g_object_set_data (G_OBJECT (defctxt->definition_wnd),
@@ -193,7 +193,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
 
   if (-1 == 
       polyxdef_ui_polchemdef_wnd_fill_atom_defs_combo_list (defctxt))
-    g_critical (_("%s@%d: failed setting the atom definitions to combo list\n"),
+    g_critical (_("%s@%d: failed to set the atom definitions to combo list\n"),
 	   __FILE__, __LINE__);
   
 
@@ -204,20 +204,21 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
      combobox of available atom definitions.
 
      Note, however, that if the definition_wnd was setup for a new
-     polymer definition (through New menu item in the main program
-     window, then, of course, the polymer definition pointed to by
-     defctxt->polchemdef is totally incomplete... the user just wants
-     to start defining it. In this case, it makes no sense to try to
-     find the proper atom definition with respect to the current
-     defctxt->polchemdef->type... Thus we skip that search.
+     polymer chemistry definition (through New menu item in the main
+     program window, then, of course, the polymer chemistry definition
+     pointed to by defctxt->polchemdef is totally incomplete... the
+     user just wants to start defining it. In this case, it makes no
+     sense to try to find the proper atom definition with respect to
+     the current defctxt->polchemdef->type... Thus we skip that
+     search.
   */
   if (defctxt->polchemdef->type != NULL)
     {
       if (FALSE == 
 	  polyxdef_ui_polchemdef_wnd_set_atomdef_name_to_combo_list (defctxt))
 	{
-	  g_critical (_("%s@%d: failed setting the proper atom definition name "
-		   "for current polymer definition to combo list\n"),
+	  g_critical (_("%s@%d: failed to set the proper atom definition name "
+		   "for current polymer chemistry definition to combo list\n"),
 		 __FILE__, __LINE__);
 	  
 	  return NULL;
@@ -240,7 +241,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
 	  polyxdef_ui_polchemdef_wnd_atom_definition_read_button (NULL, 
 								  defctxt))
 	{
-	  g_critical (_("%s@%d: Failed reading the atom definition file\n"),
+	  g_critical (_("%s@%d: failed to read the atom definition file\n"),
 		 __FILE__, __LINE__);
 	  
 	  return NULL;
@@ -328,7 +329,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
       polyxdef_ui_polchemdef_wnd_setup_monomers_notebook_page (defctxt,
 							       xml))
     {
-      g_critical (_("%s@%d: failed setting up the monomers' notebook page.\n"),
+      g_critical (_("%s@%d: failed to set up the monomers' tab.\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -341,7 +342,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
       polyxdef_ui_polchemdef_wnd_setup_modifs_notebook_page (defctxt,
 							     xml))
     {
-      g_critical (_("%s@%d: failed setting up the modifs' notebook page.\n"),
+      g_critical (_("%s@%d: failed to set up the modifs' tab.\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -356,7 +357,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
       polyxdef_ui_polchemdef_wnd_setup_cleavespecs_notebook_page (defctxt,
 								  xml))
     {
-      g_critical (_("%s@%d: failed setting up the cleavespecs' notebook page.\n"),
+      g_critical (_("%s@%d: failed to set up the cleavespecs' tab.\n"),
 	     __FILE__, __LINE__);
       
       return NULL;
@@ -370,7 +371,7 @@ polyxdef_ui_polchemdef_wnd_setup_window (PxmDefCtxt *defctxt)
       polyxdef_ui_polchemdef_wnd_setup_fragspecs_notebook_page (defctxt,
 								xml))
     {
-      g_critical (_("%s@%d: failed setting up the fragspecs' notebook page.\n"),
+      g_critical (_("%s@%d: failed to set up the fragspecs' tab.\n"),
 	     __FILE__, __LINE__);
       
       return NULL;
@@ -666,12 +667,13 @@ polyxdef_ui_polchemdef_wnd_set_atomdef_name_to_combo_list (PxmDefCtxt *defctxt)
     
 
   /* The window passed as parameter contains has a pointer to its
-     polymer definition window, "polchemdef". We want to get the type of
-     that polymer so that we can find the proper atom definition for
-     it as described in the dictionary of equivalences between polymer
-     definitions and atom definition names... Once we have found the
-     proper atom definition name, we can set the corresponding item in
-     the combo box and thus the corresponding file name in the entry.
+     polymer chemistry definition window, "polchemdef". We want to get
+     the type of that polymer so that we can find the proper atom
+     definition for it as described in the dictionary of equivalences
+     between polymer definitions and atom definition names... Once we
+     have found the proper atom definition name, we can set the
+     corresponding item in the combo box and thus the corresponding
+     file name in the entry.
   */
   g_assert (defctxt != NULL);
   g_assert (defctxt->definition_wnd != NULL);
@@ -766,7 +768,7 @@ polyxdef_ui_polchemdef_wnd_atom_definition_read_button (GtkWidget *widget,
     {
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) defctxt->definition_wnd,
-	 _("Reading of the atom definition file: FAILURE"),
+	 _("Failed to read the atom definition file"),
 	 POLYXMASS_LONG_MSG_TIMEOUT);
 
       g_free (filename);
@@ -779,8 +781,8 @@ polyxdef_ui_polchemdef_wnd_atom_definition_read_button (GtkWidget *widget,
      is OK.
   */
   message = 
-    g_strdup_printf (_("Reading of the atom definition file: SUCCESS; " 
-		       "%d atoms parsed"), 
+    g_strdup_printf (_("Succeeded to read the atom definition file; " 
+		       "Atoms parsed: '%d'"), 
 		     defctxt->polchemdef->atomGPA->len);
   
   polyxmass_timeoutmsg_message_set 
@@ -813,7 +815,7 @@ polyxdef_ui_polchemdef_wnd_atom_definition_locate_button (GtkWidget *widget,
      GtkFileChooser dialog.
    */
 
-  dialog = gtk_file_chooser_dialog_new ("Find Atom Definition File",
+  dialog = gtk_file_chooser_dialog_new (_("Find Atom Definition File"),
 					GTK_WINDOW (defctxt->definition_wnd),
 					GTK_FILE_CHOOSER_ACTION_OPEN,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -869,9 +871,9 @@ polyxdef_ui_polchemdef_wnd_polchemdef_check_syntax_button (GtkWidget *widget,
   g_assert (defctxt != NULL);
   g_assert (defctxt->definition_wnd != NULL);
 
-  /* All we want to do is get the polymer definition out of the window
-   * and next call the validating function. This function returns an
-   * allocated string that we can display later.
+  /* All we want to do is get the polymer chemistry definition out of
+   * the window and next call the validating function. This function
+   * returns an allocated string that we can display later.
    */
     
   /* There are some fieds that need reading manually here:
@@ -949,7 +951,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_check_syntax_button (GtkWidget *widget,
 	  
 	  if (defctxt->syntax_check_wnd == NULL)
 	    {
-	      g_message (_("%s@%d: failed setting up the syntax-checking "
+	      g_message (_("%s@%d: failed to set up the syntax-checking "
 		       "window for the following errors: '%s'\n\n"),
 		     __FILE__, __LINE__, valid);
 	      
@@ -1008,7 +1010,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_save_button (GtkWidget *widget,
   g_assert (defctxt->polchemdef != NULL);
 
   
-  /* We do not save a polymer definition which is not valid.
+  /* We do not save a polymer chemistry definition which is not valid.
    */
   if (FALSE == 
       polyxdef_ui_polchemdef_wnd_polchemdef_check_syntax_button (NULL, 
@@ -1019,8 +1021,8 @@ polyxdef_ui_polchemdef_wnd_polchemdef_save_button (GtkWidget *widget,
   /* Now, if the defctxt->polchemdef->file member is non-NULL, then
      that means that the polchemdef was actually saved at least once
      or was read from a disk file (in other words, it is not
-     "new"). Then we can save the polymer definition to that file
-     immediately. Conversely, we need to get a file name from the
+     "new"). Then we can save the polymer chemistry definition to that
+     file immediately. Conversely, we need to get a file name from the
      user.
   */
   if (defctxt->polchemdef->file == NULL)
@@ -1035,14 +1037,14 @@ polyxdef_ui_polchemdef_wnd_polchemdef_save_button (GtkWidget *widget,
 
   if (filep == NULL)
     {
-      g_critical (_("%s@%d: error with opening file '%s'\n"),
+      g_critical (_("%s@%d: failed to open file: '%s'\n"),
 	     __FILE__, __LINE__, defctxt->polchemdef->file);
       
       return;
     }
   
    /* Construct a string with all the xml-formatted data pertaining to
-      the polymer definition 'polchemdef'.
+      the polymer chemistry definition 'polchemdef'.
    */
   xml = 
     pxmchem_polchemdef_format_xml_string_polchemdefdata (defctxt->polchemdef,
@@ -1059,7 +1061,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_save_button (GtkWidget *widget,
   
   if (result == EOF || result < 0)
     {
-      g_critical (_("%s@%d: error with saving polchemdef to file '%s'\n"),
+      g_critical (_("%s@%d: failed to save polchemdef to file: '%s'\n"),
 	     __FILE__, __LINE__, defctxt->polchemdef->file);
       
       return;
@@ -1095,7 +1097,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
   g_assert (defctxt->definition_wnd != NULL);
 
   
-  /* We do not save a polymer definition which is not valid.
+  /* We do not save a polymer chemistry definition which is not valid.
    */
   if (FALSE == 
       polyxdef_ui_polchemdef_wnd_polchemdef_check_syntax_button (NULL, 
@@ -1104,7 +1106,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
 
 
   dialog = 
-    gtk_file_chooser_dialog_new ("Save Polymer Definition File",
+    gtk_file_chooser_dialog_new (_("Save Polymer Chemistry Definition File"),
 				 GTK_WINDOW (defctxt->definition_wnd),
 				 GTK_FILE_CHOOSER_ACTION_SAVE,
 				 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1140,8 +1142,8 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
       return;
     }
   
-  /* Ok, we have a file to which the polymer definition can be
-     performed.
+  /* Ok, we have a file to which the polymer chemistry definition can
+     be performed.
   */
 
   /* We can destroy the file chooser dialog.
@@ -1154,7 +1156,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
   
   if (filep == NULL)
     {
-      g_critical (_("%s@%d: error with opening file %s\n"),
+      g_critical (_("%s@%d: failed to open file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       g_free (file);
@@ -1162,8 +1164,8 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
       return;
     }
 
-  /* Construct a string with all the xml-formatted data pertaining
-   * to the polymer definition 'polchemdef'.
+  /* Construct a string with all the xml-formatted data pertaining to
+   * the polymer chemistry definition 'polchemdef'.
    */
   xml = 
     pxmchem_polchemdef_format_xml_string_polchemdefdata (defctxt->
@@ -1181,14 +1183,14 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
   
   if (result == EOF || result < 0)
     {
-      g_critical (_("%s@%d: error with saving polchemdef to file '%s'\n"),
+      g_critical (_("%s@%d: failed to save polchemdef to file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       return;
     }
 
-  /* Now that the polymer definition is in a new file, we have to set
-     its member datum to this new file name:
+  /* Now that the polymer chemistry definition is in a new file, we
+     have to set its member datum to this new file name:
    */
   pxmchem_polchemdef_set_file (defctxt->polchemdef, file);
 
@@ -1199,7 +1201,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_saveas_button (GtkWidget *widget,
   /* Now we should change the window title so that it reads the new
      filename.
    */
-  help = g_strdup_printf (_("Polymer Definition: %s"), 
+  help = g_strdup_printf (_("Polymer Chemistry Definition: %s"), 
 			  defctxt->polchemdef->file);
 
   gtk_window_set_title (GTK_WINDOW (defctxt->definition_wnd), help);
@@ -1268,7 +1270,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_wnd_delete_event (GtkWidget *window,
       if (FALSE == g_ptr_array_remove (polyxdef_defctxtGPA, 
 				       defctxt))
 	{
-	  g_critical (_("%s@%d: failed removing context from array.\n"),
+	  g_critical (_("%s@%d: failed to remove context from array.\n"),
 		 __FILE__, __LINE__);
 	}
 
@@ -1280,8 +1282,8 @@ polyxdef_ui_polchemdef_wnd_polchemdef_wnd_delete_event (GtkWidget *window,
   /* The polyxdef context associated with this widget is modified, we
    * should ask if it should be saved before.
    */
-  help = g_strdup_printf ("The polymer chemistry definition of "
-			  "type '%s' is modified, save it?\n",
+  help = g_strdup_printf (_("The polymer chemistry definition of "
+			  "type: '%s' is modified, save it?\n"),
 			  defctxt->polchemdef->type);
   
   dialog = gtk_message_dialog_new (GTK_WINDOW (defctxt->definition_wnd),
@@ -1321,7 +1323,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_wnd_delete_event (GtkWidget *window,
 	  if (FALSE == g_ptr_array_remove (polyxdef_defctxtGPA, 
 					   defctxt))
 	    {
-	      g_critical (_("%s@%d: failed removing context from array.\n"),
+	      g_critical (_("%s@%d: failed to remove context from array.\n"),
 		     __FILE__, __LINE__);
 	    }
 	  
@@ -1341,7 +1343,7 @@ polyxdef_ui_polchemdef_wnd_polchemdef_wnd_delete_event (GtkWidget *window,
       if (FALSE == g_ptr_array_remove (polyxdef_defctxtGPA, 
 				       defctxt))
 	{
-	  g_critical (_("%s@%d: failed removing context from array.\n"),
+	  g_critical (_("%s@%d: failed to remove context from array.\n"),
 		 __FILE__, __LINE__);
 	}
       
