@@ -29,7 +29,7 @@
 */
 #include "polyxedit-acidobasic.h"
 #include "polyxedit-ui-pka-ph-pi.h"
-
+#include "polyxmass-window-mngmt.h"
 
 
 gboolean
@@ -42,10 +42,11 @@ polyxedit_acidobasic_setup_framework (PxmEditCtxt *editctxt)
   
 
   g_assert (editctxt != NULL);
+  g_assert (editctxt->seqeditorctxt->sequence_editor_wnd != NULL);
 
 
   /*
-    We are asked to perform an acido-basic computation for a given
+    We are asked to perform an acido-basic calculation for a given
     editctxt. We first have to ensure that acido-basic data have been
     already read from the xml file, otherwise we must first ensure
     that we do this.
@@ -77,7 +78,7 @@ polyxedit_acidobasic_setup_framework (PxmEditCtxt *editctxt)
       */
       if (FALSE == polyxedit_acidobasic_reload_data (editctxt))
 	{
-	  g_critical (_("%s@%d: failed reloading the acido-basic "
+	  g_critical (_("%s@%d: failed to reload the acido-basicity "
 		   "data from xml file\n"),
 		 __FILE__, __LINE__);
 	  
@@ -86,7 +87,7 @@ polyxedit_acidobasic_setup_framework (PxmEditCtxt *editctxt)
     }
   
   /* 
-     At this point, we have the acido-basic data in their respective
+     At this point, we have the acido-basicity data in their respective
      arrays of monomers/modifications, we can go on with the setting
      up of the GUI window.
   */
@@ -95,13 +96,28 @@ polyxedit_acidobasic_setup_framework (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed setting up the window for acido-basic"
-	       "computations\n"),
+      g_critical (_("%s@%d: failed to set up the window for acido-basicity"
+	       " calculations\n"),
 	     __FILE__, __LINE__);
       
       return FALSE;
     }
 
+  /* Register this results' window !
+   */
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXEDIT",
+       window,
+       editctxt->seqeditorctxt->sequence_editor_wnd,
+       editctxt,
+       _("Results of pH-pI-pKa Calculations"),
+       NULL,
+       TRUE,
+       polyxedit_pka_ph_pi_wnd_make_report))
+    g_critical (_("%s@%d: failed to register the acido-basicity calculation"
+		  " results' window\n"),
+		__FILE__, __LINE__);
+
   return TRUE;
 }
 
@@ -185,7 +201,7 @@ polyxedit_acidobasic_reload_data (PxmEditCtxt *editctxt)
 					       (GPtrArray *) prop_mdf->data,
 					       NULL))
     {
-      g_critical (_("%s@%d: failed reloading the acido-basic "
+      g_critical (_("%s@%d: failed to reload the acido-basicity "
 		   "data from xml file\n"),
 	     __FILE__, __LINE__);
 
@@ -270,7 +286,7 @@ polyxedit_acidobasic_get_modif (gchar *name, PxmEditCtxt *editctxt)
    function should continue processing as we return. Return 0 if we
    had not processed the chemgroup but it was dealt with (as it was
    eligible for left_end modification accounting). Return > 0 to tell
-   the calling function how many charge computations were performed.
+   the calling function how many charge calculations were performed.
 */
 gint
 polyxedit_acidobasic_chemgroup_account_plm_end_modif (PxmChemgroup *chemgroup,
@@ -353,12 +369,12 @@ polyxedit_acidobasic_chemgroup_account_plm_end_modif (PxmChemgroup *chemgroup,
 	 actually a chemgroup suitable for a right_end modif.  If this
 	 chemgroup was actually suitable for a right_end modif, but it
 	 is not effectively modified, that means that we have to
-	 compute the charge for the non-modified chemgroup...
+	 calculate the charge for the non-modified chemgroup...
       */
       if (cgr != NULL)
 	{
 	  charge = 
-	    libpolyxmass_acidobasic_compute_charge_ratio 
+	    libpolyxmass_acidobasic_calculate_charge_ratio 
 	    (chemgroup->pka, ph, chemgroup->acidcharged);
 	  
 	  /*
@@ -430,7 +446,7 @@ polyxedit_acidobasic_chemgroup_account_plm_end_modif (PxmChemgroup *chemgroup,
 	group could bring to the polymer/oligomer.
       */
       charge = 
-	libpolyxmass_acidobasic_compute_charge_ratio 
+	libpolyxmass_acidobasic_calculate_charge_ratio 
 	(chemgroup->pka, ph, chemgroup->acidcharged);
 	  
       /*
@@ -458,7 +474,7 @@ polyxedit_acidobasic_chemgroup_account_plm_end_modif (PxmChemgroup *chemgroup,
 
   /* Whatever we should do with the left/right end monomer's
      chemgroup, we should take into account the modification itself
-     that might have brought chemgroup(s) worth computing their
+     that might have brought chemgroup(s) worth calculating their
      intrinsic charges!
      
      Find a modif object in the special acidobasic array of modif
@@ -484,7 +500,7 @@ polyxedit_acidobasic_chemgroup_account_plm_end_modif (PxmChemgroup *chemgroup,
 	  g_assert (chemgroup_mdf != NULL);
 			  
 	  charge = 
-	    libpolyxmass_acidobasic_compute_charge_ratio (chemgroup_mdf->
+	    libpolyxmass_acidobasic_calculate_charge_ratio (chemgroup_mdf->
 							  pka, ph, 
 							  chemgroup_mdf->
 							  acidcharged);
@@ -575,13 +591,13 @@ polyxedit_acidobasic_chemgroup_account_monomer_modif (PxmMonomer *monomer,
 	 have to make sure that the chemgroup that we were parsing is
 	 actually a chemgroup suitable for a modif.  If this chemgroup
 	 was actually suitable for a monomer modif, but it is not
-	 effectively modified, that means that we have to compute the
+	 effectively modified, that means that we have to calculate the
 	 charge for the non-modified chemgroup...
       */
       if (cgr != NULL)
 	{
 	  charge = 
-	    libpolyxmass_acidobasic_compute_charge_ratio 
+	    libpolyxmass_acidobasic_calculate_charge_ratio 
 	    (chemgroup->pka, ph, chemgroup->acidcharged);
 	  
 	  /*
@@ -652,7 +668,7 @@ polyxedit_acidobasic_chemgroup_account_monomer_modif (PxmMonomer *monomer,
 	group could bring to the polymer/oligomer.
       */
       charge = 
-	libpolyxmass_acidobasic_compute_charge_ratio 
+	libpolyxmass_acidobasic_calculate_charge_ratio 
 	(chemgroup->pka, ph, chemgroup->acidcharged);
 	  
       /*
@@ -680,7 +696,7 @@ polyxedit_acidobasic_chemgroup_account_monomer_modif (PxmMonomer *monomer,
 
   /* Whatever we should do with this monomer's chemgroup, we should
      take into account the modification itself that might have brought
-     chemgroup(s) worth computing their intrinsic charges!
+     chemgroup(s) worth calculating their intrinsic charges!
      
      Find a modif object in the special acidobasic array of modif
      objects, that has the same name as the modification with which
@@ -705,7 +721,7 @@ polyxedit_acidobasic_chemgroup_account_monomer_modif (PxmMonomer *monomer,
 	  g_assert (chemgroup_mdf != NULL);
 			  
 	  charge = 
-	    libpolyxmass_acidobasic_compute_charge_ratio (chemgroup_mdf->
+	    libpolyxmass_acidobasic_calculate_charge_ratio (chemgroup_mdf->
 							  pka, ph, 
 							  chemgroup_mdf->
 							  acidcharged);
@@ -740,7 +756,7 @@ polyxedit_acidobasic_chemgroup_account_monomer_modif (PxmMonomer *monomer,
 
 
 gint
-polyxedit_acidobasic_polseq_compute_net_charge (PxmEditCtxt *editctxt,
+polyxedit_acidobasic_polseq_calculate_net_charge (PxmEditCtxt *editctxt,
 						gdouble ph,
 						PxmCalcOpt *calcopt,
 						gdouble *negative_charges,
@@ -814,7 +830,7 @@ polyxedit_acidobasic_polseq_compute_net_charge (PxmEditCtxt *editctxt,
       
       if (monomer_cg == NULL)
 	{
-	  g_error (_("%s@%d: Found no corresponding monomer for code '%s'"
+	  g_error (_("%s@%d: failed to find a monomer of code: '%s'"
 	       " in the array of chemgroup-containing monomers\n"),
 	     __FILE__, __LINE__, monomer_seq->code);
 	  
@@ -899,7 +915,7 @@ polyxedit_acidobasic_polseq_compute_net_charge (PxmEditCtxt *editctxt,
 
 	      if (result >= 0)
 		{
-		  /* Evidently the computation was performed OK, which
+		  /* Evidently the calculation was performed OK, which
 		     means that we can continue to the next chemgroup
 		     as the current one has been dealt with.
 		  */
@@ -930,7 +946,7 @@ polyxedit_acidobasic_polseq_compute_net_charge (PxmEditCtxt *editctxt,
 
 	      if (result >= 0)
 		{
-		  /* Evidently the computation was performed OK, which
+		  /* Evidently the calculation was performed OK, which
 		     means that we can continue to the next chemgroup
 		     as the current one has been dealt with.
 		  */
@@ -970,7 +986,7 @@ polyxedit_acidobasic_polseq_compute_net_charge (PxmEditCtxt *editctxt,
 
 		  if (result >= 0)
 		    {
-		      /* Evidently the computation was performed OK, which
+		      /* Evidently the calculation was performed OK, which
 			 means that we can continue to the next chemgroup
 			 as the current one has been dealt with.
 		      */
@@ -989,7 +1005,7 @@ polyxedit_acidobasic_polseq_compute_net_charge (PxmEditCtxt *editctxt,
 	     not been taken into account before.
 	  */
 	  charge = 
-	    libpolyxmass_acidobasic_compute_charge_ratio 
+	    libpolyxmass_acidobasic_calculate_charge_ratio 
 	    (chemgroup_mnm->pka, ph, chemgroup_mnm->acidcharged);
       
 	  /*
