@@ -80,7 +80,7 @@ polyxedit_monomer_modif_modify_monomer (PxmMonomer *mnm,
    */
   if (-1 == pxmchem_modif_get_index_by_name (modif, polchemdef->modifGPA))
     {
-      g_critical (_("%s@%d: modif '%s' is not known to the polchemdef\n"),
+      g_critical (_("%s@%d: modif is not known to the polchemdef: '%s'\n"),
 	     __FILE__, __LINE__, modif);
       
       return MODIF_CHEM_N_RENDER_N;
@@ -92,8 +92,8 @@ polyxedit_monomer_modif_modify_monomer (PxmMonomer *mnm,
   */
   if (FALSE == pxmchem_monomer_modify (monomer, modif))
     {
-      g_critical (_("%s@%d: failed modifying monomer at index '%d' "
-	       "with modif '%s'\n"),
+      g_critical (_("%s@%d: failed to modify monomer at index: '%d' "
+	       "with modif: '%s'\n"),
 	     __FILE__, __LINE__, idx, modif);
       
       return MODIF_CHEM_N_RENDER_N;
@@ -116,8 +116,8 @@ polyxedit_monomer_modif_modify_monomer (PxmMonomer *mnm,
   
   if (pixbuf == NULL)
     {
-      g_critical (_("%s@%d: failed rendering monicon for monomer '%s' "
-	       "at index '%d' with modif '%s'. Chemical modification "
+      g_critical (_("%s@%d: failed to render monicon for monomer: '%s' "
+	       "at index: '%d' with modif: '%s'. Chemical modification "
 	       "was performed ok, however.\n"),
 	     __FILE__, __LINE__, monomer->code, idx, modif);
 	  
@@ -140,8 +140,8 @@ polyxedit_monomer_modif_modify_monomer (PxmMonomer *mnm,
 						    idx,
 						    editctxt))
     {
-      g_critical (_("%s@%d: failed making canvas_item for monomer code '%s' "
-	       "at index '%d', with modif '%s'. Chemical modification "
+      g_critical (_("%s@%d: failed to make canvas_item for monomer code: '%s' "
+	       "at index: '%d', with modif: '%s'. Chemical modification "
 	       "was performed ok, however.\n"),
 	     __FILE__, __LINE__, monomer->code, idx, modif);
 	  
@@ -286,7 +286,7 @@ polyxedit_monomer_modif_modify_monomer_GA (GArray *GA,
 	  if (errors)
 	    g_string_append_printf 
 	      (gs, 
-	       _("pos '%d' - not modified - no visual\n"),
+	       _("pos: '%d' - not modified - no visual\n"),
 	       iter + 1);
 
 	  if (full_failure != NULL)
@@ -298,7 +298,7 @@ polyxedit_monomer_modif_modify_monomer_GA (GArray *GA,
 	  if (errors)
 	    g_string_append_printf 
 	      (gs, 
-	       _("pos '%d' - modified - no visual\n"),
+	       _("pos: '%d' - modified - no visual\n"),
 	       iter + 1);
 	  
 	  if (render_failure != NULL)
@@ -310,7 +310,7 @@ polyxedit_monomer_modif_modify_monomer_GA (GArray *GA,
 	  if (errors)
 	    g_string_append_printf 
 	      (gs, 
-	       _("pos '%d' - not modified - visual\n"),
+	       _("pos: '%d' - not modified - visual\n"),
 	       iter + 1);
 	  
 	  if (chem_failure != NULL)
@@ -389,7 +389,7 @@ polyxedit_monomer_modif_un_modify_monomer (PxmMonomer *mnm,
   if (modif != NULL && 
       -1 == pxmchem_modif_get_index_by_name (modif, polchemdef->modifGPA))
     {
-      g_critical (_("%s@%d: modif '%s' is not known to the polchemdef\n"),
+      g_critical (_("%s@%d: modif is not known to the polchemdef: '%s'\n"),
 	     __FILE__, __LINE__, modif);
       
       return MODIF_CHEM_N_RENDER_N;
@@ -408,15 +408,15 @@ polyxedit_monomer_modif_un_modify_monomer (PxmMonomer *mnm,
     {
       if (modif != NULL)
 	{
-	  g_critical (_("%s@%d: failed un-modifying monomer "
-		   "at index '%d' with modif '%s'\n"),
+	  g_critical (_("%s@%d: failed to un-modify monomer "
+		   "at index: '%d' with modif: '%s'\n"),
 		 __FILE__, __LINE__, idx, modif);
 	}
       
       else
 	{
-	  g_critical (_("%s@%d: failed or did not un-modify monomer "
-		   "at index '%d'\n"),
+	  g_critical (_("%s@%d: failed to or did not un-modify monomer "
+		   "at index: '%d'\n"),
 		 __FILE__, __LINE__, idx);
 	}
       
@@ -449,8 +449,8 @@ polyxedit_monomer_modif_un_modify_monomer (PxmMonomer *mnm,
   
   if (pixbuf == NULL)
     {
-      g_critical (_("%s@%d: failed rendering monicon for un-modified "
-	       "monomer '%s' at index '%d'. Chemical un-modification "
+      g_critical (_("%s@%d: failed to render monicon for un-modified "
+	       "monomer: '%s' at index: '%d'. Chemical un-modification "
 	       "was performed ok, however.\n"),
 	     __FILE__, __LINE__, monomer->code, idx);
 	  
@@ -473,9 +473,9 @@ polyxedit_monomer_modif_un_modify_monomer (PxmMonomer *mnm,
 						    idx,
 						    editctxt))
     {
-      g_critical (_("%s@%d: failed making canvas_item for un-modified "
-		    "monomer code '%s' at index '%d'. Chemical "
-		    "un-modification xwas performed ok, however.\n"),
+      g_critical (_("%s@%d: failed to make canvas_item for un-modified "
+		    "monomer, code: '%s' at index: '%d'. Chemical "
+		    "un-modification was performed ok, however.\n"),
 	     __FILE__, __LINE__, monomer->code, idx);
 	  
       /* FIXME: we should handle in a better way the situation here,
@@ -622,7 +622,7 @@ polyxedit_monomer_modif_un_modify_monomer_GA (GArray *GA,
 	  if (errors)
 	    g_string_append_printf 
 	      (gs, 
-	       _("pos '%d' - not un-modified - no visual\n"),
+	       _("pos: '%d' - not un-modified - no visual\n"),
 	       iter + 1);
 
 	  if (full_failure != NULL)
@@ -634,7 +634,7 @@ polyxedit_monomer_modif_un_modify_monomer_GA (GArray *GA,
 	  if (errors)
 	    g_string_append_printf 
 	      (gs, 
-	       _("pos '%d' - un-modified - no visual\n"),
+	       _("pos: '%d' - un-modified - no visual\n"),
 	       iter + 1);
 	  
 	  if (render_failure != NULL)
@@ -646,7 +646,7 @@ polyxedit_monomer_modif_un_modify_monomer_GA (GArray *GA,
 	  if (errors)
 	    g_string_append_printf 
 	      (gs, 
-	       _("pos '%d' - not un-modified - visual\n"),
+	       _("pos: '%d' - not un-modified - visual\n"),
 	       iter + 1);
 	  
 	  if (chem_failure != NULL)
