@@ -103,17 +103,17 @@ polyxedit_rendering_pixbuf_render_no_modif (gchar *code,
       /* As a last resort we should try to render a file that is in
          the distribution: the interrogation mark.
        */
-      g_critical (_("%s@%d: failed rendering a pixbuf for code: '%s'\n"),
+      g_critical (_("%s@%d: failed to render a pixbuf for code: '%s'\n"),
 	     __FILE__, __LINE__, code);
 
       return NULL;
     }
   
   /* At this point we have effectively CREATED ex nihilo the pixbuf
-     that was asked and we thus let the polymer definition context
-     know that we have rendered the pixbuf for the unmodified monomer
-     'code'. Note that for the moment we do not ref this newly created
-     pixbuf, because it was created with a ref_count of 1
+     that was asked and we thus let the polymer chemistry definition
+     context know that we have rendered the pixbuf for the unmodified
+     monomer 'code'. Note that for the moment we do not ref this newly
+     created pixbuf, because it was created with a ref_count of 1
      already. When this function returns the user will know if it is
      to be reffed or not based on what is going to be performed with
      this pixbuf. For example, using the pixbuf to create a
@@ -209,7 +209,7 @@ polyxedit_rendering_pixbuf_render_modif (gchar *code,
   
   if (NULL == mdfspec)
     {
-      g_critical (_("%s@%d: failed getting modif specification "
+      g_critical (_("%s@%d: failed to get modif specification "
 	       "for name: '%s'\n"),
 	     __FILE__, __LINE__, modif);
       	
@@ -228,7 +228,7 @@ polyxedit_rendering_pixbuf_render_modif (gchar *code,
   
   if (NULL == mnmspec)
     {
-      g_critical (_("%s@%d: failed getting monomer specification "
+      g_critical (_("%s@%d: failed to get monomer specification "
 	       "for code: '%s'\n"),
 	     __FILE__, __LINE__, code);
       
@@ -273,7 +273,7 @@ polyxedit_rendering_pixbuf_render_modif (gchar *code,
 	  
 	  if (pixbuf_modif == NULL)
 	    {
-	      g_error (_("%s@%d: failed rendering a modification pixbuf from "
+	      g_error (_("%s@%d: failed to render a modification pixbuf from "
 		       "vector/raster files: '%s'/'%s'\n"),
 		     __FILE__, __LINE__, mdfspec->vector, mdfspec->raster);
 
@@ -299,15 +299,15 @@ polyxedit_rendering_pixbuf_render_modif (gchar *code,
 	}
       
       /* At this point we have effectively CREATED ex nihilo the
-         pixbuf that was asked and we thus let the polymer definition
-         context know that we have rendered the pixbuf for the monomer
-         'code' modified with 'modif'. Note that for the moment we do
-         not ref this newly created pixbuf, because it was created
-         with a ref_count of 1 already. When this function returns the
-         user will know if it is to be reffed or not based on what is
-         going to be performed with this pixbuf. For example, using
-         the pixbuf to create a canvas_item has a side effect of
-         automatically reff the pixbuf that's used.
+         pixbuf that was asked and we thus let the polymer chemistry
+         definition context know that we have rendered the pixbuf for
+         the monomer 'code' modified with 'modif'. Note that for the
+         moment we do not ref this newly created pixbuf, because it
+         was created with a ref_count of 1 already. When this function
+         returns the user will know if it is to be reffed or not based
+         on what is going to be performed with this pixbuf. For
+         example, using the pixbuf to create a canvas_item has a side
+         effect of automatically reff the pixbuf that's used.
        */
       polyxedit_rendering_pixbuf_set_to_data_list (pixbuf_modif, 
 						   code, 
@@ -353,7 +353,7 @@ polyxedit_rendering_pixbuf_render_modif (gchar *code,
 	  /* FIXME: As a last resort we should try to render a file
 	   * that is in the distribution: the interrogation mark.
 	   */
-	  g_error (_("%s@%d: failed rendering a pixbuf for code: '%s'\n"),
+	  g_error (_("%s@%d: failed to render a pixbuf for code: '%s'\n"),
 		 __FILE__, __LINE__, code);
 	  
 	  return NULL;
@@ -440,7 +440,7 @@ polyxedit_rendering_pixbuf_render_modif (gchar *code,
 	  
 	  if (pixbuf_modif == NULL)
 	    {
-	      g_error (_("%s@%d: failed rendering a modification pixbuf from "
+	      g_error (_("%s@%d: failed to render a modification pixbuf from "
 		       "vector/raster files: '%s'/'%s'\n"),
 		     __FILE__, __LINE__, mdfspec->vector, mdfspec->raster);
 	      
@@ -532,7 +532,7 @@ polyxedit_rendering_cursor_monicon_render (PxmEditCtxt *editctxt,
   
   if (pixbuf == NULL)
     {
-      g_error (_("%s@%d: failed rendering pixbuf from vector file: %s\n"),
+      g_error (_("%s@%d: failed to render pixbuf from vector file: '%s'\n"),
 	     __FILE__, __LINE__, file);
       
       g_free (file);
@@ -599,7 +599,7 @@ polyxedit_rendering_pixbuf_get_from_data_list (gchar *code,
        */
 	key = g_strdup_printf ("pxm-raw-modif$%s", modif);
       else
-	g_error (_("%s@%d: both 'code' and 'modif' cannot be NULL or empty\n"),
+	g_error (_("%s@%d: both 'code' and 'modif' cannot be NULL nor empty\n"),
 	       __FILE__, __LINE__);
     }
   
@@ -688,7 +688,7 @@ polyxedit_rendering_pixbuf_make_with_vector (gchar *code,
    */  
   if (NULL == mnmspec->vector)
     {
-      g_message (_("%s@%d: mnmspec->vector is NULL for code '%s'\n"),
+      g_message (_("%s@%d: mnmspec->vector is NULL for code: '%s'\n"),
 	     __FILE__, __LINE__, code);
       
       return NULL;
@@ -696,7 +696,7 @@ polyxedit_rendering_pixbuf_make_with_vector (gchar *code,
   
   if (FALSE == g_file_test (mnmspec->vector, G_FILE_TEST_EXISTS))
     {
-      g_critical (_("%s@%d: mnmspec->vector '%s' does not exist (code: '%s')\n"),
+      g_critical (_("%s@%d: mnmspec->vector: '%s' does not exist (code: '%s')\n"),
 	     __FILE__, __LINE__, mnmspec->vector, code);
       
       return NULL;
@@ -712,7 +712,7 @@ polyxedit_rendering_pixbuf_make_with_vector (gchar *code,
 
   if (pixbuf == NULL)
     {
-      g_critical (_("%s@%d: failed rendering a pixbuf from vector file: %s\n"),
+      g_critical (_("%s@%d: failed to render a pixbuf from vector file: '%s'\n"),
 	     __FILE__, __LINE__, mnmspec->vector);
     }
   
@@ -757,7 +757,7 @@ polyxedit_rendering_pixbuf_make_with_raster (gchar *code,
    */  
   if (NULL == mnmspec->raster)
     {
-      g_message (_("%s@%d: mnmspec->raster is NULL for code '%s'\n"),
+      g_message (_("%s@%d: mnmspec->raster is NULL for code: '%s'\n"),
 	     __FILE__, __LINE__, code);
       
       return NULL;
@@ -765,7 +765,7 @@ polyxedit_rendering_pixbuf_make_with_raster (gchar *code,
 
   if (FALSE == g_file_test (mnmspec->raster, G_FILE_TEST_EXISTS))
     {
-      g_critical (_("%s@%d: mnmspec->raster '%s' does not "
+      g_critical (_("%s@%d: mnmspec->raster: '%s' does not "
 		    "exist (code: '%s')\n"),
 		  __FILE__, __LINE__, mnmspec->raster, code);
       
@@ -779,7 +779,7 @@ polyxedit_rendering_pixbuf_make_with_raster (gchar *code,
 
   if (pixbuf == NULL)
     {
-      g_warning (_("%s@%d: failed rendering a pixbuf "
+      g_warning (_("%s@%d: failed to render a pixbuf "
 		   "from raster file: '%s'\n"),
 		 __FILE__, __LINE__, mnmspec->raster);
   
@@ -826,7 +826,7 @@ polyxedit_rendering_monicon_make_canvas_item (PxmMonicon *monicon,
   g_assert (editctxt->seqeditorctxt != NULL);
   
 
-  /* First of all, we have to compute the position of the monicon for
+  /* First of all, we have to calculate the position of the monicon for
      the currently iterated item. Only (x1,y1) are relevant to us here.
    */
   polyxedit_seqed_wnd_monicon_get_pixel_coord (idx, seqeditorctxt, 
