@@ -86,7 +86,7 @@ polyxedit_calculations_opt_wnd_setup (PxmEditCtxt *editctxt)
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -96,7 +96,7 @@ polyxedit_calculations_opt_wnd_setup (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the calc mass options window\n"),
+      g_critical (_("%s@%d: failed to create the calculations options window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -446,7 +446,7 @@ polyxedit_calculations_opt_checkbutton_toggled (GtkWidget *widget,
   /* Now that the new settings have been made into the
      editctxt->calcopt structure, we have to ask that the masses be
      recalculated. Also, do not forget to update the editctxt's data
-     because the user may be configuring the way masses are computed
+     because the user may be configuring the way masses are calculated
      for a polymer sequence that is not currently focused.
   */
   polyxedit_ui_masses_display_wnd_update_sequence_data (editctxt);
@@ -525,7 +525,7 @@ polyxedit_calculations_opt_ionizerule_activate_entry (GtkWidget *widget,
   
   if (FALSE == libpolyxmass_globals_strtoi (help, &charge, 10))
     {
-      g_warning (_("%s@%d: charge failed to convert to integer: '%s'\n"),
+      g_warning (_("%s@%d: failed to convert from '%s' (charge) to gint\n"),
 		 __FILE__, __LINE__, help);
       
       g_free (help);
@@ -545,7 +545,7 @@ polyxedit_calculations_opt_ionizerule_activate_entry (GtkWidget *widget,
   
   if (FALSE == libpolyxmass_globals_strtoi (help, &level, 10))
     {
-      g_warning (_("%s@%d: level failed to convert to integer: '%s'\n"),
+      g_warning (_("%s@%d: failed to convert from '%s' (level) to gint\n"),
 		 __FILE__, __LINE__, help);
       
       g_free (help);
@@ -575,7 +575,7 @@ polyxedit_calculations_opt_ionizerule_activate_entry (GtkWidget *widget,
   /* Now that the new settings have been made into the
      editctxt->calcopt structure, we have to ask that the masses be
      recalculated. Also, do not forget to update the editctxt's data
-     because the user may be configuring the way masses are computed
+     because the user may be configuring the way masses are calculated
      for a polymer sequence that is not currently focused.
   */
   polyxedit_ui_masses_display_wnd_update_sequence_data (editctxt);
