@@ -29,6 +29,7 @@
 */
 #include "polyxedit-ui-cleave-options.h"
 #include "polyxedit-ui-cleave-results.h"
+#include "polyxmass-window-mngmt.h"
 
 
 
@@ -54,9 +55,12 @@ polyxedit_cleave_opt_wnd_setup (PxmEditCtxt *editctxt)
   
   xml = glade_xml_new (gui_file, "cleave_options_wnd", 
 		       PACKAGE);
+
+  g_free (gui_file);
+
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -66,7 +70,7 @@ polyxedit_cleave_opt_wnd_setup (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the cleavage options window\n"),
+      g_error (_("%s@%d: failed to create the cleavage options window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -90,7 +94,7 @@ polyxedit_cleave_opt_wnd_setup (PxmEditCtxt *editctxt)
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else 
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 
   /* Set the polymer sequence context id number (its pointer) to its
      correspondent GtkEntry.
@@ -121,7 +125,7 @@ polyxedit_cleave_opt_wnd_setup (PxmEditCtxt *editctxt)
   if (FALSE == 
       polyxedit_cleave_opt_setup_cls_treeview (window, widget))
     {
-      g_error (_("%s@%d: failed setting up the cleavespecs' material\n"),
+      g_error (_("%s@%d: failed to set up the cleavage specifications\n"),
 	     __FILE__, __LINE__);
       
       g_object_unref (G_OBJECT (xml));
@@ -157,15 +161,31 @@ polyxedit_cleave_opt_wnd_setup (PxmEditCtxt *editctxt)
   g_signal_connect (G_OBJECT (window),
 		    "delete_event",
 		    G_CALLBACK (polyxedit_cleave_opt_wnd_delete_event),
-		    window);
+		    editctxt);
   
   g_signal_connect (G_OBJECT (window),
 		    "destroy_event",
 		    G_CALLBACK (polyxedit_cleave_opt_wnd_destroy_event),
-		    window);
+		    editctxt);
 
-  g_free (gui_file);
 
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
+
+     There might be more than one cleavage options' window opened for
+     a given polymer seqence editing window, and we do not want that
+     the second window destroys the datum name of the first window, so
+     we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("cleave_options_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_cleave_opt_wnd_really_close);
+  
+  g_free (help);
 
 
   return window;
@@ -266,7 +286,7 @@ polyxedit_cleave_opt_setup_cls_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Name",
+						 -1, _("Name"),
 						 renderer, 
 						 "text",
 						 
@@ -297,7 +317,7 @@ polyxedit_cleave_opt_setup_cls_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Pattern",
+						 -1, _("Pattern"),
 						 renderer, "text",
 
 						 COLUMN_CLS_PATTERN,
@@ -327,7 +347,7 @@ polyxedit_cleave_opt_setup_cls_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Left code",
+						 -1, _("Left code"),
 						 renderer, "text",
 						 
 						 COLUMN_LRR_LEFT_CODE,
@@ -357,7 +377,7 @@ polyxedit_cleave_opt_setup_cls_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Left actform",
+						 -1, _("Left actform"),
 						 renderer, "text",
 
 						 COLUMN_LRR_LEFT_ACTFORM,
@@ -387,7 +407,7 @@ polyxedit_cleave_opt_setup_cls_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Right code",
+						 -1, _("Right code"),
 						 renderer, "text",
 
 						 COLUMN_LRR_RIGHT_CODE,
@@ -417,7 +437,7 @@ polyxedit_cleave_opt_setup_cls_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Right actform",
+						 -1, _("Right actform"),
 						 renderer, "text",
 
 						 COLUMN_LRR_RIGHT_ACTFORM,
@@ -565,7 +585,6 @@ polyxedit_cleave_opt_wnd_cleave_button (GtkWidget *widget, gpointer data)
   gchar *help = NULL;
 
   
-
   /* The mass calculation options are taken from the editctxt's
      calcopt member. The user can modify these at will by selecting
      the appropriate menu.
@@ -629,7 +648,7 @@ polyxedit_cleave_opt_wnd_cleave_button (GtkWidget *widget, gpointer data)
   if (res == FALSE && cleaveopt->partial < 0)
     {
       gtk_entry_set_text (GTK_ENTRY (messages_entry),
-			  _("Error with partial cleavages' value"));
+			  _("Partial cleavages value is incorrect"));
       
       pxmchem_cleaveopt_free (cleaveopt);
       pxmchem_calcopt_free (calcopt);
@@ -726,11 +745,11 @@ polyxedit_cleave_opt_wnd_cleave_button (GtkWidget *widget, gpointer data)
 			      calcopt,
 			      ionizerule))
     {
-      g_critical (_("%s@%d: failed cleaving polymer\n"),
+      g_critical (_("%s@%d: failed to cleave polymer\n"),
 	     __FILE__, __LINE__);
       
       gtk_entry_set_text (GTK_ENTRY (messages_entry),
-			  _("failed cleaving polymer."));
+			  _("Failed to cleave polymer."));
 
       pxmchem_oligomer_GPA_of_GPA_free (partialsGPA);
       
@@ -752,8 +771,10 @@ polyxedit_cleave_opt_wnd_cleave_button (GtkWidget *widget, gpointer data)
 						   partialsGPA);
   if (display_window == NULL)
     {
-      gtk_entry_set_text (GTK_ENTRY (messages_entry),
-			  _("Failed displaying the oligomers in a window"));
+      polyxmass_timeoutmsg_message_set
+	((GtkWindow *) window,
+	 _("Failed to display the oligomers in a window"),
+	 POLYXMASS_NORM_MSG_TIMEOUT);
       
       pxmchem_oligomer_GPA_of_GPA_free (partialsGPA);
       
@@ -788,6 +809,40 @@ polyxedit_cleave_opt_wnd_cleave_button (GtkWidget *widget, gpointer data)
   */
   polyxedit_cleave_res_wnd_update_cleavage_data (display_window);
   
+  /* Register the results' window !
+   */
+  /* Immediately set a automagically freeable string with the
+     description of the new allocated results window so that later
+     -during window management- we can describe what the window was
+     for. This will be used if the user asks to find masses in the
+     results and then a new window will be displayed with all the
+     masses that were found in the results window, and we will want to
+     display that description string.
+  */
+  help = g_strdup_printf (_("Cleavage of '%p' With '%s'"), editctxt,
+			  cleaveopt->cleavespec->name);
+
+  g_object_set_data_full (G_OBJECT (display_window),
+			  "wnd_desc", help, 
+			  (GDestroyNotify) free);
+
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXEDIT",
+       display_window,
+       window,
+       editctxt,
+       _("Results of Cleavage"),
+       help,
+       TRUE,
+       polyxedit_cleave_results_wnd_make_report))
+      g_critical (_("%s@%d: failed to register the cleave results' window\n"),
+		  __FILE__, __LINE__);
+
+  /* Do not free help, because we have set it as a full datum to
+     the window where the cleavage results are to be displayed !
+     
+     g_free (help);
+  */
   
   /* Finally we can return, our work here is finished.
    */
@@ -797,19 +852,67 @@ polyxedit_cleave_opt_wnd_cleave_button (GtkWidget *widget, gpointer data)
 
 
 
-gboolean
-polyxedit_cleave_opt_wnd_delete_event (GtkWidget *widget,
-					   GdkEvent *event,
-					   gpointer data)
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_cleave_opt_wnd_really_close (GtkWidget *window)
 {
+  g_assert (window != NULL);
+  
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  gtk_widget_destroy (window);
+}
+
+
+gboolean
+polyxedit_cleave_opt_wnd_delete_event (GtkWidget *window,
+				       GdkEvent *event,
+				       gpointer data)
+{
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
+  
+  g_assert (window != NULL);
+  g_assert (editctxt != NULL);
+
+
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("cleave_options_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+			     help);
+  
+  g_free (help);
+  
+  /* Let Gtk+ do the rest of the work.
+   */
   return FALSE;
 }
 
 
-
-
 gboolean
-polyxedit_cleave_opt_wnd_destroy_event (GtkWidget *widget,
+polyxedit_cleave_opt_wnd_destroy_event (GtkWidget *window,
 					   GdkEvent *event,
 					    gpointer data)
 {
