@@ -30,26 +30,35 @@
 #include "polyxedit-ui-cleave-results.h"
 #include "polyxedit-ui-findmass-options.h"
 #include "polyxedit-ui-seqed-wnd.h"
+#include "polyxmass-window-mngmt.h"
+
 
 
 /* columns */
 
 enum
 {
+  /* Oligomer name, "p0#4", for example */
+  COLUMN_OLIG_NAME = 0,
+
   /* Partial cleavage */
-  COLUMN_OLIG_PARTIAL = 0,
-  /* Oligomer name, "p0-n4", for example */
-  COLUMN_OLIG_NAME,
+  COLUMN_OLIG_PARTIAL,
+
   /* Coordinates */
   COLUMN_OLIG_COORDINATES,
-  /* Masses */
+
+  /* Mono Mass */
   COLUMN_OLIG_MONO,
+
+  /* Average Mass */
   COLUMN_OLIG_AVG,
+
   /* Contains modified monomers*/
   COLUMN_OLIG_MODIFIED,
+
   /* Pointer to oligomer */
   COLUMN_OLIG_POINTER,
-
+  
   COLUMN_OLIG_COL_COUNT
 };
 
@@ -90,9 +99,12 @@ polyxedit_cleave_res_wnd_setup (PxmEditCtxt *editctxt,
   
   xml = glade_xml_new (gui_file, "cleave_results_wnd", 
 		       PACKAGE);
+
+  g_free (gui_file);
+
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -102,7 +114,7 @@ polyxedit_cleave_res_wnd_setup (PxmEditCtxt *editctxt,
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the cleavage results window\n"),
+      g_error (_("%s@%d: failed to create the cleavage results window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -136,7 +148,7 @@ polyxedit_cleave_res_wnd_setup (PxmEditCtxt *editctxt,
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else 
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 
   /* Set the polymer sequence context id number (its pointer) to its
      correspondent GtkEntry.
@@ -339,14 +351,6 @@ polyxedit_cleave_res_wnd_setup (PxmEditCtxt *editctxt,
 
   /* Finally the buttons of the window.
    */
-  widget = glade_xml_get_widget (xml, "cleave_results_wnd_close_button");
-  g_object_set_data (G_OBJECT (window),
-		     "cleave_results_wnd_close_button", widget);
-  g_signal_connect (G_OBJECT (widget),
-		    "clicked",
-		    G_CALLBACK (polyxedit_cleave_results_wnd_close_button),
-		    window);
-
   widget = glade_xml_get_widget (xml, "cleave_results_wnd_find_button");
   g_object_set_data (G_OBJECT (window),
 		     "cleave_results_wnd_find_button", widget);
@@ -364,16 +368,32 @@ polyxedit_cleave_res_wnd_setup (PxmEditCtxt *editctxt,
   g_signal_connect (G_OBJECT (window),
 		    "delete_event",
 		    G_CALLBACK (polyxedit_cleave_res_wnd_delete_event),
-		    window);
+		    editctxt);
   
   g_signal_connect (G_OBJECT (window),
 		    "destroy_event",
 		    G_CALLBACK (polyxedit_cleave_res_wnd_destroy_event),
-		    window);
-
-  g_free (gui_file);
+		    editctxt);
 
 
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
+
+     There might be more than one cleavage results' window opened for
+     a given polymer seqence editing window, and we do not want that
+     the second window destroys the datum name of the first window, so
+     we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("cleave_results_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_cleave_res_wnd_really_close);
+  
+  g_free (help);
+  
   return window;
 }
 
@@ -626,18 +646,25 @@ polyxedit_cleave_res_create_oligs_treeview_model (GPtrArray *GPA)
   
 
   model = gtk_tree_store_new (COLUMN_OLIG_COL_COUNT,
-			      /* Partial cleavage */
+			      /* Oligo name COLUMN_OLIG_NAME*/
+			      G_TYPE_STRING,
+
+			      /* Partial cleavage COLUMN_OLIG_PARTIAL*/
 			      G_TYPE_INT,
-			      /* Oligo name */
+
+			      /* Coordinates COLUMN_OLIG_COORDINATES*/
 			      G_TYPE_STRING,
-			      /* Coordinates */
-			      G_TYPE_STRING,
-			      /* Masses */
+
+			      /* Mono Mass COLUMN_OLIG_MONO*/
 			      G_TYPE_DOUBLE,
+
+			      /* Average Mass COLUMN_OLIG_AVG*/
 			      G_TYPE_DOUBLE,
-			      /* Modified */
+
+			      /* Modified COLUMN_OLIG_MODIFIED*/
 			      G_TYPE_BOOLEAN,
-			      /* Pointer to oligomer */
+
+			      /* Pointer to oligomer COLUMN_OLIG_POINTER*/
 			      G_TYPE_POINTER);
 
   count = g_malloc0 (sizeof (gint));
@@ -688,9 +715,9 @@ polyxedit_cleave_res_create_oligs_treeview_model (GPtrArray *GPA)
 	  gtk_tree_store_set 
 	    (model, &treeiter,
 
-	     COLUMN_OLIG_PARTIAL, iter,
-
 	     COLUMN_OLIG_NAME, oligomer->name,
+
+	     COLUMN_OLIG_PARTIAL, iter,
 	     
 	     COLUMN_OLIG_COORDINATES, coordinates,
 	     
@@ -703,25 +730,6 @@ polyxedit_cleave_res_create_oligs_treeview_model (GPtrArray *GPA)
 	     COLUMN_OLIG_POINTER, oligomer,
 	     -1);
 	  
-#if 0
-	  /* Generate a latex string so that printing is feasible
-	   */
-	  {
-	    GString *printgs = NULL;
-	    
-	    printgs = g_string_new ("");
-	    g_string_append_printf (printgs, "%d & %s & %s & "
-				    "%lf & %lf & %d \\\\\n", 
-				    iter, oligomer->name, coordinates,
-				    oligomer->masspair->mono,
-				    oligomer->masspair->avg,
-				    modified);
-	    printf (printgs->str);
-	    
-	    printgs = g_string_truncate (printgs, 0);
-	  }
-#endif  
-
 	  /* Now that the data have been set to the store, we can free
 	     the string that were all allocated.
 	  */
@@ -853,6 +861,40 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		    window);
   
 
+  /* Oligomer name column.
+   */
+  renderer = gtk_cell_renderer_text_new ();
+
+  g_object_set (G_OBJECT (renderer), "xalign", 0.5, NULL);
+
+  g_object_set_data (G_OBJECT (renderer), "column",
+		      (gint *) COLUMN_OLIG_NAME);
+
+  column = 
+    gtk_tree_view_column_new_with_attributes (_("Name"),
+					      
+					      renderer,
+					      
+					      "text", 
+					      COLUMN_OLIG_NAME,
+					      
+					      NULL);
+  
+  gtk_tree_view_column_set_sort_column_id (column, 
+					   COLUMN_OLIG_NAME);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+
+  gtk_tree_sortable_set_sort_func 
+    (GTK_TREE_SORTABLE (model),
+     COLUMN_OLIG_NAME,
+     polyxedit_cleave_res_wnd_sort_name_column,
+     NULL,
+     NULL);
+
+
   /* Partial cleavage number column.
    */
   renderer = gtk_cell_renderer_text_new ();
@@ -863,7 +905,7 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_PARTIAL);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Part. Cleav.",
+    gtk_tree_view_column_new_with_attributes (_("Part. Cleav."),
 
 						 renderer,
 
@@ -879,32 +921,6 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
   gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
 
-  /* Oligomer number column.
-   */
-  renderer = gtk_cell_renderer_text_new ();
-
-  g_object_set (G_OBJECT (renderer), "xalign", 0.5, NULL);
-
-  g_object_set_data (G_OBJECT (renderer), "column",
-		      (gint *) COLUMN_OLIG_NAME);
-
-  column = 
-    gtk_tree_view_column_new_with_attributes ("Number",
-
-						 renderer,
-
-						 "text", 
-						 COLUMN_OLIG_NAME,
-						 
-						 NULL);
-
-  gtk_tree_view_column_set_sort_column_id (column, 
-					   COLUMN_OLIG_NAME);
-
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-
   /* Oligomer coordinates column.
    */
   renderer = gtk_cell_renderer_text_new ();
@@ -915,7 +931,7 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_COORDINATES);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Coordinates",
+    gtk_tree_view_column_new_with_attributes (_("Coordinates"),
 					      
 					      renderer,
 					      
@@ -948,7 +964,7 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_MONO);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mono Mass",
+    gtk_tree_view_column_new_with_attributes (_("Mono Mass"),
 
 						 renderer,
 
@@ -975,7 +991,7 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_AVG);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Avg Mass",
+    gtk_tree_view_column_new_with_attributes (_("Avg Mass"),
 
 						 renderer,
 						 
@@ -1002,7 +1018,7 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_MODIFIED);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Modified",
+    gtk_tree_view_column_new_with_attributes (_("Modified"),
 
 						 renderer,
 
@@ -1024,7 +1040,7 @@ polyxedit_cleave_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_POINTER);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Oligo. Pointer",
+    gtk_tree_view_column_new_with_attributes (_("Oligo. Pointer"),
 
 						 renderer,
 
@@ -1127,7 +1143,7 @@ polyxedit_cleave_res_setup_oligomer_modifs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_MDF_MNM_POS);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Position",
+    gtk_tree_view_column_new_with_attributes (_("Position"),
 
 						 renderer,
 
@@ -1149,7 +1165,7 @@ polyxedit_cleave_res_setup_oligomer_modifs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_MDF_MNM_CODE);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Code",
+    gtk_tree_view_column_new_with_attributes (_("Code"),
 
 						 renderer, 
 
@@ -1171,7 +1187,7 @@ polyxedit_cleave_res_setup_oligomer_modifs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_MDF_MNM_MODIF);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Monomer Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Monomer Modif."),
 
 						 renderer, 
 
@@ -1193,7 +1209,7 @@ polyxedit_cleave_res_setup_oligomer_modifs_treeview (GtkWidget *window,
 		     (gint *)COLUMN_OLIG_MDF_LE_MODIF );
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Left End Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Left End Modif."),
 
 						 renderer, 
 
@@ -1215,7 +1231,7 @@ polyxedit_cleave_res_setup_oligomer_modifs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_MDF_RE_MODIF);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Right End Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Right End Modif."),
 
 						 renderer, 
 
@@ -1305,7 +1321,8 @@ polyxedit_cleave_res_olig_show_modification_data (PxmOligomer *oligomer,
 	 COLUMN_OLIG_MDF_LE_MODIF, prop->data,
 
 	 -1);
-    }
+
+          }
 
   /* Second we check if there is are monomer modifications in the
      oligomer. These are thus listed between the left end modif and
@@ -1700,33 +1717,6 @@ polyxedit_cleave_results_wnd_sort_mass_column (GtkTreeModel *model,
 }
 
 
-
-void
-polyxedit_cleave_results_wnd_close_button (GtkWidget *widget, gpointer data)
-{
-  GtkWidget *window = data;
-
-  GPtrArray *GPA = NULL;
-  
-  g_assert (window != NULL);
-  
-
-  /* We have a full array of arrays of oligomers to free before
-     leaving this window!
-  */
-  GPA = g_object_get_data (G_OBJECT (window), "partialsGPA");
-  g_assert (GPA != NULL);
-  
-  pxmchem_oligomer_GPA_of_GPA_free (GPA);
-  
-  /* Now we can safely destroy this window.
-   */
-  gtk_object_destroy (GTK_OBJECT (window));
-  
-  return;
-}
-
-
 void
 polyxedit_cleave_results_wnd_find_button (GtkWidget *widget, gpointer data)
 {
@@ -1735,6 +1725,8 @@ polyxedit_cleave_results_wnd_find_button (GtkWidget *widget, gpointer data)
   
   GPtrArray *GPA = NULL;
   
+  gchar *help = NULL;
+    
   g_assert (window != NULL);
   
 
@@ -1753,14 +1745,75 @@ polyxedit_cleave_results_wnd_find_button (GtkWidget *widget, gpointer data)
   
   if (window_new == NULL)
     {
-      g_critical (_("%s@%d: failed setting up the find mass options window\n"),
+      g_critical (_("%s@%d: failed to set up the find mass options window\n"),
 	     __FILE__, __LINE__);
     }
+
+  /* At this point we ought to set an explanation string to the
+     created window, so that we later can determine for what purpose
+     this window was created. This is particularly important to know
+     how to sort the names of the oligomers that will be displayed in
+     the findmass results window.
+  */
+  help = g_strdup ("CLEAVAGE");
   
+  g_object_set_data_full (G_OBJECT (window_new), 
+			  "oligomer_type", help,  
+			  (GDestroyNotify) g_free);
+
   return;
 }
 
 
+gint
+polyxedit_cleave_res_wnd_sort_name_column (GtkTreeModel *model,
+					     GtkTreeIter *a,
+					     GtkTreeIter *b,
+					     gpointer user_data)
+{
+  
+  gchar *name_a = NULL;
+  gchar *name_b = NULL;
+  
+  gint partial_a = -1;
+  gint number_a = -1;
+  
+  gint partial_b = -1;
+  gint number_b = -1;
+  
+  
+  /* We get the pointer to two different items in the treeview (the
+     model actually) and we need to access the data in them and then
+     tell which is greater to the other.
+  */
+  gtk_tree_model_get (model, a, 
+		      COLUMN_OLIG_NAME, &name_a,
+		      -1);
+
+  gtk_tree_model_get (model, b, 
+		      COLUMN_OLIG_NAME, &name_b,
+		      -1);
+
+  /* The name of the oligomer is of kind "p1#103", which means that we
+     are dealing with "oligomer number 103 of partial cleavage 1".
+  */
+  sscanf (name_a, "p%d#%d", &partial_a, &number_a);
+  sscanf (name_b, "p%d#%d", &partial_b, &number_b);
+  
+  if (partial_a == partial_b)
+    {
+      if (number_a == number_b)
+	return 0;
+      
+      return (number_a > number_b) ? 1 : -1;
+    }
+  else
+    return (partial_a > partial_b ? 1 : -1);
+  
+  return 0;
+}
+
+
 gint
 polyxedit_cleave_res_wnd_sort_coordinates_column (GtkTreeModel *model,
 						  GtkTreeIter *a,
@@ -1804,41 +1857,537 @@ polyxedit_cleave_res_wnd_sort_coordinates_column (GtkTreeModel *model,
   */
 
   if (start_a == start_b)
-    return 0;
+    {
+      if (end_a == end_b)
+	return 0;
+      return (end_a > end_b) ? 1 : -1;
+    }
   
   return (start_a > start_b) ? 1 : -1;
 }
 
 
+
+
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_cleave_results_wnd_make_report (PxmReportOpt* reportopt,
+					    PxmWinMngmt* winmngmt)
+{
+
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+  
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_cleave_results_wnd_make_report_text_format (reportopt,
+								 winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_cleave_results_wnd_make_report_latex_format (reportopt,
+								  winmngmt);
+  else
+    g_assert_not_reached ();
+    
+  return NULL;
+}
+
+
+
+gchar *
+polyxedit_cleave_results_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						      PxmWinMngmt* winmngmt)
+{
+  PxmCleaveOpt *cleaveopt = NULL;
+  PxmCalcOpt *calcopt = NULL;
+  PxmIonizerule *ionizerule = NULL;
+
+  GtkWidget *window = NULL;
+  
+  gchar *report = NULL;
+  
+  GString *report_gs = NULL;
+  
+  PxmPolymer *polymer = NULL;
+
+  PxmOligomer *oligomer = NULL;
+
+  PxmProp *prop = NULL;
+
+
+  GtkTreeView *treeview = NULL;
+  GtkTreeStore *model;
+  GtkTreeIter treeiter;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+
+  g_assert (winmngmt->editctxt != NULL);
+  /* The window where the cleave results are displayed is in
+     'winmngmt->wnd'.
+   */
+  window = winmngmt->wnd;
+  g_assert (window != NULL);
+  
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
+
+
+
+  report_gs = g_string_new ("");
+
+  /* We have absolutely to describe the cleavage options !
+   */
+  cleaveopt = g_object_get_data (G_OBJECT (window), "cleaveopt");
+  g_assert (cleaveopt != NULL);
+  g_assert (cleaveopt->cleavespec != NULL);
+  
+  g_string_append_printf (report_gs, _("Cleavage Options:\n"
+			  "-----------------\n"
+			  "Cleavage Agent Name: %s -- Pattern: %s\n"
+			  "Partial Cleavages: %d\n\n"),
+			  cleaveopt->cleavespec->name, 
+			  cleaveopt->cleavespec->pattern,
+			  cleaveopt->partial);
+  
+  if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_CALCOPTIONS) ==
+      PXM_OLM_REPORTOPT_CALCOPTIONS)
+    {
+      calcopt = g_object_get_data (G_OBJECT (window), "calcopt");
+      g_assert (calcopt != NULL);
+      
+      report_gs = 
+	g_string_append (report_gs, _("Calculations Options:\n"
+			 "---------------------\n"));
+
+      if (calcopt->capping & PXM_CAPPING_RIGHT && 
+	  calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: BOTH\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_RIGHT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: RIGHT\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: LEFT\n"));
+      
+      else
+	report_gs = g_string_append (report_gs, "Capping: NONE\n");
+	
+      if (calcopt->mnm_chement & PXMCHEMENT_MNM_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: MODIFS\n"));
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: NONE\n"));
+	
+      if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF
+	  && calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modifs: BOTH\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: LEFT\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: RIGHT\n"));
+	
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: NONE\n\n"));
+
+      /* Describe the ionization rule.
+       */
+      ionizerule = g_object_get_data (G_OBJECT (window), "ionizerule");
+      g_assert (ionizerule != NULL);
+
+      g_string_append_printf (report_gs, 
+			      _("Ionization: "
+			      "%s, with charge %d and level %d\n\n"),
+			      ionizerule->actform,
+			      ionizerule->charge,
+			      ionizerule->level);
+    }
+
+
+  /* Since we want to make a user-friendly report, we manage to have
+     the different oligomers reported in the order that the user has
+     set in the treeview (some of that treeview column are sortable).
+
+     Thus we iterate in the treeview instead of iterating in the
+     arrray of oligomers... Some tricky work is required to still
+     inform the user of the partial cleavage of each oligomer.
+  */
+  model = g_object_get_data (G_OBJECT (window), "oligomers_treeview_model");
+  g_assert (model != NULL);
+  
+  treeview = g_object_get_data (G_OBJECT (window), "oligomers_treeview");
+  g_assert (treeview != NULL);
+  
+  if (FALSE == gtk_tree_model_get_iter_first ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      g_warning (_("%s@%d: treeview is empty, nothing to report\n"),
+		 __FILE__, __LINE__);
+
+      report_gs = 
+	g_string_append (report_gs, _("Treeview is empty, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  else
+    {
+      /* We have the first item of the list here. Use it !
+       */
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+
+      g_string_append_printf (report_gs, "%-12s [%-5s-->%5s] "
+			      "%-20s %-20s %-6s %-20s %-20s\n\n",
+			      _("name"), _("start"), _("end"), _("mono"), _("avg"), 
+			      _("Modif?"), _("LE-modif?"), _("RE-modif?")); 
+      
+      g_string_append_printf (report_gs, "%-12s [%-5d-->%5d] ",
+			      oligomer->name,
+			      oligomer->start_idx + 1,
+			      oligomer->end_idx + 1);
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	  PXM_OLM_REPORTOPT_MONO_MASS 
+	  &&
+	  (reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	  PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono,
+				  oligomer->masspair->avg);
+	}
+      
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	       PXM_OLM_REPORTOPT_MONO_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono, 0.0);
+	}
+      
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	       PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  0.0, oligomer->masspair->avg);
+	}
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_PROP) == 
+	  PXM_OLM_REPORTOPT_PROP)
+	{
+	  /* See if the oligomer contains a modification... maybe not.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "POS/IDX/MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-6s ",
+				  (prop != NULL ? _("Yes") : _("No")));
+	  
+	  /* See if the oligomer is LEFT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "LEFT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s ",
+				  (prop != NULL ? 
+				   (gchar *) prop->data : _("No")));
+	  
+	  /* See if the oligomer is RIGHT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "RIGHT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s\n",
+				  (prop != NULL ? 
+				   (gchar *) prop->data : _("No")));
+	}
+      else
+	report_gs = g_string_append (report_gs, "\n");
+      
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_SEQUENCE) == 
+	  PXM_OLM_REPORTOPT_SEQUENCE)
+	{
+	  report = pxmchem_polymer_make_codes_string (oligomer->polymer,
+						      oligomer->start_idx,
+						      oligomer->end_idx);
+	  g_assert (report != NULL);
+	  
+	  g_string_append_printf (report_gs, "%s\n", report);
+	  
+	  g_free (report);      
+	}
+    }
+  /*
+    End of successfully  getting the first item in the treeview.
+  */
+
+
+  /* And now continue to the remaining one in the while loop.
+   */
+  while (TRUE == gtk_tree_model_iter_next ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+      
+      g_string_append_printf (report_gs, "%-12s [%-5d-->%5d] ",
+			      oligomer->name,
+			      oligomer->start_idx + 1,
+			      oligomer->end_idx + 1);
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	  PXM_OLM_REPORTOPT_MONO_MASS 
+	  &&
+	  (reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	  PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono,
+				  oligomer->masspair->avg);
+	}
+      
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	       PXM_OLM_REPORTOPT_MONO_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono, 0.0);
+	}
+      
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	       PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  0.0, oligomer->masspair->avg);
+	}
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_PROP) == 
+	  PXM_OLM_REPORTOPT_PROP)
+	{
+	  /* See if the oligomer contains a modification... maybe not.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "POS/IDX/MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-6s ",
+				  (prop != NULL ? _("Yes") : _("No")));
+	  
+	  /* See if the oligomer is LEFT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "LEFT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s ",
+				  (prop != NULL ? (gchar *) prop->data : _("No")));
+	  
+	  /* See if the oligomer is RIGHT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "RIGHT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s\n",
+				  (prop != NULL ? (gchar *) prop->data : _("No")));
+	}
+      else
+	report_gs = g_string_append (report_gs, "\n");
+      
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_SEQUENCE) == 
+	  PXM_OLM_REPORTOPT_SEQUENCE)
+	{
+	  report = pxmchem_polymer_make_codes_string (oligomer->polymer,
+						      oligomer->start_idx,
+						      oligomer->end_idx);
+	  g_assert (report != NULL);
+	  
+	  g_string_append_printf (report_gs, "%s\n", report);
+	  
+	  g_free (report);      
+	}
+    }
+  /*
+    End of getting the remaining items in the treeview.
+  */
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+
+
+gchar *
+polyxedit_cleave_results_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						       PxmWinMngmt* winmngmt)
+{
+
+
+
+  return NULL;
+}
+
+
+
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_cleave_res_wnd_really_close (GtkWidget *window)
+{
+  GPtrArray *GPA = NULL;
+
+  gint count = 0;
+
+  g_assert (window != NULL);
+  
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* We have a full array of arrays of oligomers to free before
+     leaving this window!
+  */
+  GPA = g_object_get_data (G_OBJECT (window), "partialsGPA");
+  g_assert (GPA != NULL);
+  
+  count = pxmchem_oligomer_GPA_of_GPA_free (GPA);
+
+  /*
+    debug_printf (("freed %d oligomers\n", count));
+  */
+
+  gtk_widget_destroy (window);
+}
+
+
+
 gboolean
 polyxedit_cleave_res_wnd_delete_event (GtkWidget *window,
 				       GdkEvent *event,
 				       gpointer data)
 {
-  gint count = 0;
   GPtrArray *GPA = NULL;
-
-  /* We have a full array of arrays of oligomers to free before
-     leaving this window!
-  */
+  
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
+  gint count = 0;
+  
+  
   g_assert (window != NULL);
+  g_assert (editctxt != NULL);
   
-  GPA = g_object_get_data (G_OBJECT (window), "partialsGPA");
-  g_assert (GPA != NULL);
-  
-  pxmchem_oligomer_GPA_of_GPA_free (GPA);
+
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
   
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
   
+  /* We have a full array of arrays of oligomers to free before
+     leaving this window!
+  */
+  GPA = g_object_get_data (G_OBJECT (window), "partialsGPA");
+  g_assert (GPA != NULL);
+  
+  count = pxmchem_oligomer_GPA_of_GPA_free (GPA);
+
   /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
+    debug_printf (("freed %d oligomers\n", count));
   */
 
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("cleave_results_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->
+				   sequence_editor_wnd),
+			     help);
+  
+  g_free (help);
+  
   /* Let Gtk+ do the rest of the work.
    */
   return FALSE;
