@@ -129,7 +129,7 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -139,7 +139,7 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the completions window\n"),
+      g_critical (_("%s@%d: failed to create the completions window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -157,7 +157,8 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
 		     widget);
 
 
-  /* Set the polymer definition type to its correspondent GtkEntry.
+  /* Set the polymer chemistry definition type to its correspondent
+     GtkEntry.
    */
   widget = glade_xml_get_widget (xml, "polchemdef_type_entry");
   g_assert (widget != NULL);
@@ -251,7 +252,7 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
 
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Monicon", renderer,
+     -1, _("Monicon"), renderer,
      "pixbuf", COMP_COLUMN_MNM_PIXBUF,
      NULL);
   
@@ -269,7 +270,7 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
 		      (gint *) COMP_COLUMN_MNM_CODE);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Code",
+    gtk_tree_view_column_new_with_attributes (_("Code"),
 					      
 					      renderer,
 					      
@@ -302,7 +303,7 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
 		      (gint *) COMP_COLUMN_MNM_CODE);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Name",
+    gtk_tree_view_column_new_with_attributes (_("Name"),
 					      
 					      renderer,
 					      
@@ -339,7 +340,7 @@ polyxedit_completions_wnd_setup (PxmEditCtxt *editctxt, GPtrArray *GPA)
   /* Set the name of the polymer sequence to the title bar of the
    * window.
    */
-  help = g_strdup_printf ("Completions: %s", 
+  help = g_strdup_printf (_("Completions: %s"), 
 			  editctxt->polymer->plminfo->name);
   
   gtk_window_set_title (GTK_WINDOW (window), help);
@@ -524,11 +525,11 @@ polyxedit_completions_wnd_update_list_completions (PxmEditCtxt *editctxt,
 							    editctxt);
 	      if (pixbuf != NULL)
 		{
-		  /* Let the polymer definition context know that we
-		   * have rendered the pixbuf for the monomer 'code'.
-		   * Note that we just created a pixbuf from nothing
-		   * and it was created by a reference count of 1, so
-		   * we do not need to do anything.
+		  /* Let the polymer chemistry definition context know
+		   * that we have rendered the pixbuf for the monomer
+		   * 'code'.  Note that we just created a pixbuf from
+		   * nothing and it was created by a reference count
+		   * of 1, so we do not need to do anything.
 		   */
 		  polyxedit_rendering_pixbuf_set_to_data_list (pixbuf, 
 							       monomer->code,
@@ -537,7 +538,7 @@ polyxedit_completions_wnd_update_list_completions (PxmEditCtxt *editctxt,
 		}
 	      else
 		{
-		  g_error (_("%s@%d: failed rendering pixbuf for code: %s\n"),
+		  g_error (_("%s@%d: failed to render pixbuf for code: '%s'\n"),
 			 __FILE__, __LINE__, monomer->code);
 		}
 	    }
@@ -704,7 +705,7 @@ polyxedit_completions_treeview_row_activated_event (GtkTreeView *treeview,
     {
       g_free (code);
 
-      err = g_strdup_printf ("failed completion monomer code: '%s'",
+      err = g_strdup_printf (_("Failed completion monomer code: '%s'"),
 			     code);
       
       gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -820,7 +821,7 @@ polyxedit_completions_treeview_key_release_event (GtkWidget *widget,
     {
       g_free (code);
 
-      err = g_strdup_printf ("failed completion monomer code: '%s'",
+      err = g_strdup_printf (_("Failed completion monomer code: '%s'"),
 			     code);
       
       gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
