@@ -57,7 +57,7 @@ polyxedit_elemcompos_wnd_setup (PxmEditCtxt *editctxt)
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -67,7 +67,7 @@ polyxedit_elemcompos_wnd_setup (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the elemental composition window\n"),
+      g_critical (_("%s@%d: failed to create the elemental composition window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -134,7 +134,7 @@ polyxedit_elemcompos_wnd_setup (PxmEditCtxt *editctxt)
   */
   polyxedit_elemcompos_wnd_update_sequence_region_button (NULL, window);
 
-  /* The checkbutton that says if we want the computation to be
+  /* The checkbutton that says if we want the calculation to be
      incremental or not.
   */
   widget = glade_xml_get_widget (xml, "incremental_checkbutton");
@@ -202,6 +202,25 @@ polyxedit_elemcompos_wnd_setup (PxmEditCtxt *editctxt)
 		    "destroy_event",
 		    G_CALLBACK (polyxedit_elemcompos_wnd_destroy_event), 
 		    editctxt);
+
+
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
+
+     There might be more than one composition results' window opened
+     for a given polymer seqence editing window, and we do not want
+     that the second window destroys the datum name of the first
+     window, so we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("elemcompos_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_elemcompos_wnd_really_close);
+  
+  g_free (help);
   
   return window;
 }
@@ -257,7 +276,7 @@ polyxedit_elemcompos_wnd_execute_button (GtkWidget *button,
   messages_entry = g_object_get_data (G_OBJECT (window), 
 				      "messages_entry");
   
-  /* We must check if the user wants that the computation be made for
+  /* We must check if the user wants that the calculation be made for
      the whole sequence or for the selection region of the polymer sequence
      only, or for the interval that is defined with the start_pos and 
      end_pos entry widgets.
@@ -322,7 +341,7 @@ polyxedit_elemcompos_wnd_execute_button (GtkWidget *button,
 	    calcopt->end_idx = 0;
 	  else
 	    {
-	      /* Remember that for the end_idx, the computations need
+	      /* Remember that for the end_idx, the calculations need
 		 to have it incremented by one with respect to the real
 		 last monomer index. So, contrary to start_idx, we do not
 		 change its value.
@@ -349,7 +368,7 @@ polyxedit_elemcompos_wnd_execute_button (GtkWidget *button,
     }
 
 
-  /* If the user wants not that the computations be incremental, 
+  /* If the user wants not that the calculations be incremental, 
      we first have to empty the array of atomcounts.
   */
   widget = 
@@ -359,7 +378,7 @@ polyxedit_elemcompos_wnd_execute_button (GtkWidget *button,
   if (FALSE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     pxmchem_atomcount_GPA_empty (acGPA);
   
-  /* We finally have all needed to perform the computation:
+  /* We finally have all needed to perform the calculation:
    */
   res = pxmchem_elemcompcalc_polymer (editctxt->polymer,
 				      editctxt->polchemdefctxt->polchemdef,
@@ -370,14 +389,14 @@ polyxedit_elemcompos_wnd_execute_button (GtkWidget *button,
   if (res != PXM_COMPCALC_SUCCESS)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					     _("Computation failed"),
+					     _("Calculation failed"),
 					     POLYXMASS_NORM_MSG_TIMEOUT);
     }
   else
     {
       if (formula == NULL)
 	  polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-						 _("Computation failed"),
+						 _("Calculation failed"),
 						 POLYXMASS_NORM_MSG_TIMEOUT);
       else
 	{
@@ -390,16 +409,27 @@ polyxedit_elemcompos_wnd_execute_button (GtkWidget *button,
 
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("Computation successful"),
+	     _("Calculation succeeded"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	}
     }
   
-  /* At this point we can free the helper stuff.
-   */
-  pxmchem_calcopt_free (calcopt);
-  pxmchem_ionizerule_free (ionizerule);
+  /* Since we might have to write a report about this calculation, we
+     have to be able to know with which calculation/ionization options
+     the calculation was performed. Thus, we store this information as
+     full data to the window, for later enquiry. See
+     polyxedit_elemcompos_wnd_make_report_text_format() for details !
+
+     Note that the g_object_set_data_full calls below will elicit
+     freeing of potentially pre-existing instances using their
+     respective freeing functions.
+  */
+  g_object_set_data_full (G_OBJECT (window), "calcopt", calcopt,
+			  (GDestroyNotify) pxmchem_calcopt_free);
   
+  g_object_set_data_full (G_OBJECT (window), "ionizerule", ionizerule,
+			  (GDestroyNotify) pxmchem_ionizerule_free);
+    
   return;
 }
 
@@ -484,29 +514,303 @@ polyxedit_elemcompos_wnd_update_sequence_region_button (GtkWidget *button,
 }
 
 
-gint 
-polyxedit_elemcompos_wnd_delete_event (GtkWidget *window, 
-					GdkEventAny *event, 
-				       gpointer data)
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_elemcompos_wnd_make_report (PxmReportOpt* reportopt,
+					  PxmWinMngmt* winmngmt)
 {
-  gint count = 0;
+  
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_elemcompos_wnd_make_report_text_format (reportopt,
+								 winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_elemcompos_wnd_make_report_latex_format (reportopt,
+								  winmngmt);
+  else
+    g_assert_not_reached ();
+    
+  return NULL;
+}
+
+
+
+gchar *
+polyxedit_elemcompos_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+  GtkWidget *window = NULL;
+  GtkWidget *entry = NULL;
+
+  gchar *report = NULL;
+  const gchar *entry_text = NULL;
+  
+  GString *report_gs = NULL;
+
+  PxmPolymer *polymer = NULL;
+  PxmPlminfo *plminfo = NULL;
+  PxmCalcOpt *calcopt = NULL;
+  PxmIonizerule *ionizerule = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  
+  window = winmngmt->wnd ;
+  g_assert (window != NULL);
+  
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
+
+  plminfo = polymer->plminfo;
+  g_assert (plminfo != NULL);
+
+  
+  report_gs = g_string_new ("");
+  
+  report_gs = pxmchem_polymer_format_txt_string_polseqinfo (plminfo,
+							    reportopt,
+							    report_gs);
+  
+  /* Get the pointers to the structures we know have determined how
+     the calculation was performed. However, these pointers are
+     non-NULL only if at least one calculation was performed, since
+     they are set as full data when the Execute button is pushed.
+
+     Thus, if these are NULL, we return with a message...
+  */
+  calcopt = g_object_get_data (G_OBJECT (window), "calcopt");
+  ionizerule = g_object_get_data (G_OBJECT (window), "ionizerule");
+  
+  if  (calcopt == NULL || ionizerule == NULL)
+    {
+      g_warning (_("%s@%d: no calculation took place, nothing to report\n"),
+		 __FILE__, __LINE__);
+      
+      report_gs = 
+	g_string_append (report_gs, _("No calculation took place, "
+			 "nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  
+
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_CALCOPTIONS) ==
+      PXM_PLM_REPORTOPT_CALCOPTIONS)
+    {
+      report_gs = 
+	g_string_append (report_gs, _("Calculations Options:\n"
+			 "---------------------\n"));
+
+      if (calcopt->capping & PXM_CAPPING_RIGHT && 
+	  calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: BOTH\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_RIGHT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: RIGHT\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: LEFT\n"));
+      
+      else
+	report_gs = g_string_append (report_gs, _("Capping: NONE\n"));
+	
+      if (calcopt->mnm_chement & PXMCHEMENT_MNM_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: MODIFS\n"));
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: NONE\n"));
+	
+	
+      if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF
+	  && calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modifs: BOTH\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: LEFT\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: RIGHT\n"));
+	
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: NONE\n\n"));
+
+      /* Describe the ionization rule.
+       */
+      g_string_append_printf (report_gs, 
+			      _("Ionization: "
+			      "%s, with charge %d and level %d\n\n"),
+			      ionizerule->actform,
+			      ionizerule->charge,
+			      ionizerule->level);
+    }
+  
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_WHOLE_SEQ_MASSES) ==
+      PXM_PLM_REPORTOPT_WHOLE_SEQ_MASSES ||
+      (reportopt->polymer_opt & PXM_PLM_REPORTOPT_SELECTION_MASSES) ==
+      PXM_PLM_REPORTOPT_SELECTION_MASSES)
+      report_gs = 
+	g_string_append (report_gs, _("Masses:\n"
+			 "-------\n"));
+
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_WHOLE_SEQ_MASSES) ==
+      PXM_PLM_REPORTOPT_WHOLE_SEQ_MASSES)
+    {
+      g_string_append_printf (report_gs,
+			      _("Whole sequence: "
+			      "mono mass = %.5lf -- avg mass = %.5lf\n"),
+			      polymer->masspair_seq->mono,
+			      polymer->masspair_seq->avg);
+    }
+  
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_SELECTION_MASSES) ==
+      PXM_PLM_REPORTOPT_SELECTION_MASSES)
+    {
+      g_string_append_printf (report_gs, 
+			      _("Selected sequence: "
+			      "mono mass = %.5lf -- avg mass = %.5lf\n\n"),
+			      polymer->masspair_sel->mono,
+			      polymer->masspair_sel->avg);
+    }
+  
+  /* At this point, we can ask that the actual report be performed.
+   */
+
+  /* Tell for which sequence, the composition was performed.
+   */
+  g_string_append_printf (report_gs, 
+			  _("Elemental Composition:\n"
+			  "----------------------\n\n"
+			  "Selected sequence: [%d-%d]\n\n"),
+			  calcopt->start_idx + 1, 
+			  calcopt->end_idx);
+  
+  entry = g_object_get_data (G_OBJECT (window), 
+			     "elemental_composition_entry");
+  
+  /* Get the text that corresponds to the formula representing the
+     elemental composition.
+  */
+  entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
+  g_assert (entry_text != NULL);
+  
+  g_string_append_printf (report_gs, 
+			  _("Elemental Composition: %s\n\n"),
+			  entry_text);
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+  
+gchar *
+polyxedit_elemcompos_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+
+  return NULL;
+  
+}
+
+  
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_elemcompos_wnd_really_close (GtkWidget *window)
+{
+
+  g_assert (window != NULL);
+  
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
   
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
   
-  /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
-  */
-
-  return FALSE;
+  gtk_widget_destroy (window);
 }
 
 
 
+gint 
+polyxedit_elemcompos_wnd_delete_event (GtkWidget *window, 
+					GdkEventAny *event, 
+				       gpointer data)
+{
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
+  
+  g_assert (window != NULL);
+  g_assert (editctxt != NULL);
+  
+
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("elemcompos_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+			 help);
+  
+  g_free (help);
+  
+  /* Let Gtk+ do the rest of the work.
+   */
+  return FALSE;
+}
+
+
 gint 
 polyxedit_elemcompos_wnd_destroy_event (GtkWidget *window, 
 					GdkEventAny *event, 
