@@ -35,6 +35,8 @@
 GtkWidget *
 polyxedit_findmass_opt_setup_wnd (GtkWidget *parent, GPtrArray *haystackGPA)
 {
+  PxmEditCtxt *editctxt;
+
   GtkWidget *window = NULL;
   GtkWidget *widget = NULL;
   GtkWidget *combo = NULL;
@@ -51,11 +53,25 @@ polyxedit_findmass_opt_setup_wnd (GtkWidget *parent, GPtrArray *haystackGPA)
   */
   g_assert (haystackGPA != NULL);
 
-  /* The window in which the oligomeric results are displayed is passed
-     as parameter so that the find-masses-result window will be informed
-     of the window from which the masses were found.
+  /* This function is called from windows where oligomer data are
+     displayed. For example, this function is called from the window
+     where oligomers obtained after cleavage of polymers or after
+     fragmentation of oligomers.
+     
+     See polyxedit_cleave_results_wnd_find_button() to check that
+     'parent' is actually the window where the oligomer results were
+     displayed. We use that pointer to the parent window in order to
+     set to it a pointer to *this window as a full datum. See the
+     really_close function below. We want this options window to be
+     automagically closed if the results window from which it was
+     elicited is closed.
+
+     Since that 'parent' window had a knowledge of what editctxt it
+     was created in, we can get that context out of the 'parent'
+     window ! 
   */
   g_assert (parent != NULL);
+
   
   gui_file = 
     g_strdup_printf ("%s/polyxedit-findmass-options.glade", 
@@ -70,7 +86,7 @@ polyxedit_findmass_opt_setup_wnd (GtkWidget *parent, GPtrArray *haystackGPA)
 
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -80,7 +96,7 @@ polyxedit_findmass_opt_setup_wnd (GtkWidget *parent, GPtrArray *haystackGPA)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the find mass window\n"),
+      g_critical (_("%s@%d: failed to create the find mass window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -89,21 +105,27 @@ polyxedit_findmass_opt_setup_wnd (GtkWidget *parent, GPtrArray *haystackGPA)
     }
 
 
-  /* Immediately set a datum to the window, that contains the parent 
+  /* Immediately set a datum to the window, that contains the parent
      window, so that when the results of this mass find operation are
-     displayed, the result window can display this value. The user
-     will thus know from which window these results come. This 'parent'
-     window will turn out to be the grand_parent of the window in which
-     this datum is effectively used, because the findmass-options window
-     is the intermediate, in which this datum is not used.
+     displayed, the result window can display that value.
+
+     The user will thus know from which cleave/fragment results window
+     the findmass results come. Thus, this 'parent' window will turn
+     out to be the grand_parent of the window in which this datum is
+     effectively used, because the findmass-options window is the
+     intermediate, in which this datum is not used.
   */
   g_object_set_data (G_OBJECT (window), "grand_parent", parent);
+
+  editctxt = g_object_get_data (G_OBJECT (parent), "editctxt");
+  g_assert (editctxt);
+    g_object_set_data (G_OBJECT (window), "editctxt", editctxt);
+  
   
   widget = glade_xml_get_widget (xml, "messages_entry");
   g_object_set_data (G_OBJECT (window), "messages_entry",
 		     widget);
 
-
   /* Set the parent window pointer to the relative entry.
    */
   widget = glade_xml_get_widget (xml, "results_set_identity_number_entry");
@@ -307,6 +329,33 @@ polyxedit_findmass_opt_setup_wnd (GtkWidget *parent, GPtrArray *haystackGPA)
      G_CALLBACK (polyxedit_findmass_opt_wnd_delete_event), 
      NULL);
 
+  g_signal_connect 
+    (G_OBJECT (window),
+     "destroy_event",
+     G_CALLBACK (polyxedit_findmass_opt_wnd_destroy_event), 
+     NULL);
+
+  /* Set this window pointer as a full datum to the results window
+     from which this window is created (typicall the results window is
+     a window where oligomers obtained from a cleavage or a
+     fragmentation are displayed. We want to make sure that, if the
+     results window from which *this window is created is closed, then
+     *this window is closed also.
+
+     There might be more than one findmass options' window opened for
+     a given results window, and we do not want that the second window
+     destroys the datum name of the first window, so we create an
+     uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("findmass_options_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (parent),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_findmass_opt_wnd_really_close);
+  
+  g_free (help);
+
   return window;
 }
 
@@ -314,9 +363,13 @@ void
 polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 					      gpointer data)
 {
+  PxmEditCtxt *editctxt = NULL;
+
   GtkWidget *check = NULL;
+
   GtkWidget *window = data;
   GtkWidget *display_window = NULL;
+  GtkWidget *parent_wnd = NULL;
 
   /* Textview stuff....
    */
@@ -326,7 +379,8 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
   GtkTextIter end;
 
   gchar *new_text = NULL;
-  
+  gchar *wnd_desc = NULL;
+
   PxmFindmassOpt *fmopt = NULL;
 
   PxmMassType mass_type = PXM_MASS_NONE;
@@ -391,7 +445,7 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("could not retrieve a correct mass value"),
+	     _("Failed to get a correct mass value"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_findmassopt_free (fmopt);
@@ -409,7 +463,7 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("could not retrieve a correct tolerance value"),
+	     _("Failed to get a correct tolerance value"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_findmassopt_free (fmopt);
@@ -426,7 +480,7 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("could not get a correct tolerance type"),
+	     _("Failed to get a correct tolerance type"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_findmassopt_free (fmopt);
@@ -456,7 +510,7 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("failed finding the mass in the oligomer array"),
+	     _("Failed to find the mass in the oligomer array"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -468,7 +522,7 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("mass not found in the polymer"),
+	     _("Mass not found in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -494,14 +548,57 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("Failed displaying the oligomers in a window"),
+	     _("Failed to display the oligomers in a window"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
 	  
 	  return;
 	}
-            
+      
+      /* Register the results' window !
+       */
+      /* Get the window description string from the window where the
+	 cleavage/fragmentation results were displayed. We will use
+	 this string to make sure the user will know exactly from
+	 which data the find mass results were extracted !
+      */
+      parent_wnd = g_object_get_data (G_OBJECT (window), "grand_parent");
+      g_assert (parent_wnd != NULL);
+      
+      editctxt = g_object_get_data (G_OBJECT (parent_wnd), "editctxt");
+      g_assert (editctxt != NULL);
+      
+      wnd_desc = g_object_get_data (G_OBJECT (parent_wnd), "wnd_desc");
+      g_assert (wnd_desc != NULL);
+      
+      help = g_strdup_printf (_("Find Mass For Results in Window ID '%p'"
+			      " ('%s')"), 
+			      parent_wnd, wnd_desc);
+      
+      g_object_set_data_full (G_OBJECT (display_window),
+			      "wnd_desc", help, 
+			      (GDestroyNotify) free);
+
+      if (NULL == polyxmass_winmngmt_register_window 
+	  ("POLYXEDIT",
+	   display_window,
+	   window,
+	   editctxt,
+	   _("Results of Find Mass"),
+	   help,
+	   TRUE,
+	   polyxedit_findmass_results_wnd_make_report))
+	g_critical (_("%s@%d: failed to register the "
+		      "find mass results' window\n"),
+		    __FILE__, __LINE__);
+      
+      /* Do not free help, because we have set it as a full datum to
+	 the window where the find mass results are to be displayed !
+	 
+	 g_free (help);
+      */
+
       /* Finally we can return, our work here is finished.
        */
       return;
@@ -524,7 +621,7 @@ polyxedit_findmass_opt_mass_entry_activate (GtkEntry *entry,
 					"avg_masses_textview");
 	}
       else
-	g_error (_("%s@%d: error in the window layout\n"),
+	g_error (_("%s@%d: failed to interpret the window layout\n"),
 	       __FILE__, __LINE__);
 
       /* Get the buffer that holds the text presently (if any) in the
@@ -612,7 +709,7 @@ polyxedit_findmass_opt_find_masses (GtkWidget *window,
 	{
 	  polyxmass_timeoutmsg_message_set
 	((GtkWindow *) window,
-	     _("failed finding one mass in the oligomer array"),
+	     _("Failed to find one mass in the oligomer array"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  return -1;
@@ -635,8 +732,12 @@ void
 polyxedit_findmass_opt_find_button (GtkWidget *button,
 				    gpointer data)
 {
+  PxmEditCtxt *editctxt = NULL;
+
   GtkWidget *window = data;
   GtkWidget *display_window = NULL;
+  GtkWidget *parent_wnd = NULL;
+
   GtkWidget *entry = NULL;
   GtkWidget *check = NULL;
 
@@ -646,8 +747,11 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
   GtkTextView *textview = NULL;
   GtkTextIter start;
   GtkTextIter end;
+
   gchar *masses_text = NULL;
-  
+  gchar *wnd_desc = NULL;
+  gchar *help = NULL;
+    
   gdouble *mass = NULL;
 
   PxmMassType mass_types [] = 
@@ -732,7 +836,7 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
 	{
 	 polyxmass_timeoutmsg_message_set
 	((GtkWindow *) window,
-	     _("both MONO and AVG text entries have a mass value"),
+	     _("Both MONO and AVG text entries have a mass value"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	}
       else if (mono_ok == TRUE)
@@ -847,7 +951,7 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
 	    {
 	      polyxmass_timeoutmsg_message_set
 		((GtkWindow *) window,
-		 _("the text view data are not valid UTF-8"),
+		 _("The data in the text view are not valid UTF-8"),
 		 POLYXMASS_NORM_MSG_TIMEOUT);
 	      
 	      /* Here it makes sense to continue even if we do not have
@@ -905,7 +1009,7 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
 	    {
 	      polyxmass_timeoutmsg_message_set
 		((GtkWindow *) window,
-		 _("could not retrieve a correct tolerance value"),
+		 _("Failed to get a correct tolerance value"),
 		 POLYXMASS_NORM_MSG_TIMEOUT);
 	     
 	      /* Only return, however, if there are no fmopts in the
@@ -934,7 +1038,7 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
 	    {
 	      polyxmass_timeoutmsg_message_set
 		((GtkWindow *) window,
-		 _("could not get a correct tolerance type"),
+		 _("Failed to get a correct tolerance type"),
 		 POLYXMASS_NORM_MSG_TIMEOUT);
 
 	      /* Only return, however, if there are no fmopts in the
@@ -1051,7 +1155,7 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	((GtkWindow *) window,
-	     _("failed finding the masses in the polymer"),
+	     _("Failed to find the masses in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -1063,7 +1167,7 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	((GtkWindow *) window,
-	     _("no mass was found in the polymer"),
+	     _("No mass was found in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -1079,23 +1183,68 @@ polyxedit_findmass_opt_find_button (GtkWidget *button,
       */
       pxmchem_findmassopt_GPA_free (fmoptGPA);
 	  
-      /* At this point we just have to display the oligomers. We pass
-	 to the found oligomers-displaying window the pointer to
+      /* At this point we just have to display the found oligomers. We
+	 pass to the found oligomers-displaying window the pointer to
 	 _this_ window.
        */
       display_window = polyxedit_findmass_res_wnd_setup (window,
 							 alloligsGPA);
+
       if (display_window == NULL)
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("Failed displaying the oligomers in a window"),
+	     _("Failed to display the oligomers in a window"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
 	  
 	  return;
 	}
+
+      /* Register the results' window !
+       */
+
+      /* Get the window description string from the window where the
+	 cleavage/fragmentation results were displayed. We will use
+	 this string to make sure the user will know exactly from
+	 which data the find mass results were extracted !
+      */
+      parent_wnd = g_object_get_data (G_OBJECT (window), "grand_parent");
+      g_assert (parent_wnd != NULL);
+      
+      editctxt = g_object_get_data (G_OBJECT (parent_wnd), "editctxt");
+      g_assert (editctxt != NULL);
+      
+      wnd_desc = g_object_get_data (G_OBJECT (parent_wnd), "wnd_desc");
+      g_assert (wnd_desc != NULL);
+      
+      help = g_strdup_printf (_("Find Mass For Results in Window ID '%p'"
+			      " ('%s')"), 
+			      parent_wnd, wnd_desc);
+      
+      g_object_set_data_full (G_OBJECT (display_window),
+			      "wnd_desc", help, 
+			      (GDestroyNotify) free);
+
+      if (NULL == polyxmass_winmngmt_register_window 
+	  ("POLYXEDIT",
+	   display_window,
+	   window,
+	   editctxt,
+	   _("Results of Find Mass"),
+	   help,
+	   TRUE,
+	   polyxedit_findmass_results_wnd_make_report))
+	g_critical (_("%s@%d: failed to register the "
+		      "find mass results' window\n"),
+		    __FILE__, __LINE__);
+      
+      /* Do not free help, because we have set it as a full datum to
+	 the window where the find mass results are to be displayed !
+	 
+	 g_free (help);
+      */
       
       /* Finally we can return, our work here is finished.
        */
@@ -1288,25 +1437,67 @@ polyxedit_findmass_opt_get_tolerance_type (GtkWidget *window,
 }
 
 
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_findmass_opt_wnd_really_close (GtkWidget *window)
+{
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+
+
+  gtk_widget_destroy (window);
+}
+
+  
 gboolean
 polyxedit_findmass_opt_wnd_delete_event (GtkWidget *window, 
 					 GdkEventAny *event, 
 					 gpointer data)
 {
-  gint count = 0;
+  gchar *help = NULL;
 
+  GtkWidget *parent_wnd = NULL;
+  
+  g_assert (window != NULL);
+
+  /* See top for the explanation of why we name that datum
+     "grand_parent" and not "parent".
+  */
+  parent_wnd = g_object_get_data (G_OBJECT (window), "grand_parent");
+  g_assert (parent_wnd != NULL);
+  
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
-  
-  /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
-  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
 
+  /* This window pointer was set as a full datum to the parent window
+     (a cleavage or fragmentatioon results window), which means that
+     we have to remove that pointer, without triggering the callback
+     function call.
+  */
+  help = g_strdup_printf ("findmass_options_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (parent_wnd), help);
+  
+  g_free (help);
+  
+  /* Let Gtk+ do the rest of the work.
+   */
   return FALSE;
 }
 
   
+gboolean
+polyxedit_findmass_opt_wnd_destroy_event (GtkWidget *window, 
+					 GdkEventAny *event, 
+					 gpointer data)
+{
+  return FALSE;
+}
