@@ -28,25 +28,36 @@
    Boston, MA 02111-1307, USA.
 */
 #include "polyxedit-ui-findmass-results.h"
+#include "polyxedit-ui-cleave-results.h"
+#include "polyxedit-ui-fragment-results.h"
+#include "polyxedit-ui-searchmass-results.h"
+
 
 /* columns */
 
 enum
 {
+  /* The name of the oligo ! */
+  COLUMN_OLIG_NAME = 0,
+
   /* The mass that was found. */
   COLUMN_OLIG_TO_FIND_MASS,
+
   /* the difference between found and found masses */
   COLUMN_OLIG_MASS_ERROR,
-  /* The name of the oligo ! */
-  COLUMN_OLIG_NAME,
+
   /* The index + 1 in the array of oligos ! */
   COLUMN_OLIG_NUMBER,
+
   /* MONO or AVG: the mass type of the find */
   COLUMN_OLIG_MASS_TYPE,
+
   /* Mono mass */
   COLUMN_OLIG_MONO,
+
   /* Average mass */
   COLUMN_OLIG_AVG,
+
   /* Pointer to the oligomer */
   COLUMN_OLIG_POINTER,
 
@@ -81,9 +92,12 @@ polyxedit_findmass_res_wnd_setup (GtkWidget *parent,
   
   xml = glade_xml_new (gui_file, "findmass_results_wnd", 
 		       PACKAGE);
+
+  g_free (gui_file);
+
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -93,7 +107,7 @@ polyxedit_findmass_res_wnd_setup (GtkWidget *parent,
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the findmass results window\n"),
+      g_error (_("%s@%d: failed to create the findmass results window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -114,16 +128,26 @@ polyxedit_findmass_res_wnd_setup (GtkWidget *parent,
 
   /* Set the parent window pointer to the relative entry.
    */
-  /* The window from which _this_ window was asked to setup has
-     a datum that corresponds to the former's parent, which is the
-     window in which the mass data were in the first place.
-     See the polyxedit-ui-findmass-options.c file at the place where
-     the options window is setup.
+  /* The window from which _this_ window was asked to setup has a
+     datum that corresponds to the one-generation-up-level parent,
+     that is the window in which the cleave/fragment results mass data
+     were in the first place and from which mass(es) where asked to be
+     found.  See the polyxedit-ui-findmass-options.c file at the place
+     where the options window is setup.
+
+     We will need to access that datum later, so we put it in an
+     identical manner to _this window. We will use that 'grand_parent'
+     pointer to connect _this window really_close () function to the
+     window-closing function belonging to the grand_parent
+     window. Indeed, it makes no sense to still have _this found
+     masses-window open if the initial masses window does not exist
+     anymore.
   */
   grand_parent = g_object_get_data (G_OBJECT (parent), "grand_parent");
   g_assert (grand_parent != NULL);
+  g_object_set_data (G_OBJECT (window), "grand_parent", grand_parent);
   
-  
+
   widget = glade_xml_get_widget (xml, "results_set_identity_number_entry");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (window), "results_set_identity_number_entry", 
@@ -132,6 +156,46 @@ polyxedit_findmass_res_wnd_setup (GtkWidget *parent,
   help = g_strdup_printf ("%p", grand_parent);
   gtk_entry_set_text (GTK_ENTRY (widget), help);
   g_free (help);
+
+  
+  /* At this point we ought to set an explanation string to the
+     created window, so that we later can determine for what purpose
+     this window was created. This is particularly important to know
+     how to sort the names of the oligomers that will be displayed in
+     the findmass results window.
+     
+     We actually did set that explanatory string in the oligomer
+     results window, either the cleavage oligomer results window,
+     or the fragmentation oligomer results window. We have to get
+     it out of _this_ window and duplicate it to the findmass
+     results window.
+  */
+  help = g_object_get_data (G_OBJECT (parent), 
+			    "oligomer_type");
+  g_assert (help != NULL);
+  
+  help = g_strdup (help);
+  
+  g_object_set_data_full (G_OBJECT (window), 
+			  "oligomer_type", help, g_free);
+  
+  /* We also want to provide an identification number of this window
+     to the user, so that when a reporting of the results is asked it
+     will be possible to identify *this* specific window of mass find
+     results.
+   */
+  widget =
+    glade_xml_get_widget (xml, 
+			  "mass_find_results_set_identity_number_entry");
+  g_assert (widget != NULL);
+  g_object_set_data (G_OBJECT (window), 
+		     "mass_find_results_set_identity_number_entry", 
+		     widget);
+  
+  help = g_strdup_printf ("%p", window);
+  gtk_entry_set_text (GTK_ENTRY (widget), help);
+  g_free (help);
+
   
 
   /* The oligomers' frame must be correctly set up:
@@ -164,17 +228,6 @@ polyxedit_findmass_res_wnd_setup (GtkWidget *parent,
 	return NULL;
     }
   
-  /* Finally the button of the window.
-   */
-  widget = glade_xml_get_widget (xml, "findmass_results_wnd_close_button");
-  g_object_set_data (G_OBJECT (window),
-		     "findmass_results_wnd_close_button", widget);
-  g_signal_connect 
-    (G_OBJECT (widget),
-     "clicked",
-     G_CALLBACK (polyxedit_findmass_results_wnd_close_button),  
-     window);
-  
 
   /* We don't need the GladeXML object any more, so unref it
      to save some memory 
@@ -191,7 +244,25 @@ polyxedit_findmass_res_wnd_setup (GtkWidget *parent,
 		    G_CALLBACK (polyxedit_findmass_res_wnd_destroy_event),
 		    window);
 
-  g_free (gui_file);
+  /* Set this window pointer as a full datum to the window where the
+     results were displayed, and in which the find mass operation was
+     performed to produce _this findmass results window, so that when
+     it is closed this window is closed also.
+
+     There might be more than one findmass results' window opened for
+     a given oligomer results window, and we do not want that the
+     second window destroys the datum name of the first window, so we
+     create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("findmass_results_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (grand_parent),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_findmass_res_wnd_really_close);
+  
+  g_free (help);
+  
 
 
   return window;
@@ -275,23 +346,32 @@ polyxedit_findmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
   g_assert (alloligsGPA != NULL);
   
 
-  model = gtk_tree_store_new (COLUMN_OLIG_COL_COUNT,
-			      /* The mass that was found. */
-			      G_TYPE_DOUBLE,
-			      /* Difference (found - found) */
-			      G_TYPE_DOUBLE,
-			      /* The name of the oligo ! */
-			      G_TYPE_STRING,
-			      /* The index + 1 in the array of oligos ! */
-			      G_TYPE_INT,
-			      /* MONO or AVG: the mass type of the find */
-			      G_TYPE_STRING,
-			      /* Mono mass */
-			      G_TYPE_DOUBLE,
-			      /* Average mass */
-			      G_TYPE_DOUBLE,
-			      /* Pointer to the oligomer */
-			      G_TYPE_POINTER);
+  model = gtk_tree_store_new 
+    (COLUMN_OLIG_COL_COUNT,
+     
+     /* The name of the oligo ! COLUMN_OLIG_NAME*/
+     G_TYPE_STRING,
+     
+     /* The mass that was found. COLUMN_OLIG_TO_FIND_MASS*/
+     G_TYPE_DOUBLE,
+     
+     /* Difference (found - found) COLUMN_OLIG_MASS_ERROR*/
+     G_TYPE_DOUBLE,
+     
+     /* The index + 1 in the array of oligos ! COLUMN_OLIG_NUMBER*/
+     G_TYPE_INT,
+     
+     /* MONO or AVG: the mass type of the find COLUMN_OLIG_MASS_TYPE*/
+     G_TYPE_STRING,
+     
+     /* Mono mass COLUMN_OLIG_MONO*/
+     G_TYPE_DOUBLE,
+     
+     /* Average mass COLUMN_OLIG_AVG*/
+     G_TYPE_DOUBLE,
+     
+     /* Pointer to the oligomer COLUMN_OLIG_POINTER*/
+     G_TYPE_POINTER);
   
   count = g_malloc0 (sizeof (gint));
 
@@ -326,7 +406,7 @@ polyxedit_findmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 	  fmopt = prop->data;
 	  g_assert (fmopt != NULL);
 
-	  /* Now we can compute the error:
+	  /* Now we can calculate the error:
 	   */
 	  if (fmopt->mass_type == PXM_MASS_MONO)
 	    {
@@ -334,7 +414,7 @@ polyxedit_findmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 
 	      /* Take advantage to set the mass type string:
 	       */
-	      mass_type = g_strdup_printf ("MONO");
+	      mass_type = g_strdup_printf (_("MONO"));
 	    }
 	  else /*  (fmopt->mass_type == PXM_MASS_AVG) */
 	    {
@@ -342,27 +422,34 @@ polyxedit_findmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 
 	      /* Take advantage to set the mass type string:
 	       */
-	      mass_type = g_strdup_printf ("AVG");
+	      mass_type = g_strdup_printf (_("AVG"));
 	    }
 	  
 	  gtk_tree_store_append (model, &treeiter, NULL);
 	  gtk_tree_store_set 
 	    (model, &treeiter,
 
-	     /* The mass that was found. */
-	     COLUMN_OLIG_TO_FIND_MASS, fmopt->mass,
-	     /* Difference (found - found) */
-	     COLUMN_OLIG_MASS_ERROR, error,
 	     /* The name of the oligo ! */
 	     COLUMN_OLIG_NAME, oligomer->name,
+
+	     /* The mass that was found. */
+	     COLUMN_OLIG_TO_FIND_MASS, fmopt->mass,
+
+	     /* Difference (found - found) */
+	     COLUMN_OLIG_MASS_ERROR, error,
+
 	     /* The absolute index + 1 in the arrays of oligos ! */
 	     COLUMN_OLIG_NUMBER, (*count) + 1,
+
 	     /* MONO or AVG: the mass type of the find */
 	     COLUMN_OLIG_MASS_TYPE, mass_type,
+
 	     /* Mono mass */
 	     COLUMN_OLIG_MONO, oligomer->masspair->mono,
+
 	     /* Average mass */
 	     COLUMN_OLIG_AVG, oligomer->masspair->avg,
+
 	     /* Pointer to the oligomer */
 	     COLUMN_OLIG_POINTER, oligomer,
 
@@ -408,6 +495,8 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
 
   GtkWidget *sw = NULL;
 
+  gchar *oligomer_type = NULL;
+  
 
   g_assert (window != NULL);
   g_assert (vbox != NULL);
@@ -456,8 +545,6 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
    */
   treeview = gtk_tree_view_new_with_model (model);
   
-  g_object_unref (G_OBJECT (model));
-
   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
 
   /* Set to the window a datum with a pointer to the treeview, so that
@@ -470,54 +557,12 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
 			       (GTK_TREE_VIEW (treeview)),
 			       GTK_SELECTION_MULTIPLE);
 
-  /* The found mass column.
-   */
-  renderer = gtk_cell_renderer_text_new ();
-
-  column = 
-    gtk_tree_view_column_new_with_attributes ("To Find",
-					      
-					      renderer, 
-					      
-					      "text",
-					      COLUMN_OLIG_TO_FIND_MASS,
-					      
-					      NULL);
-  
-  gtk_tree_view_column_set_sort_column_id (column, 
-					   COLUMN_OLIG_TO_FIND_MASS);
-
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-
-  /* The mass error column.
-   */
-  renderer = gtk_cell_renderer_text_new ();
-
-  column = 
-    gtk_tree_view_column_new_with_attributes ("Error",
-					      
-					      renderer, 
-					      
-					      "text",
-					      COLUMN_OLIG_MASS_ERROR,
-					      
-					      NULL);
-  
-  gtk_tree_view_column_set_sort_column_id (column, 
-					   COLUMN_OLIG_MASS_ERROR);
-
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-
   /* Oligomer name column.
    */
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Name",
+    gtk_tree_view_column_new_with_attributes (_("Name"),
 					      
 					      renderer, 
 					      
@@ -533,12 +578,91 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
   gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
 
+  /* Depending on what kind of oligomer (cleavage or fragmentation oligomer),
+     we have to choose the proper name-sorting function ! 
+
+     This is because the names of the oligomers do not share the same
+     syntax and layout if they are from a cleavage or a fragmentation.
+  */
+  oligomer_type = g_object_get_data (G_OBJECT (window), 
+				     "oligomer_type");
+  g_assert (oligomer_type != NULL);
+  
+  if (0 == strcmp (oligomer_type, "CLEAVAGE"))
+    gtk_tree_sortable_set_sort_func 
+      (GTK_TREE_SORTABLE (model),
+       COLUMN_OLIG_NAME,
+       polyxedit_cleave_res_wnd_sort_name_column,
+       NULL,
+       NULL);
+  else if (0 == strcmp (oligomer_type, "FRAGMENT"))
+    gtk_tree_sortable_set_sort_func 
+      (GTK_TREE_SORTABLE (model),
+       COLUMN_OLIG_NAME,
+       polyxedit_fragment_res_wnd_sort_name_column,
+       NULL,
+       NULL);
+  else if (0 == strcmp (oligomer_type, "SEARCHMASS"))
+    gtk_tree_sortable_set_sort_func 
+      (GTK_TREE_SORTABLE (model),
+       COLUMN_OLIG_NAME,
+       polyxedit_searchmass_res_wnd_sort_name_column,
+       NULL,
+       NULL);
+  else
+    g_assert_not_reached ();
+
+
+  /* The found mass column.
+   */
+  renderer = gtk_cell_renderer_text_new ();
+
+  column = 
+    gtk_tree_view_column_new_with_attributes (_("To Find"),
+					      
+					      renderer, 
+					      
+					      "text",
+					      COLUMN_OLIG_TO_FIND_MASS,
+					      
+					      NULL);
+  
+  gtk_tree_view_column_set_sort_column_id (column, 
+					   COLUMN_OLIG_TO_FIND_MASS);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+
+
+  /* The mass error column.
+   */
+  renderer = gtk_cell_renderer_text_new ();
+
+  column = 
+    gtk_tree_view_column_new_with_attributes (_("Error"),
+					      
+					      renderer, 
+					      
+					      "text",
+					      COLUMN_OLIG_MASS_ERROR,
+					      
+					      NULL);
+  
+  gtk_tree_view_column_set_sort_column_id (column, 
+					   COLUMN_OLIG_MASS_ERROR);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+
+  
   /* Oligomer number column.
    */
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Number",
+    gtk_tree_view_column_new_with_attributes (_("Number"),
 					      
 					      renderer, 
 					      
@@ -559,7 +683,7 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mass Type",
+    gtk_tree_view_column_new_with_attributes (_("Mass Type"),
 					      
 					      renderer, 
 					      
@@ -580,7 +704,7 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mono Mass",
+    gtk_tree_view_column_new_with_attributes (_("Mono Mass"),
 					      
 					      renderer, 
 					      
@@ -600,7 +724,7 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Avg Mass",
+    gtk_tree_view_column_new_with_attributes (_("Avg Mass"),
 					      
 					      renderer, 
 					      
@@ -620,7 +744,7 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
   
   column = 
-    gtk_tree_view_column_new_with_attributes ("Oligo. Pointer",
+    gtk_tree_view_column_new_with_attributes (_("Oligo. Pointer"),
 					      
 					      renderer,
 					      
@@ -638,22 +762,243 @@ polyxedit_findmass_res_setup_oligs_treeview (GtkWidget *window,
   gtk_container_add (GTK_CONTAINER (sw), treeview);
   
   gtk_widget_show_all (vbox);
+
+  /* At this point we can finally unref the model.
+   */
+  g_object_unref (G_OBJECT (model));
   
   return TRUE;
 }
 
 
-
-void
-polyxedit_findmass_results_wnd_close_button (GtkWidget *widget, 
-					    gpointer data)
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_findmass_results_wnd_make_report (PxmReportOpt* reportopt,
+					    PxmWinMngmt* winmngmt)
 {
-  GtkWidget *window = data;
 
-  GPtrArray *alloligsGPA = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
   
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+  
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_findmass_results_wnd_make_report_text_format (reportopt,
+								 winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_findmass_results_wnd_make_report_latex_format (reportopt,
+								  winmngmt);
+  else
+    g_assert_not_reached ();
+    
+  return NULL;
+}
+
+
+
+gchar *
+polyxedit_findmass_results_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						      PxmWinMngmt* winmngmt)
+{
+  GtkWidget *window = NULL;
+  
+  gchar *report = NULL;
+  gchar *type = NULL;
+
+  gdouble find = 0;
+  gdouble error = 0;
+    
+  GString *report_gs = NULL;
+  
+  PxmPolymer *polymer = NULL;
+
+  GtkTreeView *treeview = NULL;
+  GtkTreeStore *model;
+  GtkTreeIter treeiter;
+
+  PxmOligomer *oligomer = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+
+  g_assert (winmngmt->editctxt != NULL);
+  /* The window where the fragment results are displayed is in
+     'winmngmt->wnd'.
+   */
+  window = winmngmt->wnd;
   g_assert (window != NULL);
   
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
+
+ 
+
+ report_gs = g_string_new ("");
+
+
+
+  /* Since we want to make a user-friendly report, we manage to have
+     the different oligomers reported in the order that the user has
+     set in the treeview (some of that treeview column are sortable).
+
+     Thus we iterate in the treeview instead of iterating in the
+     arrray of oligomers... Some tricky work is required to still
+     inform the user of the partial cleavage of each oligomer.
+  */
+  model = g_object_get_data (G_OBJECT (window), "oligomers_treeview_model");
+  g_assert (model != NULL);
+  
+  treeview = g_object_get_data (G_OBJECT (window), "oligomers_treeview");
+  g_assert (treeview != NULL);
+  
+  if (FALSE == gtk_tree_model_get_iter_first ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      g_warning (_("%s@%d: treeview is empty, nothing to report\n"),
+		 __FILE__, __LINE__);
+
+      report_gs = 
+	g_string_append (report_gs, _("Treeview is empty, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  else
+    {
+      /* We have the first item of the list here. Use it !
+       */
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_TO_FIND_MASS,
+			  &find,
+
+			  COLUMN_OLIG_MASS_ERROR,
+			  &error,
+
+			  COLUMN_OLIG_MASS_TYPE,
+			  &type,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+      
+      g_string_append_printf (report_gs, 
+			      "%-12s %-20s %-20s %-5s %-20s %-20s\n\n",
+			      _("name"), _("mass to find"), _("mass error"), _("type"), 
+			      _("mono"), _("avg"));
+      
+      g_string_append_printf (report_gs, 
+			      "%-12s %-20.5lf %-20.5lf %-5s "
+			      "%-20.5lf %-20.5lf\n",
+			      oligomer->name, find, error, type,
+			      oligomer->masspair->mono, 
+			      oligomer->masspair->avg);
+    }
+  /*
+    End of successfully  getting the first item in the treeview.
+  */
+
+
+  /* And now continue to the remaining one in the while loop.
+   */
+  while (TRUE == gtk_tree_model_iter_next ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_TO_FIND_MASS,
+			  &find,
+
+			  COLUMN_OLIG_MASS_ERROR,
+			  &error,
+
+			  COLUMN_OLIG_MASS_TYPE,
+			  &type,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+      
+      g_string_append_printf (report_gs, 
+			      "%-12s %-20.5lf %-20.5lf %-5s "
+			      "%-20.5lf %-20.5lf\n",
+			      oligomer->name, find, error, type,
+			      oligomer->masspair->mono, 
+			      oligomer->masspair->avg);
+    }
+  /*
+    End of getting the remaining items in the treeview.
+  */
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+gchar *
+polyxedit_findmass_results_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						      PxmWinMngmt* winmngmt)
+{
+
+  return NULL;
+}
+
+
+
+
+
+
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_findmass_res_wnd_really_close (GtkWidget *window)
+{
+  GPtrArray *alloligsGPA = NULL;
+
+  gint count = 0;
+
+  g_assert (window != NULL);  
+
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
 
   /* We have a full array of arrays of oligomers to free before
      leaving this window! Also we have to free the array of fragopt
@@ -661,35 +1006,71 @@ polyxedit_findmass_results_wnd_close_button (GtkWidget *widget,
   */
   alloligsGPA = g_object_get_data (G_OBJECT (window), "alloligsGPA");
   g_assert (alloligsGPA != NULL);
-  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
+  count = pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
 
-  /* Now we can safely destroy this window.
-   */
-  gtk_object_destroy (GTK_OBJECT (window));
+  /*
+    debug_printf (("freed %d oligomers\n", count));
+  */
 
-  return;
+  gtk_widget_destroy (window);
 }
 
 
-
-
 gboolean
-polyxedit_findmass_res_wnd_delete_event (GtkWidget *widget,
+polyxedit_findmass_res_wnd_delete_event (GtkWidget *window,
 					   GdkEvent *event,
 					   gpointer data)
 {
+  GtkWidget *grand_parent = NULL;
+  
+  PxmEditCtxt *editctxt = data;
+
   GPtrArray *alloligsGPA = NULL;
 
+  gchar *help = NULL;
+  gint count = 0;
+  
+
+  g_assert (window != NULL);
+  g_assert (editctxt != NULL);
+
+
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
   /* We have a full array of arrays of oligomers to free before
      leaving this window! Also we have to free the array of fragopt
      objects.
   */
-  g_assert (widget != NULL);
-  
-  alloligsGPA = g_object_get_data (G_OBJECT (widget), "alloligsGPA");
+  alloligsGPA = g_object_get_data (G_OBJECT (window), "alloligsGPA");
   g_assert (alloligsGPA != NULL);
-  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
+  count = pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
+
+  /*
+    debug_printf (("freed %d oligomers\n", count));
+  */
+
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("findmass_results_wnd-%p", window);
   
+  grand_parent = g_object_get_data (G_OBJECT (window), "grand_parent");
+  g_assert (grand_parent != NULL);
+  
+  window = g_object_steal_data (G_OBJECT (grand_parent), help);
+  
+  g_free (help);
+
+
   /* Let Gtk+ do the rest of the work.
    */
   return FALSE;
@@ -699,7 +1080,7 @@ polyxedit_findmass_res_wnd_delete_event (GtkWidget *widget,
 
 
 gboolean
-polyxedit_findmass_res_wnd_destroy_event (GtkWidget *widget,
+polyxedit_findmass_res_wnd_destroy_event (GtkWidget *window,
 					   GdkEvent *event,
 					    gpointer data)
 {
