@@ -69,7 +69,7 @@ polyxedit_findrep_opt_setup_wnd (PxmEditCtxt *editctxt)
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -79,7 +79,7 @@ polyxedit_findrep_opt_setup_wnd (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the find/replace options window\n"),
+      g_critical (_("%s@%d: failed to create the find/replace options window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -492,7 +492,7 @@ polyxedit_findrep_opt_find_treeview_setup (GtkWidget *widget,
 
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Monicon", renderer,
+     -1, _("Monicon"), renderer,
      "pixbuf", COLUMN_MNM_PIXBUF,
      NULL);
   
@@ -757,8 +757,8 @@ polyxedit_findrep_opt_find_update_graphics_button (GtkWidget *button,
 						  polchemdef->monomerGPA, FALSE);
   if (-1 == count)
     {
-      g_critical ("%s@%d: failed filling monomer array from string "
-	     "of codes: %s\n",
+      g_critical (_("%s@%d: failed to fill monomer array from string "
+		    "of codes: %s\n"),
 	     __FILE__, __LINE__, find_sequence_text);
       
       return;
@@ -804,11 +804,11 @@ polyxedit_findrep_opt_find_update_graphics_button (GtkWidget *button,
 							editctxt);
 	  if (pixbuf != NULL)
 	    {
-	      /* Let the polymer definition context know that we
-	       * have rendered the pixbuf for the monomer 'code'.
-	       * Note that we just created a pixbuf from nothing
-	       * and it was created by a reference count of 1, so
-	       * we do not need to do anything.
+	      /* Let the polymer chemistry definition context know
+	       * that we have rendered the pixbuf for the monomer
+	       * 'code'.  Note that we just created a pixbuf from
+	       * nothing and it was created by a reference count of 1,
+	       * so we do not need to do anything.
 	       */
 	      polyxedit_rendering_pixbuf_set_to_data_list (pixbuf, 
 							   monomer->code,
@@ -817,7 +817,7 @@ polyxedit_findrep_opt_find_update_graphics_button (GtkWidget *button,
 	    }
 	  else
 	    {
-	      g_error (_("%s@%d: failed rendering pixbuf for code: %s\n"),
+	      g_error (_("%s@%d: failed to render pixbuf for code: %s\n"),
 		     __FILE__, __LINE__, monomer->code);
 	    }
 	}
