@@ -30,6 +30,7 @@
 #include "polyxedit-ui-fragment-options.h"
 #include "polyxedit-ui-fragment-results.h"
 #include "polyxedit-ui-seqed-wnd.h"
+#include "polyxmass-window-mngmt.h"
 
 /* columns */
 
@@ -77,11 +78,12 @@ polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt)
   
   xml = glade_xml_new (gui_file, "fragment_options_wnd", 
 		       PACKAGE);
+
   g_free (gui_file);
 
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -91,7 +93,7 @@ polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the fragmentation options window\n"),
+      g_error (_("%s@%d: failed to create the fragmentation options window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -115,7 +117,7 @@ polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt)
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else 
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 
   /* Set the polymer sequence context id number (its pointer) to its
      correspondent GtkEntry.
@@ -141,7 +143,7 @@ polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt)
   if (FALSE == 
       polyxedit_fragment_opt_setup_fgs_treeview (window, widget))
     {
-      g_error (_("%s@%d: failed setting up the fragspecs' material\n"),
+      g_error (_("%s@%d: failed to set up the fragspecs treeview\n"),
 	     __FILE__, __LINE__);
       
       g_object_unref (G_OBJECT (xml));
@@ -176,14 +178,32 @@ polyxedit_fragment_opt_wnd_setup (PxmEditCtxt *editctxt)
   g_signal_connect (G_OBJECT (window),
 		    "delete_event",
 		    G_CALLBACK (polyxedit_fragment_opt_wnd_delete_event),
-		    window);
+		    editctxt);
   
   g_signal_connect (G_OBJECT (window),
 		    "destroy_event",
 		    G_CALLBACK (polyxedit_fragment_opt_wnd_destroy_event),
-		    window);
+		    editctxt);
 
 
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
+
+     There might be more than one fragment options' window opened for
+     a given polymer seqence editing window, and we do not want that
+     the second window destroys the datum name of the first window, so
+     we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("fragment_options_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_fragment_opt_wnd_really_close);
+  
+  g_free (help);
+
   return window;
 }
 
@@ -282,7 +302,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Name",
+						 -1, _("Name"),
 						 renderer, 
 						 "text",
 						 
@@ -313,7 +333,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "End",
+						 -1, _("End"),
 						 renderer, 
 						 "text",
 						 
@@ -344,7 +364,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Actform",
+						 -1, _("Actform"),
 						 renderer, "text",
 
 						 COLUMN_FGS_ACTFORM,
@@ -374,7 +394,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Comment",
+						 -1, _("Comment"),
 						 renderer, "text",
 
 						 COLUMN_FGS_COMMENT,
@@ -404,7 +424,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Name",
+						 -1, _("Name"),
 						 renderer, "text",
 						 
 						 COLUMN_FGR_NAME,
@@ -434,7 +454,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Prev",
+						 -1, _("Prev"),
 						 renderer, "text",
 						 
 						 COLUMN_FGR_PREV,
@@ -464,7 +484,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "This",
+						 -1, _("This"),
 						 renderer, "text",
 						 
 						 COLUMN_FGR_THIS,
@@ -494,7 +514,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Next",
+						 -1, _("Next"),
 						 renderer, "text",
 						 
 						 COLUMN_FGR_NEXT,
@@ -524,7 +544,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Actform",
+						 -1, _("Actform"),
 						 renderer, "text",
 						 
 						 COLUMN_FGR_ACTFORM,
@@ -554,7 +574,7 @@ polyxedit_fragment_opt_setup_fgs_treeview (GtkWidget *window,
 
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Comment",
+						 -1, _("Comment"),
 						 renderer, "text",
 						 
 						 COLUMN_FGR_COMMENT,
@@ -628,7 +648,7 @@ polyxedit_fragment_opt_create_fgs_treeview_model (GPtrArray *GPA)
       else if (fgs->end == PXM_FRAG_END_NONE)
 	help = g_strdup ("NE");
       else
-	g_critical (_("%s@%d: fragspec has a bad end.\n"),
+	g_critical (_("%s@%d: fragspec has an incorrect 'end' member.\n"),
 	       __FILE__, __LINE__);
 
       gtk_tree_store_set 
@@ -718,7 +738,9 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
   
   gboolean valid = FALSE;
   gboolean selected = FALSE;
-  
+
+  GString *fragopt_gs = NULL;
+    
   gint iter = 0;
   gint idx = 0;
   gint len = 0;
@@ -743,6 +765,11 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
   polchemdef = editctxt->polchemdefctxt->polchemdef;
   g_assert (polchemdef != NULL);
 
+  /* We will use this GString to construct a string describing the 
+     fragmentation options for the window registering function call below.
+  */
+  fragopt_gs = g_string_new ("");
+  
   /* We certainly will have to display some messages.
    */
   messages_entry = g_object_get_data (G_OBJECT (window),  
@@ -840,7 +867,18 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
 	 for us.
       */
       fragopt->fragspec = pxmchem_fragspec_dup (fragspec);
-      
+
+      /* Append to the fragopt_gs the current fragspec->name.
+       */
+      if (strlen (fragopt_gs->str) < 1)
+	g_string_append_printf (fragopt_gs, 
+				_("Fragmentation pattern(s): '%s' "), 
+				fragopt->fragspec->name);
+      else
+	g_string_append_printf (fragopt_gs, 
+				"; '%s' ", fragopt->fragspec->name);
+
+            
       /* We have our copy, just append it to the array of fragopt
 	 instances.
        */
@@ -861,7 +899,9 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
   if (fragoptGPA->len <= 0)
     {
       g_ptr_array_free (fragoptGPA, TRUE);
-      
+
+      g_string_free (fragopt_gs, TRUE);
+            
       return;
     }
   
@@ -923,7 +963,8 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
 				    calcopt))
 	{
 	  help = 
-	    g_strdup_printf (_("failed fragmenting the polymer with '%s'\n"),
+	    g_strdup_printf (_("Failed to fragment the polymer with "
+			       "fragspec, name: '%s'\n"),
 			     fragopt->fragspec->name);
 	  
 	  g_critical (_("%s@%d: %s"),
@@ -939,7 +980,9 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
 	  pxmchem_fragopt_GPA_free (fragoptGPA);
 
 	  pxmchem_calcopt_free (calcopt);
-	  
+
+	  g_string_free (fragopt_gs, TRUE);
+	  	  
 	  return;
 	}
       /* Add the newly filled array of oligomer to the array of
@@ -966,7 +1009,7 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
   if (display_window == NULL)
     {
       gtk_entry_set_text (GTK_ENTRY (messages_entry),
-			  _("Failed displaying the oligomers in a window"));
+			  _("Failed to display the oligomers in a window"));
       
       pxmchem_oligomer_GPA_of_GPA_free (allfragsGPA);
       
@@ -974,6 +1017,8 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
 
       pxmchem_calcopt_free (calcopt);
       
+      g_string_free (fragopt_gs, TRUE);
+
       return;
     }
 
@@ -994,29 +1039,111 @@ polyxedit_fragment_opt_wnd_fragment_button (GtkWidget *widget,
   */
   polyxedit_fragment_res_wnd_update_fragmentation_data (display_window);
   
+  /* Register the results' window !
+   */
+  /* Immediately set a automagically freeable string with the
+     description of the new allocated results window so that later
+     -during window management- we can describe what the window was
+     for. This will be used if the user asks to find masses in the
+     results and then a new window will be displayed with all the
+     masses that were found in the results window, and we will want to
+     display that description string.
+  */
+  help = g_strdup_printf (_("Fragmentation of '%p' With '%s'"), editctxt,
+			  fragopt_gs->str);
+  
+  g_object_set_data_full (G_OBJECT (display_window),
+			  "wnd_desc", help, 
+			  (GDestroyNotify) free);
+
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXEDIT",
+       display_window,
+       window,
+       editctxt,
+       _("Results of Fragmentation"),
+       help,
+       TRUE,
+       polyxedit_fragment_results_wnd_make_report))
+    g_critical (_("%s@%d: failed to register the fragmentation "
+		  "results' window\n"),
+		__FILE__, __LINE__);
+  
+  
+  /* Now that have done our text stuff, we can free the string.
+   */
+  g_string_free (fragopt_gs, TRUE);
+
+
   /* Finally we can return, our work here is finished.
    */
   return;
 }
 
 
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_fragment_opt_wnd_really_close (GtkWidget *window)
+{
+  g_assert (window != NULL);
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  gtk_widget_destroy (window);
+}
+
 
 
 gboolean
-polyxedit_fragment_opt_wnd_delete_event (GtkWidget *widget,
+polyxedit_fragment_opt_wnd_delete_event (GtkWidget *window,
 					   GdkEvent *event,
 					   gpointer data)
 {
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
+  
+  g_assert (window != NULL);
+  g_assert (editctxt != NULL);
+  
+
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("fragment_options_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+			     help);
+  
+  g_free (help);
+  
+  /* Let Gtk+ do the rest of the work.
+   */
   return FALSE;
 }
 
 
-
-
 gboolean
-polyxedit_fragment_opt_wnd_destroy_event (GtkWidget *widget,
-					   GdkEvent *event,
-					    gpointer data)
+polyxedit_fragment_opt_wnd_destroy_event (GtkWidget *window,
+					  GdkEvent *event,
+					  gpointer data)
 {
   return FALSE;
 }
