@@ -29,22 +29,29 @@
 */
 #include "polyxedit-ui-fragment-results.h"
 #include "polyxedit-ui-findmass-options.h"
+#include "polyxmass-window-mngmt.h"
+
 
 
 /* columns */
 
 enum
 {
-  /* Fragmentation specification name, "a" for example */
-  COLUMN_OLIG_FRAGSPEC_NAME = 0,
   /* Oligomer name, "a-4", "a-4-(fgr1)", "imm-I", for example */
-  COLUMN_OLIG_NAME,
+  COLUMN_OLIG_NAME = 0,
+
+  /* Fragmentation specification name, "a" for example */
+  COLUMN_OLIG_FRAGSPEC_NAME,
+
   /* Mono mass */
   COLUMN_OLIG_MONO,
+
   /* Average mass */
   COLUMN_OLIG_AVG,
+
   /* Contains modified monomers */
   COLUMN_OLIG_MODIFIED,
+
   /* Pointer to the oligomer */
   COLUMN_OLIG_POINTER,
 
@@ -94,7 +101,7 @@ polyxedit_fragment_res_wnd_setup (PxmEditCtxt *editctxt,
   
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -104,7 +111,7 @@ polyxedit_fragment_res_wnd_setup (PxmEditCtxt *editctxt,
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the fragmentation results window\n"),
+      g_error (_("%s@%d: failed to create the fragmentation results window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -138,7 +145,7 @@ polyxedit_fragment_res_wnd_setup (PxmEditCtxt *editctxt,
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else 
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 
   /* Set the polymer sequence context id number (its pointer) to its
      correspondent GtkEntry.
@@ -301,14 +308,6 @@ polyxedit_fragment_res_wnd_setup (PxmEditCtxt *editctxt,
 
   /* Finally the buttons of the window.
    */
-  widget = glade_xml_get_widget (xml, "fragment_results_wnd_close_button");
-  g_object_set_data (G_OBJECT (window),
-		     "fragment_results_wnd_close_button", widget);
-  g_signal_connect (G_OBJECT (widget),
-		    "clicked",
-		    G_CALLBACK (polyxedit_fragment_results_wnd_close_button),
-		    window);
-
   widget = glade_xml_get_widget (xml, "fragment_results_wnd_find_button");
   g_object_set_data (G_OBJECT (window),
 		     "fragment_results_wnd_find_button", widget);
@@ -326,13 +325,31 @@ polyxedit_fragment_res_wnd_setup (PxmEditCtxt *editctxt,
   g_signal_connect (G_OBJECT (window),
 		    "delete_event",
 		    G_CALLBACK (polyxedit_fragment_res_wnd_delete_event),
-		    window);
+		    editctxt);
   
   g_signal_connect (G_OBJECT (window),
 		    "destroy_event",
 		    G_CALLBACK (polyxedit_fragment_res_wnd_destroy_event),
-		    window);
+		    editctxt);
 
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
+
+     There might be more than one cleavage results' window opened for
+     a given polymer seqence editing window, and we do not want that
+     the second window destroys the datum name of the first window, so
+     we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("fragment_results_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_fragment_res_wnd_really_close);
+  
+  g_free (help);
+  
   return window;
 }
 
@@ -485,7 +502,7 @@ polyxedit_fragment_res_wnd_show_oligs (GtkWidget *window,
   count = g_object_get_data (G_OBJECT (model), "total_oligos");
   g_assert (count != NULL);
   
-  help = g_strdup_printf (_("Total number of oligomers: %d"),
+  help = g_strdup_printf (_("The total number of oligomers is: '%d'"),
 			  *count);
   
   polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
@@ -529,26 +546,29 @@ polyxedit_fragment_res_create_oligs_treeview_model (GPtrArray *allfragsGPA,
   
 
   model = gtk_tree_store_new (COLUMN_OLIG_COL_COUNT,
-			      /* Fragspec name */
+			      /* Oligo name COLUMN_OLIG_NAME*/
 			      G_TYPE_STRING,
-			      /* Oligo name */
+
+			      /* Fragspec name COLUMN_OLIG_FRAGSPEC_NAME*/
 			      G_TYPE_STRING,
-			      /* Mono mass */
+
+			      /* Mono mass COLUMN_OLIG_MONO*/
 			      G_TYPE_DOUBLE,
-			      /* Avg Mass */
+
+			      /* Avg Mass COLUMN_OLIG_AVG*/
 			      G_TYPE_DOUBLE,
-			      /* Modified */
+
+			      /* Modified COLUMN_OLIG_MODIFIED*/
 			      G_TYPE_BOOLEAN,
-			      /* Pointer to oligomer */
+
+			      /* Pointer to oligomer COLUMN_OLIG_POINTER*/
 			      G_TYPE_POINTER);
   
   count = g_malloc0 (sizeof (gint));
 
   /* Remember that the array that we get is an array of arrays.  This
-     array contains an array for each group of partial oligomers. Note
-     that if at least one oligomer is created, as the result of
-     cleaving a polymer sequence, it must be of partial cleavage 0,
-     because that partial cleavage is the default one.
+     array contains an array for each group of fragmentation
+     pattern-generated oligomers.
   */
   for (iter = 0; iter < allfragsGPA->len; iter++)
     {
@@ -584,10 +604,10 @@ polyxedit_fragment_res_create_oligs_treeview_model (GPtrArray *allfragsGPA,
 	  gtk_tree_store_set 
 	    (model, &treeiter,
 
-	     COLUMN_OLIG_FRAGSPEC_NAME, fragopt->fragspec->name,
-
 	     COLUMN_OLIG_NAME, oligomer->name,
 	     
+	     COLUMN_OLIG_FRAGSPEC_NAME, fragopt->fragspec->name,
+
 	     COLUMN_OLIG_MONO, oligomer->masspair->mono,
 	     
 	     COLUMN_OLIG_AVG, oligomer->masspair->avg,
@@ -726,33 +746,12 @@ polyxedit_fragment_res_setup_oligs_treeview (GtkWidget *window,
 		    (polyxedit_fragment_res_oligs_treeview_row_activated),
 		    window);
   
-  /* The fragmentation name column.
-   */
-  renderer = gtk_cell_renderer_text_new ();
-
-  column = 
-    gtk_tree_view_column_new_with_attributes ("Frag. Spec.",
-					      
-					      renderer, 
-					      
-					      "text",
-					      COLUMN_OLIG_FRAGSPEC_NAME,
-					      
-					      NULL);
-  
-  gtk_tree_view_column_set_sort_column_id (column, 
-					   COLUMN_OLIG_FRAGSPEC_NAME);
-
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-
   /* Oligomer name column.
    */
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Name",
+    gtk_tree_view_column_new_with_attributes (_("Name"),
 					      
 					      renderer, 
 					      
@@ -768,12 +767,41 @@ polyxedit_fragment_res_setup_oligs_treeview (GtkWidget *window,
   gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
 
+  gtk_tree_sortable_set_sort_func 
+    (GTK_TREE_SORTABLE (model),
+     COLUMN_OLIG_NAME,
+     polyxedit_fragment_res_wnd_sort_name_column,
+     NULL,
+     NULL);
+
+
+  /* The fragmentation name column.
+   */
+  renderer = gtk_cell_renderer_text_new ();
+
+  column = 
+    gtk_tree_view_column_new_with_attributes (_("Frag. Spec."),
+					      
+					      renderer, 
+					      
+					      "text",
+					      COLUMN_OLIG_FRAGSPEC_NAME,
+					      
+					      NULL);
+  
+  gtk_tree_view_column_set_sort_column_id (column, 
+					   COLUMN_OLIG_FRAGSPEC_NAME);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+
   /* Oligomer mono mass column.
    */
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mono Mass",
+    gtk_tree_view_column_new_with_attributes (_("Mono Mass"),
 					      
 					      renderer, 
 					      
@@ -793,7 +821,7 @@ polyxedit_fragment_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Avg Mass",
+    gtk_tree_view_column_new_with_attributes (_("Avg Mass"),
 					      
 					      renderer, 
 					      
@@ -813,7 +841,7 @@ polyxedit_fragment_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_toggle_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Modified",
+    gtk_tree_view_column_new_with_attributes (_("Modified"),
 					      
 					      renderer,
 					      
@@ -831,7 +859,7 @@ polyxedit_fragment_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
   
   column = 
-    gtk_tree_view_column_new_with_attributes ("Oligo. Pointer",
+    gtk_tree_view_column_new_with_attributes (_("Oligo. Pointer"),
 					      
 					      renderer,
 					      
@@ -935,7 +963,7 @@ polyxedit_fragment_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Position",
+    gtk_tree_view_column_new_with_attributes (_("Position"),
 					      
 					      renderer,
 					      
@@ -952,7 +980,7 @@ polyxedit_fragment_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Code",
+    gtk_tree_view_column_new_with_attributes (_("Code"),
 
 						 renderer, 
 
@@ -969,7 +997,7 @@ polyxedit_fragment_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Left End Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Left End Modif."),
 
 						 renderer, 
 
@@ -986,7 +1014,7 @@ polyxedit_fragment_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Monomer Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Monomer Modif."),
 
 						 renderer, 
 
@@ -1003,7 +1031,7 @@ polyxedit_fragment_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Right End Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Right End Modif."),
 
 						 renderer, 
 
@@ -1141,7 +1169,7 @@ polyxedit_fragment_res_olig_show_modification_data (PxmOligomer *oligomer,
 	 the whole parent sequence (array of monomers in the polymer,
 	 so that we can access the monomer in the array
 	 immediately. As a comparison, with the cleavage case we could
-	 easily do the computation because the numbering of the
+	 easily do the calculation because the numbering of the
 	 monomers always started from the left end of the polymer.
       */
       sscanf (prop->data, "%d/%d/%s", &offset, &index, modif);
@@ -1401,35 +1429,446 @@ polyxedit_fragment_res_olig_show_data (PxmOligomer *oligomer,
 
 
 
-void
-polyxedit_fragment_results_wnd_close_button (GtkWidget *widget, 
-					    gpointer data)
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_fragment_results_wnd_make_report (PxmReportOpt* reportopt,
+					    PxmWinMngmt* winmngmt)
 {
-  GtkWidget *window = data;
 
-  GPtrArray *allfragsGPA = NULL;
-  GPtrArray *fragoptGPA = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
   
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+  
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_fragment_results_wnd_make_report_text_format (reportopt,
+								   winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_fragment_results_wnd_make_report_latex_format (reportopt,
+								  winmngmt);
+  else
+    g_assert_not_reached ();
+    
+  return NULL;
+}
+
+
+
+gchar *
+polyxedit_fragment_results_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						      PxmWinMngmt* winmngmt)
+{
+  PxmCalcOpt *calcopt = NULL;
+
+  GtkWidget *window = NULL;
+  
+  gchar *report = NULL;
+  
+  GString *report_gs = NULL;
+  
+  PxmPolymer *polymer = NULL;
+
+  GtkTreeView *treeview = NULL;
+  GtkTreeStore *model;
+  GtkTreeIter treeiter;
+
+  PxmOligomer *oligomer = NULL;
+
+  PxmProp *prop = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+
+  g_assert (winmngmt->editctxt != NULL);
+  /* The window where the fragment results are displayed is in
+     'winmngmt->wnd'.
+   */
+  window = winmngmt->wnd;
   g_assert (window != NULL);
   
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
 
-  /* We have a full array of arrays of oligomers to free before
-     leaving this window! Also we have to free the array of fragopt
-     objects.
-  */
-  allfragsGPA = g_object_get_data (G_OBJECT (window), "allfragsGPA");
-  g_assert (allfragsGPA != NULL);
-  pxmchem_oligomer_GPA_of_GPA_free (allfragsGPA);
-
-  fragoptGPA = g_object_get_data (G_OBJECT (window), "fragoptGPA");
-  g_assert (fragoptGPA != NULL);
-  pxmchem_fragopt_GPA_free (fragoptGPA);
+  calcopt = g_object_get_data (G_OBJECT (window), "calcopt");
+  g_assert (calcopt != NULL);
   
-  /* Now we can safely destroy this window.
-   */
-  gtk_object_destroy (GTK_OBJECT (window));
 
-  return;
+  report_gs = g_string_new ("");
+
+  /* We have absolutely to describe the fragmentation options ! The
+     fact is: each fragmentation pattern is described in PxmFragOpt
+     instances allocated and stored in the fragoptGPA GPtrArray.
+
+     Since, during registering of this fragment results' window we had
+     stored the whole set of fragmentation patterns as a single string
+     in the winmngmt->comment member, we can use it for the
+     description of the current set of results.
+   */
+  g_assert (winmngmt != NULL);
+  
+  g_string_append_printf (report_gs, _("Fragmentation Options:\n"
+			  "----------------------\n"
+			  "Fragmentation Pattern(s): %s\n\n"),
+			  winmngmt->comment);
+  
+
+  if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_CALCOPTIONS) ==
+      PXM_OLM_REPORTOPT_CALCOPTIONS)
+    {
+      calcopt = g_object_get_data (G_OBJECT (window), "calcopt");
+      g_assert (calcopt != NULL);
+      
+      report_gs = 
+	g_string_append (report_gs, _("Calculations Options:\n"
+			 "---------------------\n"));
+
+      if (calcopt->capping & PXM_CAPPING_RIGHT && 
+	  calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: BOTH\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_RIGHT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: RIGHT\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: LEFT\n"));
+      
+      else
+	report_gs = g_string_append (report_gs, _("Capping: NONE\n"));
+	
+      if (calcopt->mnm_chement & PXMCHEMENT_MNM_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: MODIFS\n"));
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: NONE\n"));
+	
+      if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF
+	  && calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modifs: BOTH\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: LEFT\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: RIGHT\n"));
+	
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: NONE\n\n"));
+
+      /* We should indicate what sequence was fragmented ! Usually
+	 fragmentation is performed on small sequences !
+      */
+      g_string_append_printf (report_gs, 
+			      _("Fragmented Oligomer: [%d-%d]\n"),
+			      calcopt->start_idx + 1, 
+			      calcopt->end_idx + 1);
+      
+      /* Give the sequence of that fragmented oligomer.
+       */
+      report = pxmchem_polymer_make_codes_string (polymer,
+						  calcopt->start_idx,
+						  calcopt->end_idx);
+      g_assert (report != NULL);
+      
+      g_string_append_printf (report_gs, "%s\n\n", report);
+      
+      g_free (report);
+    }
+
+  /* Since we want to make a user-friendly report, we manage to have
+     the different oligomers reported in the order that the user has
+     set in the treeview (some of that treeview column are sortable).
+
+     Thus we iterate in the treeview instead of iterating in the
+     arrray of oligomers... Some tricky work is required to still
+     inform the user of the partial cleavage of each oligomer.
+  */
+  model = g_object_get_data (G_OBJECT (window), "oligomers_treeview_model");
+  g_assert (model != NULL);
+  
+  treeview = g_object_get_data (G_OBJECT (window), "oligomers_treeview");
+  g_assert (treeview != NULL);
+  
+  if (FALSE == gtk_tree_model_get_iter_first ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      g_warning (_("%s@%d: treeview is empty, nothing to report\n"),
+		 __FILE__, __LINE__);
+
+      report_gs = 
+	g_string_append (report_gs, _("Treeview is empty, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  else
+    {
+      /* We have the first item of the list here. Use it !
+       */
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+
+
+      g_string_append_printf (report_gs, "%-15s "
+			      "%-20s %-20s %-6s %-20s %-20s\n\n",
+			      _("name"), _("mono"), _("avg"), 
+			      _("Modif?"), _("LE-modif?"), _("RE-modif?")); 
+      
+
+
+
+      g_string_append_printf (report_gs, "%-15s ",
+			      oligomer->name);
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	  PXM_OLM_REPORTOPT_MONO_MASS 
+	  &&
+	  (reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	  PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono,
+				  oligomer->masspair->avg);
+	}
+	  
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	       PXM_OLM_REPORTOPT_MONO_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono, 0.0);
+	}
+
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	       PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  0.0, oligomer->masspair->avg);
+	}
+
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_PROP) == 
+	  PXM_OLM_REPORTOPT_PROP)
+	{
+	  /* See if the oligomer contains a modification... maybe not.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "POS/IDX/MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	      
+	  g_string_append_printf (report_gs, "%-6s ",
+				  (prop != NULL ? _("Yes") : _("No")));
+	  
+	  /* See if the oligomer is LEFT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "LEFT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s ",
+				  (prop != NULL ? 
+				   (gchar *) prop->data : _("No")));
+	  
+	  /* See if the oligomer is RIGHT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "RIGHT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s\n",
+				  (prop != NULL ? 
+				   (gchar *) prop->data : _("No")));
+	}
+      else
+	report_gs = g_string_append (report_gs, "\n");
+
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_SEQUENCE) == 
+	  PXM_OLM_REPORTOPT_SEQUENCE)
+	{
+	  /* When we created the oligomer, we may have created a string to
+	     represent the structure of the fragment.
+	  */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "SEQUENCE",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  if (prop != NULL)
+	    {
+	      /* We want to display the sequence in the report.
+	       */
+	      g_string_append_printf (report_gs, "%s\n", 
+				      (gchar *) prop->data);
+	    }
+	}
+    }
+  /*
+    End of successfully  getting the first item in the treeview.
+  */
+
+
+  /* And now continue to the remaining one in the while loop.
+   */
+  while (TRUE == gtk_tree_model_iter_next ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+      
+
+      g_string_append_printf (report_gs, "%-15s ",
+			      oligomer->name);
+      
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	  PXM_OLM_REPORTOPT_MONO_MASS 
+	  &&
+	  (reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	  PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono,
+				  oligomer->masspair->avg);
+	}
+	  
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_MONO_MASS) == 
+	       PXM_OLM_REPORTOPT_MONO_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  oligomer->masspair->mono, 0.0);
+	}
+
+      else if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_AVG_MASS) == 
+	       PXM_OLM_REPORTOPT_AVG_MASS)
+	{
+	  g_string_append_printf (report_gs, "%-20.5lf %-20.5lf ",
+				  0.0, oligomer->masspair->avg);
+	}
+
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_PROP) == 
+	  PXM_OLM_REPORTOPT_PROP)
+	{
+	  /* See if the oligomer contains a modification... maybe not.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "POS/IDX/MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	      
+	  g_string_append_printf (report_gs, "%-6s ",
+				  (prop != NULL ? _("Yes") : _("No")));
+	  
+	  /* See if the oligomer is LEFT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "LEFT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s ",
+				  (prop != NULL ? 
+				   (gchar *) prop->data : _("No")));
+	  
+	  /* See if the oligomer is RIGHT END-modified.
+	   */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "RIGHT_END_MODIF",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  
+	  g_string_append_printf (report_gs, "%-20s\n",
+				  (prop != NULL ? 
+				   (gchar *) prop->data : _("No")));
+	}
+      else
+	report_gs = g_string_append (report_gs, "\n");
+
+      if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_SEQUENCE) == 
+	  PXM_OLM_REPORTOPT_SEQUENCE)
+	{
+	  /* When we created the oligomer, we may have created a string to
+	     represent the structure of the fragment.
+	  */
+	  prop = libpolyxmass_prop_find_prop (oligomer->propGPA,
+					      NULL,
+					      NULL,
+					      "SEQUENCE",
+					      NULL,
+					      PXM_UNDEF_PROP_CMP);
+	  if (prop != NULL)
+	    {
+	      /* We want to display the sequence in the report.
+	       */
+	      g_string_append_printf (report_gs, "%s\n", 
+				      (gchar *) prop->data);
+	    }
+	}
+    }
+  /*
+    End of getting the remaining items in the treeview.
+  */
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+
+gchar *
+polyxedit_fragment_results_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+							 PxmWinMngmt* winmngmt)
+{
+  
+
+  return NULL;
 }
 
 
@@ -1441,6 +1880,8 @@ polyxedit_fragment_results_wnd_find_button (GtkWidget *widget, gpointer data)
   
   GPtrArray *GPA = NULL;
   
+  gchar *help = NULL;
+    
   g_assert (window != NULL);
   
 
@@ -1459,14 +1900,152 @@ polyxedit_fragment_results_wnd_find_button (GtkWidget *widget, gpointer data)
   
   if (window_new == NULL)
     {
-      g_critical (_("%s@%d: failed setting up the find mass options window\n"),
+      g_critical (_("%s@%d: failed to set up the find mass options window\n"),
 	     __FILE__, __LINE__);
     }
+
+  /* At this point we ought to set an explanation string to the
+     created window, so that we later can determine for what purpose
+     this window was created. This is particularly important to know
+     how to sort the names of the oligomers that will be displayed in
+     the findmass results window.
+  */
+  help = g_strdup ("FRAGMENT");
+  
+  g_object_set_data_full (G_OBJECT (window_new), 
+			  "oligomer_type", help,  
+			  (GDestroyNotify) g_free);
   
   return;
 }
 
 
+gint
+polyxedit_fragment_res_wnd_sort_name_column (GtkTreeModel *model,
+					     GtkTreeIter *a,
+					     GtkTreeIter *b,
+					     gpointer user_data)
+{
+  
+  gchar *name_a = NULL;
+  gchar *name_b = NULL;
+  
+  gchar *pattern_a = NULL;
+  gint number_a = -1;
+  
+  gchar *pattern_b = NULL;
+  gint number_b = -1;
+  
+  
+
+  /* We get the pointer to two different items in the treeview (the
+     model actually) and we need to access the data in them and then
+     tell which is greater to the other.
+  */
+  gtk_tree_model_get (model, a, 
+		      COLUMN_OLIG_NAME, &name_a,
+		      -1);
+
+  gtk_tree_model_get (model, b, 
+		      COLUMN_OLIG_NAME, &name_b,
+		      -1);
+
+  pxmchem_fragment_parse_name (name_a,
+			       &pattern_a,
+			       &number_a);
+
+  pxmchem_fragment_parse_name (name_b,
+			       &pattern_b,
+			       &number_b);
+
+  if (strcmp (pattern_a, pattern_b) == 0)
+    {
+      if (number_a == number_b)
+	{
+	  g_free (pattern_a);
+	  g_free (pattern_b);
+	  
+	  return 0;
+	}
+      
+      g_free (pattern_a);
+      g_free (pattern_b);
+	  
+      return (number_a > number_b) ? 1 : -1;
+    }
+  else
+    {
+      if (strcmp (pattern_a, pattern_b) > 0)
+	{
+	  g_free (pattern_a);
+	  g_free (pattern_b);
+	  
+	  return 1;
+	}
+      
+      else
+	{
+	  g_free (pattern_a);
+	  g_free (pattern_b);
+	  
+	  return -1;
+	}
+    }
+  
+  g_free (pattern_a);
+  g_free (pattern_b);
+	  
+  return 0;
+}
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_fragment_res_wnd_really_close (GtkWidget *window)
+{
+  gint count = 0;
+
+  GPtrArray *allfragsGPA = NULL;
+  GPtrArray *fragoptGPA = NULL;
+
+  g_assert (window != NULL);
+
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* We have a full array of arrays of oligomers to free before
+     leaving this window! Also we have to free the array of fragopt
+     objects.
+  */
+  allfragsGPA = g_object_get_data (G_OBJECT (window), "allfragsGPA");
+  g_assert (allfragsGPA != NULL);
+  count += pxmchem_oligomer_GPA_of_GPA_free (allfragsGPA);
+
+  fragoptGPA = g_object_get_data (G_OBJECT (window), "fragoptGPA");
+  g_assert (fragoptGPA != NULL);
+  pxmchem_fragopt_GPA_free (fragoptGPA);
+
+  /*
+    debug_printf (("freed %d oligomers\n", count));
+  */
+  
+  gtk_widget_destroy (window);
+}
+
 
 
 gboolean
@@ -1475,36 +2054,56 @@ polyxedit_fragment_res_wnd_delete_event (GtkWidget *window,
 					   gpointer data)
 {
   gint count = 0;
-  
+
   GPtrArray *allfragsGPA = NULL;
   GPtrArray *fragoptGPA = NULL;
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
+  
+  g_assert (window != NULL);
+  g_assert (editctxt != NULL);
+  
 
+
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
   /* We have a full array of arrays of oligomers to free before
      leaving this window! Also we have to free the array of fragopt
      objects.
   */
-  g_assert (window != NULL);
-  
   allfragsGPA = g_object_get_data (G_OBJECT (window), "allfragsGPA");
   g_assert (allfragsGPA != NULL);
-  pxmchem_oligomer_GPA_of_GPA_free (allfragsGPA);
+  count += pxmchem_oligomer_GPA_of_GPA_free (allfragsGPA);
 
   fragoptGPA = g_object_get_data (G_OBJECT (window), "fragoptGPA");
   g_assert (fragoptGPA != NULL);
   pxmchem_fragopt_GPA_free (fragoptGPA);
 
-  /* 
-     Prior to closing the window, we want to make sure that no
-     pending timed-out messages are there...
-  */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
-  
   /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
+    debug_printf (("freed %d oligomers\n", count));
   */
 
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("fragment_results_wnd-%p", window);
   
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+			     help);
+  
+  g_free (help);
+
   /* Let Gtk+ do the rest of the work.
    */
   return FALSE;
