@@ -70,7 +70,7 @@ polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt)
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -80,7 +80,7 @@ polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the monomeric composition window\n"),
+      g_critical (_("%s@%d: failed to create the monomeric composition window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -147,7 +147,7 @@ polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt)
   */
   polyxedit_mnmcompos_wnd_update_sequence_region_button (NULL, window);
 
-  /* The checkbutton that says if we want the computation to be
+  /* The checkbutton that says if we want the calculation to be
      incremental or not.
   */
   widget = glade_xml_get_widget (xml, "incremental_checkbutton");
@@ -186,7 +186,7 @@ polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt)
   */
   if (FALSE == polyxedit_mnmcompos_wnd_setup_treeview (window))
     {
-      g_critical (_("%s@%d: failed setting up the monomer treeview\n"),
+      g_critical (_("%s@%d: failed to set up the monomer treeview\n"),
 	     __FILE__, __LINE__);
 
        g_object_unref (G_OBJECT (xml));
@@ -251,6 +251,24 @@ polyxedit_mnmcompos_wnd_setup (PxmEditCtxt *editctxt)
   /* At this point we should be able to display the data.
    */
   polyxedit_mnmcompos_wnd_update_list_monomer (window);
+
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
+
+     There might be more than one composition results' window opened
+     for a given polymer seqence editing window, and we do not want
+     that the second window destroys the datum name of the first
+     window, so we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("mnmcompos_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_mnmcompos_wnd_really_close);
+  
+  g_free (help);
   
   return window;
 }
@@ -709,8 +727,8 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
 
   PxmCompcalcRes res = PXM_COMPCALC_FAILURE;
   
-  gint start_idx = 0;
-  gint end_idx = 0;
+  gint *start_idx = NULL;
+  gint *end_idx = NULL;
   
   gchar *help = NULL;
 
@@ -730,7 +748,14 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
   g_assert (editctxt->polymer->monomerGPA != NULL);
   len = editctxt->polymer->monomerGPA->len;
     
-  /* We must check if the user wants that the computation be made for
+
+
+  start_idx = g_malloc0 (sizeof (gint));
+  end_idx = g_malloc0 (sizeof (gint));
+  
+
+
+  /* We must check if the user wants that the calculation be made for
      the whole sequence or for the selection region of the polymer sequence
      only, or for the interval that is defined with the start_pos and 
      end_pos entry widgets.
@@ -741,8 +766,8 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
 
   if (TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     {
-      start_idx = 0;
-      end_idx = len;
+      *start_idx = 0;
+      *end_idx = len;
     }
   else
     {
@@ -756,15 +781,15 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
       
       if (strlen (help) <= 0)
 	{
-	  start_idx = 0;
+	  *start_idx = 0;
 	}
       else
 	{
 	  /* There is a string in the entry. Convert it to gint.
 	   */
 	  if (FALSE == 
-	      libpolyxmass_globals_strtoi (help, &start_idx, 10))
-	    start_idx = 0;
+	      libpolyxmass_globals_strtoi (help, start_idx, 10))
+	    *start_idx = 0;
 	  else
 	    {
 	      /* Remember that the user "counts" monomers starting at 1,
@@ -772,7 +797,7 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
 		 and not positions. So decrement by one the value entered
 		 by the user.
 	      */
-	      start_idx--;
+	      *(start_idx)--;
 	    }
 	}
       
@@ -784,18 +809,18 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
       
       if (strlen (help) <= 0)
 	{
-	  end_idx = 0;
+	  *end_idx = 0;
 	}
       else
 	{
 	  /* There is a string in the entry. Convert it to gint.
 	   */
 	  if (FALSE == 
-	      libpolyxmass_globals_strtoi (help, &end_idx, 10))
-	    end_idx = 0;
+	      libpolyxmass_globals_strtoi (help, end_idx, 10))
+	    *end_idx = 0;
 	  else
 	    {
-	      /* Remember that for the end_idx, the computations need
+	      /* Remember that for the end_idx, the calculations need
 		 to have it incremented by one with respect to the real
 		 last monomer index. So, contrary to start_idx, we do not
 		 change its value.
@@ -808,21 +833,21 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
       /* Now make some final checks:
        */
 
-      if (start_idx > len)
-	start_idx = len;
+      if (*start_idx > len)
+	*start_idx = len;
 
-      if (start_idx < 0)
-	start_idx = 0;
+      if (*start_idx < 0)
+	*start_idx = 0;
       
-      if (end_idx > len)
-	end_idx = len;
+      if (*end_idx > len)
+	*end_idx = len;
 
-      if (end_idx < 0)
-	end_idx = 0;
+      if (*end_idx < 0)
+	*end_idx = 0;
     }
 
 
-  /* If the user wants not that the computations be incremental, 
+  /* If the user wants not that the calculations be incremental, 
      we first have to empty the array of atomcounts.
   */
   widget = 
@@ -832,17 +857,17 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
   if (FALSE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     pxmchem_monomer_GPA_empty (monomerGPA);
   
-  /* We finally have all needed to perform the computation:
+  /* We finally have all needed to perform the calculation:
    */
   res = pxmchem_mnmcompcalc_polymer (editctxt->polymer,
 				     monomerGPA,
 				     editctxt->polchemdefctxt->polchemdef,
-				     start_idx, 
-				     end_idx);
+				     *start_idx, 
+				     *end_idx);
   if (res != PXM_COMPCALC_SUCCESS)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					     _("Computation failed"),
+					     _("Calculation failed"),
 					     POLYXMASS_NORM_MSG_TIMEOUT);
     }
   else
@@ -859,11 +884,25 @@ polyxedit_mnmcompos_wnd_execute_button (GtkWidget *button,
 					   POLYXMASS_NORM_MSG_TIMEOUT);
       else
 	polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					   _("Computation successful"),
+					   _("Calculation succeeded"),
 					   POLYXMASS_NORM_MSG_TIMEOUT);
     }
+
+  /* Set a full data the pointer to the start_idx and end_idx 
+     integers so that we can ask for them in another part of the 
+     file.
+
+     Note that the g_object_set_data_full calls below will elicit
+     freeing of potentially pre-existing instances using their
+     respective freeing functions.
+  */
+  g_object_set_data_full (G_OBJECT (window), "start_idx", start_idx,
+			  (GDestroyNotify) g_free);
   
-  return;
+  g_object_set_data_full (G_OBJECT (window), "end_idx", end_idx,
+			  (GDestroyNotify) g_free);
+  
+  return; 
 }
 
 
@@ -949,29 +988,292 @@ polyxedit_mnmcompos_wnd_update_sequence_region_button (GtkWidget *button,
 
 
 
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_mnmcompos_wnd_make_report (PxmReportOpt* reportopt,
+					  PxmWinMngmt* winmngmt)
+{
+  
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_mnmcompos_wnd_make_report_text_format (reportopt,
+							    winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_mnmcompos_wnd_make_report_latex_format (reportopt,
+							     winmngmt);
+  else
+    g_assert_not_reached ();
+  
+  return NULL;
+}
+
+
+
+gchar *
+polyxedit_mnmcompos_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+  GtkWidget *window = NULL;
+
+  gchar *report = NULL;
+  
+  GString *report_gs = NULL;
+
+  PxmPolymer *polymer = NULL;
+  PxmPlminfo *plminfo = NULL;
+
+  gint *start_idx = NULL;
+  gint *end_idx = NULL;
+  
+  GtkTreeView *treeview = NULL;
+  GtkListStore *model;
+  GtkTreeIter treeiter;
+
+  gint count = 0;
+  gchar *monomer_code;
+  gchar *monomer_name;
+    
+  gboolean modified = FALSE;
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  
+  window = winmngmt->wnd ;
+  g_assert (window != NULL);
+  
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
+
+  plminfo = polymer->plminfo;
+  g_assert (plminfo != NULL);
+
+  
+  report_gs = g_string_new ("");
+  
+  report_gs = pxmchem_polymer_format_txt_string_polseqinfo (plminfo,
+							    reportopt,
+							    report_gs);
+  
+  /* Tell for which sequence, the composition was performed. Get the
+     pointers to the allocated gint objects that were stored as full
+     data in the function that calculated the composition.
+
+     Note that these pointers might be NULL if no single calculation
+     was performed before asking for a report !
+   */
+  start_idx = g_object_get_data (G_OBJECT (window), "start_idx");
+  end_idx = g_object_get_data (G_OBJECT (window), "end_idx");
+
+  if (start_idx == NULL || end_idx == NULL)
+    {
+      g_warning (_("%s@%d: no calculation took place, nothing to report\n"),
+		 __FILE__, __LINE__);
+      
+      report_gs = 
+	g_string_append (report_gs, _("No calculation took place, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+     
+  /* OK, at this time, we know a calculation took place, so we can
+     make the report string.
+   */ 
+  g_string_append_printf (report_gs, _("Monomeric Composition:\n"
+			  "----------------------\n\n"
+			  "Selected sequence: [%d-%d]\n\n"),
+			  *(start_idx) + 1, *end_idx);
+  
+  /* Finally do the report work, with the items in the treeview sorted in the
+     way the user wanted them to be sorted...
+  */
+
+  /* Get the treeview that was setup the very first time the window was
+     opended. After, get the model and with the associated model.
+  */
+  treeview = (GtkTreeView *) g_object_get_data (G_OBJECT (window), 
+						"TREEVIEW");
+  
+  model = (GtkListStore *) gtk_tree_view_get_model (treeview);
+  
+  if (FALSE == gtk_tree_model_get_iter_first ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      g_warning (_("%s@%d: treeview is empty, nothing to report\n"),
+		 __FILE__, __LINE__);
+
+      report_gs = 
+	g_string_append (report_gs, _("Treeview is empty, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  else
+    {
+      /* We have the first item of the list here. Use it !
+       */
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+			  
+			  COMP_COLUMN_MNM_CODE, 
+			  &monomer_code,
+			  
+			  COMP_COLUMN_MNM_NAME, 
+			  &monomer_name,
+			  
+			  COMP_COLUMN_MNM_COUNT,
+			  &count,
+			  
+			  COMP_COLUMN_MNM_MODIFIED,
+			  &modified,
+			  
+			  -1);
+      
+      g_string_append_printf (report_gs, 
+			      "%s\t%s\t%d\t%s\n",
+			      monomer_code, monomer_name, count,
+			      (modified == TRUE ? 
+			       _("Modifications\n") : _("No Modification\n")));
+    }
+  
+  /* And now continue to the remaining one in the while loop.
+   */
+  while (TRUE == gtk_tree_model_iter_next ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+			  
+			  COMP_COLUMN_MNM_CODE, 
+			  &monomer_code,
+			  
+			  COMP_COLUMN_MNM_NAME, 
+			  &monomer_name,
+			  
+			  COMP_COLUMN_MNM_COUNT,
+			  &count,
+			  
+			  COMP_COLUMN_MNM_MODIFIED,
+			  &modified,
+			  
+			  -1);
+      
+      g_string_append_printf (report_gs, 
+			      "%s\t%s\t%d\t%s\n",
+			      monomer_code, monomer_name, count,
+			      (modified == TRUE ? 
+			       _("Modification(s)\n") : _("No Modification\n")));
+    }
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+
+gchar *
+polyxedit_mnmcompos_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+
+  return NULL;
+  
+}
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_mnmcompos_wnd_really_close (GtkWidget *window)
+{
+
+  g_assert (window != NULL);
+  
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  
+  /* Make sure we unref all the pixbufs that were reffed.
+   */
+  polyxedit_mnmcompos_wnd_empty_list_monomer (window);
+
+
+  gtk_widget_destroy (window);
+}
+
+
 
 gint 
 polyxedit_mnmcompos_wnd_delete_event (GtkWidget *window, 
 					GdkEventAny *event, 
 				       gpointer data)
 {
-  gint count = 0;
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
+  
+  g_assert (window != NULL);
+  g_assert (editctxt != NULL);
+  
+
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
   
   /* Make sure we unref all the pixbufs that were reffed.
    */
   polyxedit_mnmcompos_wnd_empty_list_monomer (window);
 
-  /* 
-     Prior to closing the window, we want to make sure that no
-     pending timed-out messages are there...
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  help = g_strdup_printf ("mnmcompos_wnd-%p", window);
   
-  /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
-  */
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+			 help);
   
+  g_free (help);
+  
+  /* Let Gtk+ do the rest of the work.
+   */
   return FALSE;
 }
 
