@@ -74,7 +74,7 @@ polyxedit_ui_monomer_modif_setup_wnd (PxmEditCtxt *editctxt)
   
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -84,7 +84,7 @@ polyxedit_ui_monomer_modif_setup_wnd (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the monomer modification window\n"),
+      g_critical (_("%s@%d: failed to create the monomer modification window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -235,10 +235,10 @@ polyxedit_ui_monomer_modif_setup_wnd (PxmEditCtxt *editctxt)
    */
   g_object_unref (G_OBJECT (xml));
 
-  /* And now that we know all the window is set up, we can 
-     fill the data in it: the list of available modifications, the list
-     of the monomers in the polymer definition context, the position
-     of the possibly selected monomer...
+  /* And now that we know all the window is set up, we can fill the
+     data in it: the list of available modifications, the list of the
+     monomers in the polymer chemistry definition context, the
+     position of the possibly selected monomer...
   */
 
   /* First the index of the currently selected monomer. Function returns
@@ -338,7 +338,8 @@ polyxedit_ui_monomer_modif_setup_wnd (PxmEditCtxt *editctxt)
     }
   
   /* Second fill the treeview of modifications avaialable to the
-     polymer definition context of that specific polymer sequence.
+     polymer chemistry definition context of that specific polymer
+     sequence.
   */
   treeview = 
     GTK_TREE_VIEW (g_object_get_data (G_OBJECT (window), 
@@ -350,12 +351,13 @@ polyxedit_ui_monomer_modif_setup_wnd (PxmEditCtxt *editctxt)
 							polchemdefctxt->
 							polchemdef))
     {
-      g_critical (_("%s@%d: failed filling the modifications list\n"),
+      g_critical (_("%s@%d: failed to fill the modifications list\n"),
 	     __FILE__, __LINE__);
     }
   
   /* Third fill the treeview of all the monomer codes present in the
-     polymer definition context of that specific polymer sequence.
+     polymer chemistry definition context of that specific polymer
+     sequence.
   */
   treeview = 
     GTK_TREE_VIEW (g_object_get_data (G_OBJECT (window), 
@@ -367,7 +369,7 @@ polyxedit_ui_monomer_modif_setup_wnd (PxmEditCtxt *editctxt)
 							    polchemdefctxt->
 							    polchemdef))
     {
-      g_critical (_("%s@%d: failed filling the monomer codes list\n"),
+      g_critical (_("%s@%d: failed to fill the monomer codes list\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -479,7 +481,7 @@ polyxedit_ui_monomer_modif_setup_modifs_treeview (GtkTreeView *treeview,
     GtkTreeViewColumn *column = NULL;
     
     column = 
-    gtk_tree_view_column_new_with_attributes ("Name", 
+    gtk_tree_view_column_new_with_attributes (_("Name"), 
     renderer,
     "text", COLUMN_MDF_NAME,
     NULL); 
@@ -489,7 +491,7 @@ polyxedit_ui_monomer_modif_setup_modifs_treeview (GtkTreeView *treeview,
   
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Name", renderer,
+     -1, _("Name"), renderer,
      "text", COLUMN_MDF_NAME,
      "editable", COLUMN_MDF_EDITABLE,
      NULL);
@@ -504,7 +506,7 @@ polyxedit_ui_monomer_modif_setup_modifs_treeview (GtkTreeView *treeview,
 
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Formula", renderer,
+     -1, _("Actform"), renderer,
      "text", COLUMN_MDF_ACTFORM,
      "editable", COLUMN_MDF_EDITABLE,
      NULL);
@@ -589,7 +591,7 @@ polyxedit_ui_monomer_modif_setup_monomcodes_treeview (GtkTreeView *treeview,
     GtkTreeViewColumn *column = NULL;
     
     column = 
-    gtk_tree_view_column_new_with_attributes ("Name", 
+    gtk_tree_view_column_new_with_attributes (_("Name"), 
     renderer,
     "text", COLUMN_MNM_NAME,
     NULL); 
@@ -599,7 +601,7 @@ polyxedit_ui_monomer_modif_setup_monomcodes_treeview (GtkTreeView *treeview,
   
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Name", renderer,
+     -1, _("Name"), renderer,
      "text", COLUMN_MNM_NAME,
      "editable", COLUMN_MNM_EDITABLE,
      NULL);
@@ -614,7 +616,7 @@ polyxedit_ui_monomer_modif_setup_monomcodes_treeview (GtkTreeView *treeview,
 
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Code", renderer,
+     -1, _("Code"), renderer,
      "text", COLUMN_MNM_CODE,
      "editable", COLUMN_MNM_EDITABLE,
      NULL);
@@ -629,7 +631,7 @@ polyxedit_ui_monomer_modif_setup_monomcodes_treeview (GtkTreeView *treeview,
 
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Formula", renderer,
+     -1, _("Formula"), renderer,
      "text", COLUMN_MNM_FORMULA,
      "editable", COLUMN_MNM_EDITABLE,
      NULL);
@@ -754,8 +756,8 @@ polyxedit_ui_monomer_modif_modify_button (GtkWidget *button,
   if (render_failure != 0 || chem_failure != 0 || full_success != 0)
     polyxedit_seqed_wnd_set_polymer_modified (editctxt, TRUE);
   
-  help = g_strdup_printf (_("full success = %d; full_failure = %d; "
-			    "chem_failure = %d; render_failure = %d"),
+  help = g_strdup_printf (_("Full success = %d; Full failure = %d; "
+			    "Chem failure = %d; Render failure = %d"),
 			  full_success, full_failure, 
 			  chem_failure, render_failure);
   
@@ -932,8 +934,8 @@ polyxedit_ui_monomer_modif_un_modify_button (GtkWidget *button,
   if (render_failure != 0 || chem_failure != 0 || full_success != 0)
     polyxedit_seqed_wnd_set_polymer_modified (editctxt, TRUE);
   
-  help = g_strdup_printf (_("full success = %d; full_failure = %d; "
-			    "chem_failure = %d; render_failure = %d"),
+  help = g_strdup_printf (_("Full success = %d; Full failure = %d; "
+			    "Chem failure = %d; Render failure = %d"),
 			  full_success, full_failure, 
 			  chem_failure, render_failure);
   
@@ -1225,7 +1227,7 @@ polyxedit_ui_monomer_modif_prepare_indices_array (GtkWidget *window,
       max = editctxt->polymer->monomerGPA->len - 1;
       
       if (-1 == libpolyxmass_globals_fill_int_array_match_exp (text, GA, max))
-	g_critical (_("%s@%d: error while processing string '%s'\n"),
+	g_critical (_("%s@%d: failed to process string: '%s'\n"),
 	       __FILE__, __LINE__, text);
       
       g_free (text);
@@ -1285,7 +1287,7 @@ polyxedit_ui_monomer_modif_get_target (GtkWidget *window)
 	    return MODIF_TARGET_SPEC_POS_MONOMERS;
 
 	  else
-	    g_warning (_("%s@%d: failed getting the radiobutton widget\n"),
+	    g_warning (_("%s@%d: failed to get the radiobutton widget\n"),
 		   __FILE__, __LINE__);
 	}
 
