@@ -92,7 +92,7 @@ polyxedit_note_setup_wnd (PxmEditCtxt *editctxt,
   
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -102,7 +102,7 @@ polyxedit_note_setup_wnd (PxmEditCtxt *editctxt,
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the note window\n"),
+      g_error (_("%s@%d: failed to create the note management window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -173,7 +173,7 @@ polyxedit_note_setup_wnd (PxmEditCtxt *editctxt,
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else 
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 
   /* Set the polymer sequence context id number (its pointer) to its
      correspondent GtkEntry.
@@ -415,7 +415,7 @@ polyxedit_note_setup_wnd (PxmEditCtxt *editctxt,
 	  polyxedit_note_wnd_setup_note_treeview (window,
 						  monomer->propGPA))
 	{
-	  g_critical (_("%s@%d: failed filling treeview with monomer note(s)\n"),
+	  g_critical (_("%s@%d: failed to fill treeview with monomer note(s)\n"),
 		 __FILE__, __LINE__);
 	  
 	  gtk_object_destroy (GTK_OBJECT (window));
@@ -430,7 +430,7 @@ polyxedit_note_setup_wnd (PxmEditCtxt *editctxt,
 						  editctxt->
 						  polymer->propGPA))
 	{
-	  g_critical (_("%s@%d: failed filling treeview with polymer note(s)\n"),
+	  g_critical (_("%s@%d: failed to fill treeview with polymer note(s)\n"),
 		 __FILE__, __LINE__);
 	  
 	  g_object_unref (G_OBJECT (window));
@@ -572,7 +572,7 @@ polyxedit_note_wnd_setup_note_treeview (GtkWidget *widget,
   
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Name",
+						 -1, _("Name"),
 						 renderer, 
 						 "text",
 						 
@@ -597,7 +597,7 @@ polyxedit_note_wnd_setup_note_treeview (GtkWidget *widget,
   
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Value",
+						 -1, _("Value"),
 						 renderer, 
 						 "text",
 						 
@@ -622,7 +622,7 @@ polyxedit_note_wnd_setup_note_treeview (GtkWidget *widget,
   
   col_offset = 
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-						 -1, "Type",
+						 -1, _("Type"),
 						 renderer, 
 						 "text",
 						 
@@ -775,8 +775,7 @@ polyxedit_note_wnd_setup_note_treemodel (GPtrArray *GPA)
 	      continue;
 	    }
 	  else
-	    g_error (_("%s@%d: the type of the note's value is incorrect."
-		     " Exiting.\n"),
+	    g_error (_("%s@%d: the type of the note's value is incorrect.\n"),
 		   __FILE__, __LINE__);
 	}
 	  
@@ -1163,7 +1162,7 @@ polyxedit_note_wnd_value_add_button (GtkWidget *widget,
 	  
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("The value contents are not an integer. Operation cancelled."),
+	     _("The value content is not an integer. Operation cancelled."),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  return;
@@ -1185,7 +1184,7 @@ polyxedit_note_wnd_value_add_button (GtkWidget *widget,
 	  
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("The value contents are not a double. Operation cancelled."),
+	     _("The value content is not a double. Operation cancelled."),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  return;
@@ -1443,7 +1442,7 @@ polyxedit_note_wnd_value_apply_button (GtkWidget *widget,
 	  
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("The value contents are not an integer. Operation cancelled."),
+	     _("The value content is not an integer. Operation cancelled."),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  return;
@@ -1465,7 +1464,7 @@ polyxedit_note_wnd_value_apply_button (GtkWidget *widget,
 	  
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("The value contents are not a double. Operation cancelled."),
+	     _("The value content is not a double. Operation cancelled."),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  return;
@@ -2770,9 +2769,9 @@ polyxedit_note_wnd_selected_item_propagate (GtkMenuItem *menuitem,
 		       GTK_DIALOG_DESTROY_WITH_PARENT,
 		       GTK_MESSAGE_WARNING,
 		       GTK_BUTTONS_OK,
-		       _("Skipped monomer '%s' at position "
+		       _("Skipped monomer: '%s' at position: "
 			 "'%d' already having a note by the "
-			 "same name '%s'"),
+			 "same name: '%s'"),
 		       monomer->code, iter + 1, 
 		       note_iter->name);
   
