@@ -63,7 +63,7 @@ polyxedit_pka_ph_pi_wnd_setup (PxmEditCtxt *editctxt)
   
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       g_free (gui_file);
@@ -75,7 +75,7 @@ polyxedit_pka_ph_pi_wnd_setup (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the acido-basic config window\n"),
+      g_critical (_("%s@%d: failed to create the acido-basicity calculations configuration window\n"),
 	     __FILE__, __LINE__);
       
       g_object_unref (G_OBJECT (xml));
@@ -188,26 +188,26 @@ polyxedit_pka_ph_pi_wnd_setup (PxmEditCtxt *editctxt)
   g_object_set_data (G_OBJECT (window),
 		     "net_charge_entry", widget);
 
-  widget = glade_xml_get_widget (xml, "compute_net_charge_button");
+  widget = glade_xml_get_widget (xml, "calculate_net_charge_button");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (window),
-		     "compute_net_charge_button", widget);
+		     "calculate_net_charge_button", widget);
 
   g_signal_connect (G_OBJECT (widget),
 		    "clicked",
 		    G_CALLBACK 
-		    (polyxedit_pka_ph_pi_wnd_compute_net_charge_button), 
+		    (polyxedit_pka_ph_pi_wnd_calculate_net_charge_button), 
 		    window);
 
-  widget = glade_xml_get_widget (xml, "compute_isoelectric_point_button");
+  widget = glade_xml_get_widget (xml, "calculate_isoelectric_point_button");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (window),
-		     "compute_isoelectric_point_button", widget);
+		     "calculate_isoelectric_point_button", widget);
 
   g_signal_connect (G_OBJECT (widget),
 		    "clicked",
 		    G_CALLBACK 
-		    (polyxedit_pka_ph_pi_wnd_compute_pi_button), 
+		    (polyxedit_pka_ph_pi_wnd_calculate_pi_button), 
 		    window);
 
 
@@ -293,7 +293,7 @@ polyxedit_pka_ph_pi_wnd_get_sequence_interval (GtkWidget *window,
     }
   
 
-  /* We must check if the user wants that the computation be made for
+  /* We must check if the user wants that the calculation be made for
      the whole sequence or for the selection region of the polymer sequence
      only, or for the interval that is defined with the start_pos and 
      end_pos entry widgets.
@@ -356,7 +356,7 @@ polyxedit_pka_ph_pi_wnd_get_sequence_interval (GtkWidget *window,
 	    end = 0;
 	  else
 	    {
-	      /* Remember that for the *end_idx, the computations need
+	      /* Remember that for the *end_idx, the calculations need
 		 to have it incremented by one with respect to the real
 		 last monomer index. So, contrary to start_idx, we do not
 		 change its value.
@@ -474,10 +474,11 @@ polyxedit_pka_ph_pi_wnd_sequence_region_button (GtkWidget *button,
    processed.
  */
 gint
-polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
+polyxedit_pka_ph_pi_wnd_calculate_net_charge_button (GtkWidget *button,
 						   gpointer data)
 {
   GtkWidget *window = data;
+  GtkWidget *pi_widget = NULL;
   GtkWidget *ph_widget = NULL;
   GtkWidget *charges_widget = NULL;
 
@@ -494,7 +495,7 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
   gdouble *positive_charges = NULL;
   gdouble *negative_charges = NULL;
     
-  /* We are asked to compute the net charge of the polymer sequence
+  /* We are asked to calculate the net charge of the polymer sequence
      (or its interval) for the pH currently displayed in the
      corresponding spinbutton widget.
   */
@@ -503,7 +504,7 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
   /* Note that the charges holders (gdouble *) are allocated when the
      window is set up, so we first have to get the pointers out of the
      window ! Of course we have to reset them to 0 prior to performing
-     the new computation.
+     the new calculation.
   */
   negative_charges = g_object_get_data (G_OBJECT (window),
 					"negative_charges");
@@ -531,11 +532,23 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
   
   ph = gtk_spin_button_get_value (GTK_SPIN_BUTTON (ph_widget));
 
-  if (ph < 0 || ph > 14)
+
+  if (ph <= 0 || ph >= 14)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
 					_("pH value is not acceptable."),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
+
+      /* We do not want that the user makes fake reports if no
+	 calculation was succcessful. See the end of the function for
+	 an explanation of the function call below. It will
+	 automagically free any old calcopt instance previously stored
+	 as datum in the 'window'. Thus, when the user will try to
+	 make a report, it will not be made because no 'calcopt'
+	 pointer is available in the 'window'.
+      */
+      g_object_set_data (G_OBJECT (window), "calcopt", NULL);
+      
       return -1;
     }
   
@@ -545,7 +558,7 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
    */
   calcopt = pxmchem_calcopt_dup (editctxt->calcopt);
 
-  /* Get the sequence interval for which the computation should be
+  /* Get the sequence interval for which the calculation should be
      performed.
    */
   if (FALSE ==  
@@ -554,30 +567,54 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
 						     &calcopt->end_idx))
   {
     polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-				      _("Failed getting sequence interval."),
+				      _("Failed to get sequence interval."),
 				      POLYXMASS_MEDI_MSG_TIMEOUT);
-
+    
+    /* Free this newly allocated calcopt object.
+     */
     pxmchem_calcopt_free (calcopt);
     
+    /* We do not want that the user makes fake reports if no
+       calculation was succcessful. See the end of the function
+       for an explanation of the function call below. It will
+       automagically free any old calcopt instance previously
+       stored as datum in the 'window'. Thus, when the user will
+       try to make a report, it will not be made because no
+       'calcopt' pointer is available in the 'window'.
+    */
+    g_object_set_data (G_OBJECT (window), "calcopt", NULL);
+    
     return -1;
   }
   
   /* At this point we have all the requisites to work on the net charge
-     computation.
+     calculation.
   */
   processed_chemgroups =
-    polyxedit_acidobasic_polseq_compute_net_charge (editctxt, ph,
+    polyxedit_acidobasic_polseq_calculate_net_charge (editctxt, ph,
 						    calcopt,
 						    negative_charges,
 						    positive_charges);
   if (-1 == processed_chemgroups)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					_("Failed computing net charge."),
+					_("Failed to calculate net charge."),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       
+      /* Free this newly allocated calcopt object.
+       */
       pxmchem_calcopt_free (calcopt);
       
+      /* We do not want that the user makes fake reports if no
+	 calculation was succcessful. See the end of the function
+	 for an explanation of the function call below. It will
+	 automagically free any old calcopt instance previously
+	 stored as datum in the 'window'. Thus, when the user will
+	 try to make a report, it will not be made because no
+	 'calcopt' pointer is available in the 'window'.
+      */
+      g_object_set_data (G_OBJECT (window), "calcopt", NULL);
+      
       return -1;
     }
 
@@ -590,6 +627,16 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
 		 processed_chemgroups));
   */
   
+  /* Immediately make clear that we have calculated the pI by setting to
+     nothing the text in the pH combo-entry.
+  */
+  pi_widget = g_object_get_data (G_OBJECT (window), 
+			      "isoelectric_point_entry");
+  g_assert (pi_widget != NULL);
+
+  gtk_entry_set_text (GTK_ENTRY (pi_widget), "0.00000");
+  
+
   charges_widget = g_object_get_data (G_OBJECT (window), 
 				      "negative_charges_entry");
   g_assert (charges_widget != NULL);
@@ -619,13 +666,26 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
   gtk_entry_set_text (GTK_ENTRY (charges_widget), help);
   
   g_free (help);
-
-  pxmchem_calcopt_free (calcopt);
-
+  
+  g_object_set_data (G_OBJECT (window), "calcopt", calcopt);
+      
   polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
 				    _("Operation completed."),
 				    POLYXMASS_NORM_MSG_TIMEOUT);
 
+  /* Since we might have to write a report about this calculation, we
+     have to be able to know with which calculation  options
+     the calculation was performed. Thus, we store this information as
+     full data to the window, for later enquiry. See
+     polyxedit_pka_ph_pi_wnd_make_report_text_format() for details !
+
+     Note that the g_object_set_data_full call below will elicit
+     freeing of potentially pre-existing instances using their
+     respective freeing functions.
+  */
+  g_object_set_data_full (G_OBJECT (window), "calcopt", calcopt,
+			  (GDestroyNotify) pxmchem_calcopt_free);
+
   return processed_chemgroups;
 }
 
@@ -637,7 +697,7 @@ polyxedit_pka_ph_pi_wnd_compute_net_charge_button (GtkWidget *button,
 
 
 gint
-polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
+polyxedit_pka_ph_pi_wnd_calculate_pi_button (GtkWidget *button,
 					   gpointer data)
 {
   GtkWidget *window = data;
@@ -665,10 +725,10 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
 
   
 
-  /* We are asked to compute the isoelectric point for the current
+  /* We are asked to calculate the isoelectric point for the current
      polymer sequence (or a region of it). 
 
-     The way we do this is start by setting pH to 7.0, compute the net
+     The way we do this is start by setting pH to 7.0, calculate the net
      charge of the sequence at this pH and then set the pH to
      higher/lower value if the charge is farther away (positive or
      negative) than 0.05.
@@ -680,7 +740,7 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
   /* Note that the charges holders (gdouble *) are allocated when the
      window is set up, so we first have to get the pointers out of the
      window ! Of course we have to reset them to 0 prior to performing
-     the new computation.
+     the new calculation.
   */
   negative_charges = g_object_get_data (G_OBJECT (window),
 					"negative_charges");
@@ -700,7 +760,7 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
    */
   calcopt = pxmchem_calcopt_dup (editctxt->calcopt);
 
-  /* Get the sequence interval for which the computation should be
+  /* Get the sequence interval for which the calculation should be
      performed.
    */
   if (FALSE ==  
@@ -709,11 +769,23 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
 						     &calcopt->end_idx))
   {
     polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-				      _("Failed getting sequence interval."),
+				      _("Failed to get sequence interval."),
 				      POLYXMASS_MEDI_MSG_TIMEOUT);
-
+    
+    /* Free this newly allocated calcopt object.
+     */
     pxmchem_calcopt_free (calcopt);
     
+    /* We do not want that the user makes fake reports if no
+       calculation was succcessful. See the end of the function
+       for an explanation of the function call below. It will
+       automagically free any old calcopt instance previously
+       stored as datum in the 'window'. Thus, when the user will
+       try to make a report, it will not be made because no
+       'calcopt' pointer is available in the 'window'.
+    */
+    g_object_set_data (G_OBJECT (window), "calcopt", NULL);
+    
     return -1;
   }
   
@@ -725,28 +797,40 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
     {
 
 #if 0
-      help = g_strdup_printf ("Current pH being tested: %lf", tested_ph);
+      help = g_strdup_printf (_("Current pH being tested: %lf"), tested_ph);
       gtk_entry_set_text (GTK_ENTRY (messages_entry), help);
       debug_printf (("%s\n", help));
       g_free (help);
 #endif
 
       processed_chemgroups =
-	polyxedit_acidobasic_polseq_compute_net_charge (editctxt, tested_ph,
+	polyxedit_acidobasic_polseq_calculate_net_charge (editctxt, tested_ph,
 							calcopt,
 							negative_charges,
 							positive_charges);
       if (-1 == processed_chemgroups)
 	{
 	  polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					    _("Failed computing net charge."),
+					    _("Failed to calculate net charge."),
 					    POLYXMASS_MEDI_MSG_TIMEOUT);
 	  
+	  /* Free this newly allocated calcopt object.
+	   */
 	  pxmchem_calcopt_free (calcopt);
 	  
+	  /* We do not want that the user makes fake reports if no
+	     calculation was succcessful. See the end of the function
+	     for an explanation of the function call below. It will
+	     automagically free any old calcopt instance previously
+	     stored as datum in the 'window'. Thus, when the user will
+	     try to make a report, it will not be made because no
+	     'calcopt' pointer is available in the 'window'.
+	  */
+	  g_object_set_data (G_OBJECT (window), "calcopt", NULL);
+	  
 	  return -1;
 	}
-
+      
       /* Note that if the 0.001 tested_ph step is enough to switch
 	 the net charge from one excess value to another excess value
 	 in the opposite direction, we'll enter an infinite loop.
@@ -811,8 +895,18 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
 	}
     }
   
-  /* At this point, we should have computed the pI.
+  /* At this point, we should have calculated the pI.
    */
+  /* Immediately make clear that we have calculated the pI by setting to
+     nothing the text in the pH combo-entry.
+  */
+  widget = g_object_get_data (G_OBJECT (window), 
+			      "hydrogen_potential_spinbutton");
+  g_assert (widget != NULL);
+  
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), 0.0);
+
+
   widget = g_object_get_data (G_OBJECT (window), 
 				      "negative_charges_entry");
   g_assert (widget != NULL);
@@ -868,17 +962,278 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
   g_free (help);
   
   
-  
   polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-				    _("Computation finished."),
+				    _("Calculation finished."),
 				    POLYXMASS_MEDI_MSG_TIMEOUT);
   
-  pxmchem_calcopt_free (calcopt);
+
+  /* Since we might have to write a report about this calculation, we
+     have to be able to know with which calculation  options
+     the calculation was performed. Thus, we store this information as
+     full data to the window, for later enquiry. See
+     polyxedit_pka_ph_pi_wnd_make_report_text_format() for details !
+
+     Note that the g_object_set_data_full call below will elicit
+     freeing of potentially pre-existing instances using their
+     respective freeing functions.
+  */
+  g_object_set_data_full (G_OBJECT (window), "calcopt", calcopt,
+			  (GDestroyNotify) pxmchem_calcopt_free);
   
   return processed_chemgroups;
 }
 
 
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_pka_ph_pi_wnd_make_report (PxmReportOpt* reportopt,
+				     PxmWinMngmt* winmngmt)
+{
+  
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_pka_ph_pi_wnd_make_report_text_format (reportopt,
+							    winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_pka_ph_pi_wnd_make_report_latex_format (reportopt,
+							     winmngmt);
+  else
+    g_assert_not_reached ();
+
+  return NULL;
+}
+
+
+gchar *
+polyxedit_pka_ph_pi_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						 PxmWinMngmt* winmngmt)
+{
+  GtkWidget *window = NULL;
+  GtkWidget *widget = NULL;
+
+  gchar *report = NULL;
+  
+  gdouble ph = 0;
+  
+  GString *report_gs = NULL;
+
+  PxmPolymer *polymer = NULL;
+  PxmPlminfo *plminfo = NULL;
+  PxmCalcOpt *calcopt = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  
+  window = winmngmt->wnd ;
+  g_assert (window != NULL);
+  
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
+
+  plminfo = polymer->plminfo;
+  g_assert (plminfo != NULL);
+
+  
+  report_gs = g_string_new ("");
+  
+  report_gs = pxmchem_polymer_format_txt_string_polseqinfo (plminfo,
+							    reportopt,
+							    report_gs);
+  
+  /* Get the pointer to the structure we know have determined how the
+     calculation was performed. However, the pointer is non-NULL only
+     if at least one calculation was performed, since it is set as
+     full data when the calculation is actually performed.
+
+     Thus, if this is NULL, we return with a message...
+  */
+  calcopt = g_object_get_data (G_OBJECT (window), "calcopt");
+  
+  if  (calcopt == NULL)
+    {
+      g_warning (_("%s@%d: no calculation took place, nothing to report\n"),
+		 __FILE__, __LINE__);
+      
+      report_gs = 
+	g_string_append (report_gs, _("No calculation took place, "
+			 "nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+
+  if ((reportopt->polymer_opt & PXM_PLM_REPORTOPT_CALCOPTIONS) ==
+      PXM_PLM_REPORTOPT_CALCOPTIONS)
+    {
+      report_gs = 
+	g_string_append (report_gs, _("Calculations Options:\n"
+			 "---------------------\n"));
+
+      if (calcopt->capping & PXM_CAPPING_RIGHT && 
+	  calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: BOTH\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_RIGHT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: RIGHT\n"));
+      
+      else if (calcopt->capping & PXM_CAPPING_LEFT)
+	report_gs = 
+	  g_string_append (report_gs, _("Capping: LEFT\n"));
+      
+      else
+	report_gs = g_string_append (report_gs, _("Capping: NONE\n"));
+	
+      if (calcopt->mnm_chement & PXMCHEMENT_MNM_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: MODIFS\n"));
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Monomer Chemical Entities: NONE\n"));
+	
+	
+      if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF
+	  && calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modifs: BOTH\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_LEFT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: LEFT\n"));
+
+      else if (calcopt->plm_chement & PXMCHEMENT_PLM_RIGHT_MODIF)
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: RIGHT\n"));
+	
+      else
+	report_gs = 
+	  g_string_append (report_gs, _("Polymer End Modif: NONE\n\n"));
+    }
+
+  
+  /* At this point, we can ask that the actual report be performed.
+   */
+  
+  /* Tell for which sequence, the composition was performed.
+   */
+  g_string_append_printf (report_gs, 
+			  _("Selected sequence: [%d-%d] --- "),
+			  calcopt->start_idx + 1, 
+			  calcopt->end_idx);
+
+  if ((reportopt->oligomer_opt & PXM_OLM_REPORTOPT_SEQUENCE) ==
+      PXM_OLM_REPORTOPT_SEQUENCE)
+    {
+      report = pxmchem_polymer_make_codes_string (polymer,
+						  calcopt->start_idx + 1,
+						  calcopt->end_idx);
+      g_assert (report != NULL);
+      
+      g_string_append_printf (report_gs, "%s\n", report);
+      
+      g_free (report);
+    }
+  
+
+  widget = g_object_get_data (G_OBJECT (window), 
+			      "isoelectric_point_entry");
+  g_assert (widget != NULL);
+  
+  report = (gchar *) gtk_entry_get_text (GTK_ENTRY (widget));
+  g_assert (report != NULL);
+  
+  g_string_append_printf (report_gs, _("Iso-electric Point: %s\n\n"), report);
+
+
+  widget =  g_object_get_data (G_OBJECT (window), 
+			       "hydrogen_potential_spinbutton");
+  g_assert (widget != NULL);
+  
+  ph = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
+  
+  g_string_append_printf (report_gs, _("Hydrogen Potential: %.4lf\n\n"), ph);
+  
+
+
+  report_gs = g_string_append (report_gs,
+			       _("Charges:\n"
+			       "--------\n\n"));
+  
+  widget = g_object_get_data (G_OBJECT (window), 
+			      "positive_charges_entry");
+  g_assert (widget != NULL);
+  
+  report = (gchar *) gtk_entry_get_text (GTK_ENTRY (widget));
+  g_assert (report != NULL);
+  
+  g_string_append_printf (report_gs, _("Positive: %s"), report);
+  
+
+  widget = g_object_get_data (G_OBJECT (window), 
+			      "negative_charges_entry");
+  g_assert (widget != NULL);
+  
+  report = (gchar *) gtk_entry_get_text (GTK_ENTRY (widget));
+  g_assert (report != NULL);
+  
+  g_string_append_printf (report_gs, _("\tNegative: %s"), report);
+  
+
+  widget = g_object_get_data (G_OBJECT (window), 
+			      "net_charge_entry");
+  g_assert (widget != NULL);
+  
+  report = (gchar *) gtk_entry_get_text (GTK_ENTRY (widget));
+  g_assert (report != NULL);
+  
+  g_string_append_printf (report_gs, _("\tNet: %s\n\n"), report);
+  
+
+  widget = g_object_get_data (G_OBJECT (window), 
+			      "treated_pka_number_entry");
+  g_assert (widget != NULL);
+
+  report = (gchar *) gtk_entry_get_text (GTK_ENTRY (widget));
+  g_assert (report != NULL);
+  
+  g_string_append_printf (report_gs, _("Number of pKa analyzed: %s\n\n\n"), 
+			  report);
+
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+
+
+gchar *
+polyxedit_pka_ph_pi_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+
+
+  return NULL;
+}
+
 
 
 
@@ -890,22 +1245,28 @@ polyxedit_pka_ph_pi_wnd_compute_pi_button (GtkWidget *button,
 void
 polyxedit_pka_ph_pi_wnd_really_close (GtkWidget *window)
 {
-  gint count = 0;
-
-  
   g_assert (window != NULL);
   
 
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
    
   gtk_widget_destroy (window);
 }
 
 
+
 gint
 polyxedit_pka_ph_pi_wnd_delete_event  (GtkWidget *window, 
 					GdkEventAny *event, 
@@ -920,20 +1281,32 @@ polyxedit_pka_ph_pi_wnd_delete_event  (GtkWidget *window,
   g_assert (editctxt != NULL);
   
 
-  help = g_strdup_printf ("pka_ph_pi_wnd-%p", window);
-
-
-  /* We set the datum to NULL, then the GDestroyNotify callback that
-     was specified when the datum was set first (that is
-     xxx_wnd_really_close () function above) will be called,
-     thus destroying *this window, which is exactly what we want !
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
   */
-  g_object_set_data (G_OBJECT
-		     (editctxt->seqeditorctxt->sequence_editor_wnd), 
-		     help, NULL);
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("pka_ph_pi_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->
+				   sequence_editor_wnd),
+			 help);
+  
   g_free (help);
-    
-  return TRUE;
+  
+  /* Let Gtk+ do the rest of the work.
+   */
+  return FALSE;
 }
 
 
