@@ -67,7 +67,7 @@ polyxedit_ui_polymer_modif_setup_wnd (PxmEditCtxt *editctxt)
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -77,7 +77,7 @@ polyxedit_ui_polymer_modif_setup_wnd (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the polymer modification window\n"),
+      g_critical (_("%s@%d: failed to create the polymer modification window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -107,7 +107,7 @@ polyxedit_ui_polymer_modif_setup_wnd (PxmEditCtxt *editctxt)
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
   
 
   widget = glade_xml_get_widget (xml, "polymer_sequence_id_number_entry");
@@ -219,10 +219,10 @@ polyxedit_ui_polymer_modif_setup_wnd (PxmEditCtxt *editctxt)
    */
   g_object_unref (G_OBJECT (xml));
 
-  /* And now that we know all the window is set up, we can 
-     fill the data in it: the list of available modifications, the list
-     of the monomers in the polymer definition context, the position
-     of the possibly selected monomer...
+  /* And now that we know all the window is set up, we can fill the
+     data in it: the list of available modifications, the list of the
+     monomers in the polymer definition context, the position of the
+     possibly selected monomer...
   */
 
   /* Fill the treeview of modifications avaialable to the polymer
@@ -237,7 +237,7 @@ polyxedit_ui_polymer_modif_setup_wnd (PxmEditCtxt *editctxt)
 							editctxt->
 							polchemdefctxt->polchemdef))
     {
-      g_critical (_("%s@%d: failed filling the modifications list\n"),
+      g_critical (_("%s@%d: failed to fill the modifications list\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -324,7 +324,7 @@ polyxedit_ui_polymer_modif_setup_modifs_treeview (GtkTreeView *treeview,
     GtkTreeViewColumn *column = NULL;
     
     column = 
-    gtk_tree_view_column_new_with_attributes ("Name", 
+    gtk_tree_view_column_new_with_attributes (_("Name"), 
     renderer,
     "text", COLUMN_MDF_NAME,
     NULL); 
@@ -334,7 +334,7 @@ polyxedit_ui_polymer_modif_setup_modifs_treeview (GtkTreeView *treeview,
   
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Name", renderer,
+     -1, _("Name"), renderer,
      "text", COLUMN_MDF_NAME,
      "editable", COLUMN_MDF_EDITABLE,
      NULL);
@@ -349,7 +349,7 @@ polyxedit_ui_polymer_modif_setup_modifs_treeview (GtkTreeView *treeview,
 
   gtk_tree_view_insert_column_with_attributes 
     (GTK_TREE_VIEW (treeview),
-     -1, "Formula", renderer,
+     -1, _("Actform"), renderer,
      "text", COLUMN_MDF_ACTFORM,
      "editable", COLUMN_MDF_EDITABLE,
      NULL);
@@ -443,7 +443,7 @@ polyxedit_ui_polymer_modif_modify_button (GtkWidget *button,
 	  pxmchem_polymer_LE_modify (editctxt->polymer, modif_name))
 	{
 	  polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-						 _("left end modif. failed"), 
+						 _("Failed to modify Left End"), 
 						 POLYXMASS_NORM_MSG_TIMEOUT);
 	}
       else
@@ -467,7 +467,7 @@ polyxedit_ui_polymer_modif_modify_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window, 
-	     _("right end modif. failed"), 
+	     _("Failed to modify Right End"), 
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	}
       else
@@ -597,7 +597,7 @@ polyxedit_ui_polymer_modif_un_modify_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("left end un-modif. failed"), 
+	     _("Failed to un-modify Left End"), 
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	}
       else
@@ -610,7 +610,7 @@ polyxedit_ui_polymer_modif_un_modify_button (GtkWidget *button,
 					   "left_end_modif_entry");
 	    g_assert (widget != NULL);
 
-	    gtk_entry_set_text (GTK_ENTRY (widget), _("none set"));
+	    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 	}
     }
   
@@ -621,7 +621,7 @@ polyxedit_ui_polymer_modif_un_modify_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set 
 	    ((GtkWindow *) window,
-	     _("right end un-modif. failed"), 
+	     _("Failed to un-modify Right End"), 
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	}
       else
@@ -634,7 +634,7 @@ polyxedit_ui_polymer_modif_un_modify_button (GtkWidget *button,
 					   "right_end_modif_entry");
 	    g_assert (widget != NULL);
 
-	    gtk_entry_set_text (GTK_ENTRY (widget), _("none set"));
+	    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 	}
     }
   
