@@ -66,9 +66,11 @@ polyxedit_searchmass_opt_setup_wnd (PxmEditCtxt *editctxt)
   
   xml = glade_xml_new (gui_file, "searchmass_options_wnd", 
 		       PACKAGE);
+  g_free (gui_file);
+
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -78,7 +80,7 @@ polyxedit_searchmass_opt_setup_wnd (PxmEditCtxt *editctxt)
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the search mass window\n"),
+      g_critical (_("%s@%d: failed to create the search mass window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -107,7 +109,7 @@ polyxedit_searchmass_opt_setup_wnd (PxmEditCtxt *editctxt)
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
   
 
   widget = glade_xml_get_widget (xml, "polseq_identity_number_entry");
@@ -290,6 +292,33 @@ polyxedit_searchmass_opt_setup_wnd (PxmEditCtxt *editctxt)
 		    G_CALLBACK (polyxedit_searchmass_opt_search_button), 
 		    window);
 
+  widget = glade_xml_get_widget (xml, 
+				 "currently_searched_mass_entry");
+  g_object_set_data (G_OBJECT (window), 
+		     "currently_searched_mass_entry",
+		     widget);
+
+  widget = 
+    glade_xml_get_widget (xml, 
+			  "currently_searched_mass_mono_type_radiobutton");
+  g_object_set_data (G_OBJECT (window), 
+		     "currently_searched_mass_mono_type_radiobutton",
+		     widget);
+
+  widget = 
+    glade_xml_get_widget (xml, 
+			  "currently_searched_mass_avg_type_radiobutton");
+  g_object_set_data (G_OBJECT (window), 
+		     "currently_searched_mass_avg_type_radiobutton",
+		     widget);
+
+  widget = glade_xml_get_widget (xml, 
+				 "total_number_found_oligomers_entry");
+  g_object_set_data (G_OBJECT (window), 
+		     "total_number_found_oligomers_entry",
+		     widget);
+
+
 
   gtk_widget_show_all (GTK_WIDGET (window));
   
@@ -308,8 +337,23 @@ polyxedit_searchmass_opt_setup_wnd (PxmEditCtxt *editctxt)
      G_CALLBACK (polyxedit_searchmass_opt_wnd_delete_event), 
      editctxt);
 
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
 
-  g_free (gui_file);
+     There might be more than one cleavage options' window opened for
+     a given polymer seqence editing window, and we do not want that
+     the second window destroys the datum name of the first window, so
+     we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("searchmass_options_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_searchmass_opt_wnd_really_close);
+  
+  g_free (help);
 
   return window;
 }
@@ -337,9 +381,9 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
   PxmIonizerule *ionizerule = NULL;
   PxmMassType mass_type = PXM_MASS_NONE;
   
-  gchar *name;
-  gchar *help;
-
+  gchar *name = NULL;
+  gchar *help = NULL;
+  
   GPtrArray *alloligsGPA = NULL;
   GPtrArray *smoptGPA = NULL;
 
@@ -404,7 +448,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("could not retrieve a correct mass value"),
+	     _("Failed to get a correct mass value"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_searchmassopt_free (smopt);
@@ -422,7 +466,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("could not retrieve a correct tolerance value"),
+	     _("Failed to get a correct tolerance value"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_searchmassopt_free (smopt);
@@ -439,7 +483,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("could not get a correct tolerance type"),
+	     _("Failed to get a correct tolerance type"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_searchmassopt_free (smopt);
@@ -458,7 +502,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("failed getting selection type"),
+	     _("Failed to get selection type"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_searchmassopt_free (smopt);
@@ -497,7 +541,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("failed searching the mass in the polymer"),
+	     _("Failed to search the mass in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -511,7 +555,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("mass not found in the polymer"),
+	     _("Mass not found in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -537,7 +581,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("Failed displaying the oligomers in a window"),
+	     _("Failed to display the oligomers in a window"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -590,7 +634,7 @@ polyxedit_searchmass_opt_mass_entry_activate (GtkEntry *entry,
 					"avg_masses_textview");
 	}
       else
-	g_error (_("%s@%d: error in the window layout\n"),
+	g_error (_("%s@%d: failed to interpret the window layout\n"),
 	       __FILE__, __LINE__);
 
       /* Get the buffer that holds the text presently (if any) in the
@@ -652,6 +696,15 @@ polyxedit_searchmass_opt_search_masses (PxmEditCtxt *editctxt,
   gint count = 0;
   gint total = 0;
   gint iter = 0;
+
+  gchar *prefix = NULL;
+  gchar *help = NULL;
+  
+  GtkWidget *current_mass_entry = NULL;
+  GtkWidget *total_oligomers_entry = NULL;
+  GtkWidget *mono_radio = NULL;
+  GtkWidget *avg_radio = NULL;
+   
   
   PxmSearchmassOpt *smopt = NULL;
 
@@ -666,9 +719,33 @@ polyxedit_searchmass_opt_search_masses (PxmEditCtxt *editctxt,
   g_assert (ionizerule != NULL);
   
   
+  current_mass_entry = g_object_get_data (G_OBJECT (window),
+					  "currently_searched_mass_entry");
+  g_assert (current_mass_entry != NULL);
+  
+  total_oligomers_entry = 
+    g_object_get_data (G_OBJECT (window),
+		       "total_number_found_oligomers_entry");
+  g_assert (total_oligomers_entry != NULL);
+  
+  mono_radio = 
+    g_object_get_data (G_OBJECT (window),
+		       "currently_searched_mass_mono_type_radiobutton");
+  g_assert (mono_radio != NULL);
+  
+  avg_radio =
+    g_object_get_data (G_OBJECT (window),
+		       "currently_searched_mass_avg_type_radiobutton");
+  g_assert (avg_radio != NULL);
+  
   
   for (iter = 0; iter < smoptGPA->len ; iter++)
     {
+      /* Prepare the prefix string to allow for proper naming in the
+	 subsequently called function.
+      */
+      prefix= g_strdup_printf ("%d", iter + 1);
+
       smopt = g_ptr_array_index (smoptGPA, iter);
       g_assert (smopt != NULL);
 
@@ -676,23 +753,45 @@ polyxedit_searchmass_opt_search_masses (PxmEditCtxt *editctxt,
        */
       oligsGPA = g_ptr_array_new ();
       
+
+      /* Inform the user that a new mass is being searched.
+       */
+      help = g_strdup_printf ("%.5lf", smopt->mass);
+      gtk_entry_set_text (GTK_ENTRY (current_mass_entry), help);
+      g_free (help);
+
+      if (smopt->mass_type == PXM_MASS_MONO)
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mono_radio),
+				      TRUE);
+      else if (smopt->mass_type == PXM_MASS_AVG)
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (avg_radio),
+				      TRUE);
+      else g_assert_not_reached ();
+      
+      while (gtk_events_pending ())
+	gtk_main_iteration ();
+
+      /* Let's do the search proper !
+       */
       count = pxmchem_searchmass_polymer (editctxt->polymer,
 					  oligsGPA,
 					  editctxt->polchemdefctxt->
 					  polchemdef,
 					  smopt,
 					  calcopt,
-					  ionizerule);
-      /*
-	FIXME: should provide user feedback either in a message
-	window, with a regularly updated scroll bar... or with text
-	displayed in the messages entry.
+					  ionizerule,
+					  prefix);
+      
+      /* Free the prefix string, because we'll need to allocate a new
+	 one later, or we'll get out of the current loop.
       */
+      g_free (prefix);
+      
       if (count == -1)
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("failed searching for one mass in the polymer"),
+	     _("Failed to search for one mass in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  return -1;
@@ -707,6 +806,12 @@ polyxedit_searchmass_opt_search_masses (PxmEditCtxt *editctxt,
 	g_ptr_array_free (oligsGPA, TRUE);
       
       total += count;
+
+      /* Tell the user how many oligomers in total we got.
+       */
+      help = g_strdup_printf ("%d", total);
+      gtk_entry_set_text (GTK_ENTRY (total_oligomers_entry), help);
+      g_free (help);
     }
   
   return total;
@@ -727,7 +832,9 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
   GtkTextView *textview = NULL;
   GtkTextIter start;
   GtkTextIter end;
+
   gchar *masses_text = NULL;
+  gchar *help = NULL;
   
   gdouble *mass = NULL;
 
@@ -810,7 +917,7 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("both MONO and AVG text entries have a mass value"),
+	     _("Both MONO and AVG text entries have a mass value"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	}
       else if (mono_ok == TRUE)
@@ -935,12 +1042,12 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	      if (mass_types [iter] == PXM_MASS_MONO)
 		polyxmass_timeoutmsg_message_set
 		  ((GtkWindow *) window,
-		   _("the MONO text view data are not valid UTF-8"),
+		   _("The data in the MONO text view are not valid UTF-8"),
 		   POLYXMASS_NORM_MSG_TIMEOUT);
 	      else 
 		polyxmass_timeoutmsg_message_set
 		  ((GtkWindow *) window,
-		   _("the AVG text view data are not valid UTF-8"),
+		   _("The data in the AVG text view are not valid UTF-8"),
 		   POLYXMASS_NORM_MSG_TIMEOUT);
 	      
 	      /* Remember that we encounter this point twice: the first
@@ -987,12 +1094,12 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	      if (mass_types [iter] == PXM_MASS_MONO)
 		polyxmass_timeoutmsg_message_set
 		  ((GtkWindow *) window,
-		   _("could not retrieve a correct MONO tolerance value"),
+		   _("Failed to get a correct MONO tolerance value"),
 		   POLYXMASS_NORM_MSG_TIMEOUT);
 	      else
 		polyxmass_timeoutmsg_message_set
 		  ((GtkWindow *) window,
-		   _("could not retrieve a correct AVG tolerance value"),
+		   _("Failed to get a correct AVG tolerance value"),
 		   POLYXMASS_NORM_MSG_TIMEOUT);
 
 	      g_free (masses_text);
@@ -1011,12 +1118,12 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	      if (mass_types [iter] == PXM_MASS_MONO)
 		polyxmass_timeoutmsg_message_set
 		  ((GtkWindow *) window,
-		   _("could not get a correct MONO tolerance type"),
+		   _("Failed to get a correct MONO tolerance type"),
 		   POLYXMASS_NORM_MSG_TIMEOUT);
 	      else
 		polyxmass_timeoutmsg_message_set
 		  ((GtkWindow *) window,
-		   _("could not get a correct AVG tolerance type"),
+		   _("Failed to get a correct AVG tolerance type"),
 		   POLYXMASS_NORM_MSG_TIMEOUT);
 
 	      g_free (masses_text);
@@ -1103,7 +1210,7 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("failed getting selection type"),
+	     _("Failed to get the selection type"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_searchmassopt_free (smopt);
@@ -1133,7 +1240,7 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("failed searching the masses in the polymer"),
+	     _("Failed to search the masses in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -1147,7 +1254,7 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("no mass was found in the polymer"),
+	     _("No mass was found in the polymer"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -1173,7 +1280,7 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	{
 	  polyxmass_timeoutmsg_message_set
 	    ((GtkWindow *) window,
-	     _("Failed displaying the oligomers in a window"),
+	     _("Failed to display the oligomers in a window"),
 	     POLYXMASS_NORM_MSG_TIMEOUT);
 	  
 	  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
@@ -1182,6 +1289,43 @@ polyxedit_searchmass_opt_search_button (GtkWidget *button,
 	  
 	  return;
 	}
+
+      /* Register the results' window !
+       */
+      /* Immediately set a automagically freeable string with the
+	 description of the new allocated results window so that later
+	 -during window management- we can describe what the window was
+	 for. This will be used if the user asks to find masses in the
+	 results and then a new window will be displayed with all the
+	 masses that were found in the results window, and we will want to
+	 display that description string.
+      */
+      help = g_strdup_printf (_("Search Mass in '%p'"), editctxt);
+      
+      g_object_set_data_full (G_OBJECT (display_window),
+			      "wnd_desc", help, 
+			      (GDestroyNotify) free);
+      
+      if (NULL == polyxmass_winmngmt_register_window 
+	  ("POLYXEDIT",
+	   display_window,
+	   window,
+	   editctxt,
+	   _("Results of Search Mass"),
+	   help,
+	   TRUE,
+	   polyxedit_searchmass_results_wnd_make_report))
+	g_critical (_("%s@%d: failed to register the "
+		      "search mass results' window\n"),
+		    __FILE__, __LINE__);
+      
+
+      /* Do not free help, because we have set it as a full datum to
+	 the window where the find mass results are to be displayed !
+	 
+	 g_free (help);
+      */
+
       
       /* Now that we have the certainty that the oligomers' displaying
 	 window could be created and populated correctly with the
@@ -1377,20 +1521,23 @@ polyxedit_searchmass_opt_get_tolerance_type (GtkWidget *window,
     case 0:
       if (smopt != NULL)
 	smopt->tolerance_type = PXM_MASS_TOLERANCE_AMU;
-      printf ("was PXM_MASS_TOLERANCE_AMU\n");
-      
+      /*
+      debug_printf (("was PXM_MASS_TOLERANCE_AMU\n"));
+      */
       return TRUE;
     case 1:
       if (smopt != NULL)
 	smopt->tolerance_type = PXM_MASS_TOLERANCE_PCT;
-      printf ("was PXM_MASS_TOLERANCE_PCT\n");
-
+      /*
+	debug_printf (("was PXM_MASS_TOLERANCE_PCT\n"));
+      */
       return TRUE;
     case 2:
       if (smopt != NULL)
 	smopt->tolerance_type = PXM_MASS_TOLERANCE_PPM;
-      printf ("was PXM_MASS_TOLERANCE_PPM\n");
-
+      /*
+	debug_printf (("was PXM_MASS_TOLERANCE_PPM\n"));
+      */
       return TRUE;
     }
   
@@ -1458,25 +1605,59 @@ polyxedit_searchmass_opt_get_selection_type (GtkWidget *window,
 
 
 
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_searchmass_opt_wnd_really_close (GtkWidget *window)
+{
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+
+
+  gtk_widget_destroy (window);
+}
+
+  
+
 gboolean
 polyxedit_searchmass_opt_wnd_delete_event (GtkWidget *window, 
 					   GdkEventAny *event, 
 					   gpointer data)
 {
-  gint count = 0;
-  
+  gchar *help = NULL;
 
+  PxmEditCtxt *editctxt = NULL;
+  
+  g_assert (window != NULL);
+
+  editctxt = g_object_get_data (G_OBJECT (window), "editctxt");
+  g_assert (editctxt != NULL);
+ 
+  
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
-  
-  /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+
+  /* This window pointer was set as a full datum to the parent window
+     (a cleavage or fragmentatioon results window), which means that
+     we have to remove that pointer, without triggering the callback
+     function call.
   */
+  help = g_strdup_printf ("searchmass_options_wnd-%p", window);
+  
+  window = g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->
+					  sequence_editor_wnd), help);
+  g_free (help);
+  
+  /* Let Gtk+ do the rest of the work.
+   */
   return FALSE;
 }
-
-  
