@@ -35,24 +35,33 @@
 
 enum
 {
+  /* The name of the oligo ! */
+  COLUMN_OLIG_NAME = 0 ,
+
   /* The mass that was searched for. */
   COLUMN_OLIG_TO_SEARCH_MASS,
+
   /* the difference between found and searched masses */
   COLUMN_OLIG_MASS_ERROR,
-  /* The name of the oligo ! */
-  COLUMN_OLIG_NAME,
+
   /* The index + 1 in the array of oligos ! */
   COLUMN_OLIG_NUMBER,
+
   /* A string in the form [1-17] */
   COLUMN_OLIG_COORDINATES,
+
   /* MONO or AVG: the mass type of the search */
   COLUMN_OLIG_MASS_TYPE,
+
   /* Mono mass */
   COLUMN_OLIG_MONO,
+
   /* Average mass */
   COLUMN_OLIG_AVG,
+
   /* Contains modified monomers */
   COLUMN_OLIG_MODIFIED,
+
   /* Pointer to the oligomer */
   COLUMN_OLIG_POINTER,
 
@@ -97,9 +106,11 @@ polyxedit_searchmass_res_wnd_setup (PxmEditCtxt *editctxt,
   
   xml = glade_xml_new (gui_file, "searchmass_results_wnd", 
 		       PACKAGE);
+  g_free (gui_file);
+
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       return NULL;
@@ -109,7 +120,7 @@ polyxedit_searchmass_res_wnd_setup (PxmEditCtxt *editctxt,
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the searchmass results window\n"),
+      g_error (_("%s@%d: failed to create the searchmass results window\n"),
 	     __FILE__, __LINE__);
 
       g_object_unref (G_OBJECT (xml));
@@ -143,7 +154,7 @@ polyxedit_searchmass_res_wnd_setup (PxmEditCtxt *editctxt,
     gtk_entry_set_text (GTK_ENTRY (widget), 
 			editctxt->polymer->plminfo->name);
   else 
-    gtk_entry_set_text (GTK_ENTRY (widget), _("not set"));
+    gtk_entry_set_text (GTK_ENTRY (widget), _("Not set"));
 
   /* Set the polymer sequence context id number (its pointer) to its
      correspondent GtkEntry.
@@ -389,15 +400,31 @@ polyxedit_searchmass_res_wnd_setup (PxmEditCtxt *editctxt,
   g_signal_connect (G_OBJECT (window),
 		    "delete_event",
 		    G_CALLBACK (polyxedit_searchmass_res_wnd_delete_event),
-		    window);
+		    editctxt);
   
   g_signal_connect (G_OBJECT (window),
 		    "destroy_event",
 		    G_CALLBACK (polyxedit_searchmass_res_wnd_destroy_event),
-		    window);
+		    editctxt);
 
-  g_free (gui_file);
+  /* Set this window pointer as a full datum to the polymer sequence
+     editor window, so that when it is closed this window is closed
+     also. 
 
+     There might be more than one cleavage results' window opened for
+     a given polymer seqence editing window, and we do not want that
+     the second window destroys the datum name of the first window, so
+     we create an uambiguous datum name each time.
+  */
+  help = g_strdup_printf ("searchmass_results_wnd-%p", window);
+  
+  g_object_set_data_full 
+    (G_OBJECT (editctxt->seqeditorctxt->sequence_editor_wnd),
+     help, GTK_WIDGET (window), 
+     (GDestroyNotify) polyxedit_searchmass_res_wnd_really_close);
+  
+  g_free (help);
+  
 
   return window;
 }
@@ -590,7 +617,7 @@ polyxedit_searchmass_res_wnd_show_oligs (GtkWidget *window,
   count = g_object_get_data (G_OBJECT (model), "total_oligos");
   g_assert (count != NULL);
   
-  help = g_strdup_printf (_("Total number of oligomers: %d"),
+  help = g_strdup_printf (_("The total number of oligomers is: '%d'"),
 			  *count);
   
   polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
@@ -631,27 +658,38 @@ polyxedit_searchmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
   g_assert (alloligsGPA != NULL);
   
 
-  model = gtk_tree_store_new (COLUMN_OLIG_COL_COUNT,
-			      /* The mass that was searched for. */
-			      G_TYPE_DOUBLE,
-			      /* Difference (found - searched) */
-			      G_TYPE_DOUBLE,
-			      /* The name of the oligo ! */
-			      G_TYPE_STRING,
-			      /* The index + 1 in the array of oligos ! */
-			      G_TYPE_INT,
-			      /* A string in the form [1-17] */
-			      G_TYPE_STRING,
-			      /* MONO or AVG: the mass type of the search */
-			      G_TYPE_STRING,
-			      /* Mono mass */
-			      G_TYPE_DOUBLE,
-			      /* Average mass */
-			      G_TYPE_DOUBLE,
-			      /* Contains modified monomers */
-			      G_TYPE_BOOLEAN,
-			      /* Pointer to the oligomer */
-			      G_TYPE_POINTER);
+  model = gtk_tree_store_new 
+    (COLUMN_OLIG_COL_COUNT,
+
+     /* The name of the oligo ! COLUMN_OLIG_NAME*/
+     G_TYPE_STRING,
+
+     /* The mass that was searched for. COLUMN_OLIG_TO_SEARCH_MASS*/
+     G_TYPE_DOUBLE,
+
+     /* Difference (found - searched) COLUMN_OLIG_MASS_ERROR*/
+     G_TYPE_DOUBLE,
+
+     /* The index + 1 in the array of oligos ! COLUMN_OLIG_NUMBER*/
+     G_TYPE_INT,
+
+     /* A string in the form [1-17] COLUMN_OLIG_COORDINATES*/
+     G_TYPE_STRING,
+
+     /* MONO or AVG: the mass type of the search COLUMN_OLIG_MASS_TYPE*/
+     G_TYPE_STRING,
+
+     /* Mono mass COLUMN_OLIG_MONO*/
+     G_TYPE_DOUBLE,
+
+     /* Average mass COLUMN_OLIG_AVG*/
+     G_TYPE_DOUBLE,
+
+     /* Contains modified monomers COLUMN_OLIG_MODIFIED*/
+     G_TYPE_BOOLEAN,
+
+     /* Pointer to the oligomer COLUMN_OLIG_POINTER*/
+     G_TYPE_POINTER);
   
   count = g_malloc0 (sizeof (gint));
 
@@ -700,7 +738,7 @@ polyxedit_searchmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 	  smopt = prop->data;
 	  g_assert (smopt != NULL);
 
-	  /* Now we can compute the error:
+	  /* Now we can calculate the error:
 	   */
 	  if (smopt->mass_type == PXM_MASS_MONO)
 	    {
@@ -708,7 +746,7 @@ polyxedit_searchmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 
 	      /* Take advantage to set the mass type string:
 	       */
-	      mass_type = g_strdup_printf ("MONO");
+	      mass_type = g_strdup_printf (_("MONO"));
 	    }
 	  else /*  (smopt->mass_type == PXM_MASS_AVG) */
 	    {
@@ -716,7 +754,7 @@ polyxedit_searchmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 
 	      /* Take advantage to set the mass type string:
 	       */
-	      mass_type = g_strdup_printf ("AVG");
+	      mass_type = g_strdup_printf (_("AVG"));
 	    }
 	  
 	  /* Construct a coordinates string.
@@ -730,24 +768,33 @@ polyxedit_searchmass_res_create_oligs_treeview_model (GPtrArray *alloligsGPA)
 	  gtk_tree_store_set 
 	    (model, &treeiter,
 
-	     /* The mass that was searched for. */
-	     COLUMN_OLIG_TO_SEARCH_MASS, smopt->mass,
-	     /* Difference (found - searched) */
-	     COLUMN_OLIG_MASS_ERROR, error,
 	     /* The name of the oligo ! */
 	     COLUMN_OLIG_NAME, oligomer->name,
+
+	     /* The mass that was searched for. */
+	     COLUMN_OLIG_TO_SEARCH_MASS, smopt->mass,
+
+	     /* Difference (found - searched) */
+	     COLUMN_OLIG_MASS_ERROR, error,
+
 	     /* The absolute index + 1 in the arrays of oligos ! */
 	     COLUMN_OLIG_NUMBER, (*count) + 1,
+
 	     /* A string in the form [1-17] */
 	     COLUMN_OLIG_COORDINATES, coordinates,
+
 	     /* MONO or AVG: the mass type of the search */
 	     COLUMN_OLIG_MASS_TYPE, mass_type,
+
 	     /* Mono mass */
 	     COLUMN_OLIG_MONO, oligomer->masspair->mono,
+
 	     /* Average mass */
 	     COLUMN_OLIG_AVG, oligomer->masspair->avg,
+
 	     /* Contains modified monomers */
 	     COLUMN_OLIG_MODIFIED, modified,
+
 	     /* Pointer to the oligomer */
 	     COLUMN_OLIG_POINTER, oligomer,
 
@@ -879,12 +926,41 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
 		    (polyxedit_searchmass_res_oligs_treeview_row_activated),
 		    window);
   
+  /* Oligomer name column.
+   */
+  renderer = gtk_cell_renderer_text_new ();
+
+  column = 
+    gtk_tree_view_column_new_with_attributes (_("Name"),
+					      
+					      renderer, 
+					      
+					      "text",
+					      COLUMN_OLIG_NAME,
+					      
+					      NULL);
+  
+  gtk_tree_view_column_set_sort_column_id (column, 
+					   COLUMN_OLIG_NAME);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+
+  gtk_tree_sortable_set_sort_func 
+    (GTK_TREE_SORTABLE (model),
+     COLUMN_OLIG_NAME,
+     polyxedit_searchmass_res_wnd_sort_name_column,
+     NULL,
+     NULL);
+
+
   /* The searched mass column.
    */
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("To Search",
+    gtk_tree_view_column_new_with_attributes (_("To Search"),
 					      
 					      renderer, 
 					      
@@ -905,7 +981,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Error",
+    gtk_tree_view_column_new_with_attributes (_("Error"),
 					      
 					      renderer, 
 					      
@@ -921,33 +997,12 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
 
-  /* Oligomer name column.
-   */
-  renderer = gtk_cell_renderer_text_new ();
-
-  column = 
-    gtk_tree_view_column_new_with_attributes ("Name",
-					      
-					      renderer, 
-					      
-					      "text",
-					      COLUMN_OLIG_NAME,
-					      
-					      NULL);
-  
-  gtk_tree_view_column_set_sort_column_id (column, 
-					   COLUMN_OLIG_NAME);
-
-  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-  gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-  gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
-
   /* Oligomer number column.
    */
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Number",
+    gtk_tree_view_column_new_with_attributes (_("Number"),
 					      
 					      renderer, 
 					      
@@ -973,7 +1028,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
 		     (gint *) COLUMN_OLIG_COORDINATES);
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Coords.",
+    gtk_tree_view_column_new_with_attributes (_("Coords."),
 					      
 					      renderer, 
 					      
@@ -1001,7 +1056,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mass Type",
+    gtk_tree_view_column_new_with_attributes (_("Mass Type"),
 					      
 					      renderer, 
 					      
@@ -1022,7 +1077,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mono Mass",
+    gtk_tree_view_column_new_with_attributes (_("Mono Mass"),
 					      
 					      renderer, 
 					      
@@ -1042,7 +1097,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Avg Mass",
+    gtk_tree_view_column_new_with_attributes (_("Avg Mass"),
 					      
 					      renderer, 
 					      
@@ -1062,7 +1117,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_toggle_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Modified",
+    gtk_tree_view_column_new_with_attributes (_("Modified"),
 					      
 					      renderer,
 					      
@@ -1080,7 +1135,7 @@ polyxedit_searchmass_res_setup_oligs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
   
   column = 
-    gtk_tree_view_column_new_with_attributes ("Oligo. Pointer",
+    gtk_tree_view_column_new_with_attributes (_("Oligo. Pointer"),
 					      
 					      renderer,
 					      
@@ -1184,7 +1239,7 @@ polyxedit_searchmass_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Position",
+    gtk_tree_view_column_new_with_attributes (_("Position"),
 					      
 					      renderer,
 					      
@@ -1201,7 +1256,7 @@ polyxedit_searchmass_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Code",
+    gtk_tree_view_column_new_with_attributes (_("Code"),
 
 						 renderer, 
 
@@ -1218,7 +1273,7 @@ polyxedit_searchmass_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Left End Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Left End Modif."),
 
 						 renderer, 
 
@@ -1235,7 +1290,7 @@ polyxedit_searchmass_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Monomer Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Monomer Modif."),
 
 						 renderer, 
 
@@ -1252,7 +1307,7 @@ polyxedit_searchmass_res_setup_oligomer_modifs_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Right End Modif.",
+    gtk_tree_view_column_new_with_attributes (_("Right End Modif."),
 
 						 renderer, 
 
@@ -1685,7 +1740,7 @@ polyxedit_searchmass_res_olig_show_data (PxmOligomer *oligomer,
 	gtk_label_set_text (GTK_LABEL (widget),
 			    _("Part Per Million"));
       else
-	g_error (_("%s@%d: error with the smopt->tolerance_type\n"),
+	g_error (_("%s@%d: incorrect smopt->tolerance_type\n"),
 	       __FILE__, __LINE__);
 
       /* What was the value of the tolerance?
@@ -1747,10 +1802,12 @@ polyxedit_searchmass_results_wnd_find_button (GtkWidget *widget,
 					      gpointer data)
 {
   GtkWidget *window = data;
-  GtkWidget *window_new = NULL;
+  GtkWidget *display_window = NULL;
   
   GPtrArray *GPA = NULL;
-  
+
+  gchar *help = NULL;
+    
   g_assert (window != NULL);
   
 
@@ -1765,14 +1822,26 @@ polyxedit_searchmass_results_wnd_find_button (GtkWidget *widget,
   GPA = g_object_get_data (G_OBJECT (window), "alloligsGPA");
   g_assert (GPA != NULL);
   
-  window_new = polyxedit_findmass_opt_setup_wnd (window, GPA);
+  display_window = polyxedit_findmass_opt_setup_wnd (window, GPA);
   
-  if (window_new == NULL)
+  if (display_window == NULL)
     {
-      g_critical (_("%s@%d: failed setting up the find mass options window\n"),
+      g_critical (_("%s@%d: failed to set up the find mass options window\n"),
 	     __FILE__, __LINE__);
     }
   
+  /* At this point we ought to set an explanation string to the
+     created window, so that we later can determine for what purpose
+     this window was created. This is particularly important to know
+     how to sort the names of the oligomers that will be displayed in
+     the findmass results window.
+  */
+  help = g_strdup ("SEARCHMASS");
+  
+  g_object_set_data_full (G_OBJECT (display_window), 
+			  "oligomer_type", help,  
+			  (GDestroyNotify) g_free);
+  
   return;
 }
 
@@ -1826,41 +1895,352 @@ polyxedit_searchmass_res_wnd_sort_coordinates_column (GtkTreeModel *model,
 }
 
 
+gint
+polyxedit_searchmass_res_wnd_sort_name_column (GtkTreeModel *model,
+					     GtkTreeIter *a,
+					     GtkTreeIter *b,
+					     gpointer user_data)
+{
+  gint search_a = 0;
+  gint search_b = 0;
+  
+  gint number_a = 0;
+  gint number_b = 0;
+  
+  gchar *name_a = NULL;
+  gchar *name_b = NULL;
+  
+  /* We get the pointer to two different items in the treeview (the
+     model actually) and we need to access the data in them and then
+     tell which is greater to the other.
+  */
+  gtk_tree_model_get (model, a, 
+		      COLUMN_OLIG_NAME, &name_a,
+		      -1);
+
+  gtk_tree_model_get (model, b, 
+		      COLUMN_OLIG_NAME, &name_b,
+		      -1);
+
+  /* The oligomer name is in the form 1#2, to indicate first mass
+     searched, second oligomer of that mass found.
+   */
+  sscanf (name_a, "%d#%d", &search_a, &number_a);
+  sscanf (name_b, "%d#%d", &search_b, &number_b);
+
+  if (search_a == search_b)
+    {
+      if (number_a == number_b)
+	return 0;
+      
+      return (number_a > number_b) ? 1 : -1;
+    }
+  else
+    return (search_a > search_b ? 1 : -1);
+  
+  return 0;
+}
+
+
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxedit_searchmass_results_wnd_make_report (PxmReportOpt* reportopt,
+					    PxmWinMngmt* winmngmt)
+{
+
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+  
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxedit_searchmass_results_wnd_make_report_text_format (reportopt,
+								 winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxedit_searchmass_results_wnd_make_report_latex_format (reportopt,
+								  winmngmt);
+  else
+    g_assert_not_reached ();
+    
+  return NULL;
+}
+
+
+
+gchar *
+polyxedit_searchmass_results_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						      PxmWinMngmt* winmngmt)
+{
+  GtkWidget *window = NULL;
+  
+  gchar *report = NULL;
+  gchar *type = NULL;
+
+  gdouble search = 0;
+  gdouble error = 0;
+    
+  GString *report_gs = NULL;
+  
+  PxmPolymer *polymer = NULL;
+
+  GtkTreeView *treeview = NULL;
+  GtkTreeStore *model;
+  GtkTreeIter treeiter;
+
+  PxmOligomer *oligomer = NULL;
+
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+
+  g_assert (winmngmt->editctxt != NULL);
+  /* The window where the fragment results are displayed is in
+     'winmngmt->wnd'.
+   */
+  window = winmngmt->wnd;
+  g_assert (window != NULL);
+  
+  polymer = winmngmt->editctxt->polymer;
+  g_assert (polymer != NULL);
+
+  
+  
+  report_gs = g_string_new ("");
+ 
+
+
+  /* Since we want to make a user-friendly report, we manage to have
+     the different oligomers reported in the order that the user has
+     set in the treeview (some of that treeview column are sortable).
+
+     Thus we iterate in the treeview instead of iterating in the
+     arrray of oligomers... Some tricky work is required to still
+     inform the user of the partial cleavage of each oligomer.
+  */
+  model = g_object_get_data (G_OBJECT (window), "oligomers_treeview_model");
+  g_assert (model != NULL);
+  
+  treeview = g_object_get_data (G_OBJECT (window), "oligomers_treeview");
+  g_assert (treeview != NULL);
+  
+  if (FALSE == gtk_tree_model_get_iter_first ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      g_warning (_("%s@%d: treeview is empty, nothing to report\n"),
+		 __FILE__, __LINE__);
+
+      report_gs = 
+	g_string_append (report_gs, _("Treeview is empty, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  else
+    {
+      /* We have the first item of the list here. Use it !
+       */
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_TO_SEARCH_MASS,
+			  &search,
+
+			  COLUMN_OLIG_MASS_ERROR,
+			  &error,
+
+			  COLUMN_OLIG_MASS_TYPE,
+			  &type,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+
+      g_string_append_printf (report_gs, "%-12s [%-5s-->%5s] "
+			      "%-20s %-20s %-5s %-20s %-20s\n\n",
+			      _("name"), _("start"), _("end"), 
+			      _("mass to search"), _("mass error"), _("type"), 
+			      _("mono"), _("avg"));
+      
+      g_string_append_printf (report_gs, "%-12s [%-5d-->%5d] "
+			      "%-20.5lf %-20.5lf %-5s %-20.5lf %-20.5lf\n",
+			      oligomer->name, 
+			      oligomer->start_idx + 1, oligomer->end_idx + 1,
+			      search, error, type,
+			      oligomer->masspair->mono, 
+			      oligomer->masspair->avg);
+    }
+  /*
+    End of successfully  getting the first item in the treeview.
+  */
+
+
+  /* And now continue to the remaining one in the while loop.
+   */
+  while (TRUE == gtk_tree_model_iter_next ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_OLIG_TO_SEARCH_MASS,
+			  &search,
+
+			  COLUMN_OLIG_MASS_ERROR,
+			  &error,
+
+			  COLUMN_OLIG_MASS_TYPE,
+			  &type,
+
+			  COLUMN_OLIG_POINTER,
+			  &oligomer,
+
+			  -1);
+      
+      g_assert (oligomer != NULL);
+      g_assert (oligomer->masspair != NULL);
+      
+      g_string_append_printf (report_gs, "%-12s [%-5d-->%5d] "
+			      "%-20.5lf %-20.5lf %-5s %-20.5lf %-20.5lf\n",
+			      oligomer->name, 
+			      oligomer->start_idx + 1, oligomer->end_idx + 1,
+			      search, error, type,
+			      oligomer->masspair->mono, 
+			      oligomer->masspair->avg);
+    }
+  /*
+    End of getting the remaining items in the treeview.
+  */
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+gchar *
+polyxedit_searchmass_results_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						      PxmWinMngmt* winmngmt)
+{
+
+  return NULL;
+}
+
+
+
+
+/* WINDOW LIFE-CYCLE FUNCTIONS.
+ */
+void
+polyxedit_searchmass_res_wnd_really_close (GtkWidget *window)
+{
+  GPtrArray *GPA = NULL;
+
+  gint count = 0;
+
+  g_assert (window != NULL);
+  
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  /* We have a full array of arrays of oligomers to free before
+     leaving this window!
+  */
+  GPA = g_object_get_data (G_OBJECT (window), "alloligsGPA");
+  g_assert (GPA != NULL);
+  
+  count = pxmchem_oligomer_GPA_of_GPA_free (GPA);
+
+  /*
+    debug_printf (("freed %d oligomers\n", count));
+  */
+
+  gtk_widget_destroy (window);
+}
+
+
+
 gboolean
 polyxedit_searchmass_res_wnd_delete_event (GtkWidget *window,
 					   GdkEvent *event,
 					   gpointer data)
 {
+  GPtrArray *GPA = NULL;
+
+  PxmEditCtxt *editctxt = data;
+  
+  gchar *help = NULL;
   gint count = 0;
-  
-  GPtrArray *alloligsGPA = NULL;
 
-  /* We have a full array of arrays of oligomers to free before
-     leaving this window! Also we have to free the array of fragopt
-     objects.
-  */
   g_assert (window != NULL);
-  
-  alloligsGPA = g_object_get_data (G_OBJECT (window), "alloligsGPA");
-  g_assert (alloligsGPA != NULL);
-  pxmchem_oligomer_GPA_of_GPA_free (alloligsGPA);
+  g_assert (editctxt != NULL);
   
 
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
   
-  /*
-    printf ("polyxedit_elemcompos_wnd_delete_event, count is %d\n",
-    count);
+  /* We have a full array of arrays of oligomers to free before
+     leaving this window!
   */
+  GPA = g_object_get_data (G_OBJECT (window), "alloligsGPA");
+  g_assert (GPA != NULL);
+  
+  count = pxmchem_oligomer_GPA_of_GPA_free (GPA);
+
+  /*
+    debug_printf (("freed %d oligomers\n", count));
+  */
+
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
+  help = g_strdup_printf ("searchmass_results_wnd-%p", window);
+  
+  window = 
+    g_object_steal_data (G_OBJECT (editctxt->seqeditorctxt->
+				   sequence_editor_wnd),
+			 help);
+  
+  g_free (help);
+  
   /* Let Gtk+ do the rest of the work.
    */
   return FALSE;
-}
 
+}
 
 
 
