@@ -78,7 +78,7 @@ polyxedit_seqed_clipboard_import_wnd_setup (PxmEditCtxt *editctxt,
 		       PACKAGE);
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       g_free (gui_file);
@@ -92,7 +92,7 @@ polyxedit_seqed_clipboard_import_wnd_setup (PxmEditCtxt *editctxt,
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the sequence import window\n"),
+      g_critical (_("%s@%d: failed to create the sequence import window\n"),
 		  __FILE__, __LINE__);
       
       g_object_unref (G_OBJECT (xml));
@@ -196,7 +196,7 @@ polyxedit_seqed_clipboard_import_wnd_setup (PxmEditCtxt *editctxt,
   if (FALSE ==
       polyxedit_seqed_clipboard_import_wnd_sequence_format (window))
     {
-      g_critical (_("%s@%d: failed formatting the string %s in the "
+      g_critical (_("%s@%d: failed to format the string: '%s' in the "
 		    "textview.\n"),
 		  __FILE__, __LINE__, seq);
       
@@ -580,6 +580,8 @@ polyxedit_seqed_clipboard_import_wnd_purify_sequence_button (GtkWidget *
   GtkTextIter start_iter;
   GtkTextIter end_iter;
 
+  gsize size = 0;
+  
   gint iter = 0;
   gint bufferchars_length =0;
   
@@ -666,13 +668,14 @@ polyxedit_seqed_clipboard_import_wnd_purify_sequence_button (GtkWidget *
   entry = g_object_get_data (G_OBJECT (window), 
 			     "remove_other_characters_entry");
   g_assert (entry != NULL);
-  remove_chars_pattern = gtk_entry_get_text (GTK_ENTRY (entry));
+  remove_chars_pattern = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
   
   /* OK, we are now set for the iteration in the sequence string.
    */
-  bufferchars_length = strlen (bufferchars);
+  size = strlen (bufferchars);
+  g_assert (size < G_MAXINT) ;
+  bufferchars_length = (gint) size;
   
-
   /* We process the string from its last character up to its first
      character, so that if we have to remove invalid characters, the
      indices between the string's characters and the actual buffer
@@ -1113,7 +1116,7 @@ polyxedit_seqed_clipboard_selection_get (GtkWidget *widget,
       */
       gtk_selection_data_set (selection_data, GDK_SELECTION_TYPE_STRING,
 			      8 * sizeof (gchar), 
-			      seq, strlen (seq));
+			      (const guchar *) seq, strlen (seq));
 
       return;
     }
@@ -1183,7 +1186,7 @@ polyxedit_seqed_clipboard_selection_received (GtkWidget *widget,
    */
   if (selection_data->length < 0)
     {
-      g_critical (_("%s@%d: selection retrieval failed.\n"),
+      g_critical (_("%s@%d: failed to get selection.\n"),
 	     __FILE__, __LINE__);
 
       return;
@@ -1198,7 +1201,7 @@ polyxedit_seqed_clipboard_selection_received (GtkWidget *widget,
       return;
     }
 
-  seq = g_strdup (selection_data->data);
+  seq = g_strdup ((gchar *) selection_data->data);
   g_assert (seq != NULL);
 
   /* We now have our string that we have to interpret and to insert in
@@ -1273,7 +1276,7 @@ polyxedit_seqed_clipboard_selection_received (GtkWidget *widget,
       
       if (window == NULL)
 	{
-	  g_critical (_("%s@%d: failed setting up the clipboard import  "
+	  g_critical (_("%s@%d: failed to set up the clipboard import "
 			"window.\n"),
 		      __FILE__, __LINE__);
 	  
@@ -1322,7 +1325,7 @@ polyxedit_seqed_clipboard_selection_received (GtkWidget *widget,
     {
       if (-1 == polyxedit_seqed_wnd_remove_selected_oligomer (editctxt))
 	{
-	  g_critical (_("%s@%d: failed removing the selected "
+	  g_critical (_("%s@%d: failed to remove the selected "
 			"sequence portion.\n"),
 		 __FILE__, __LINE__);
 	  
@@ -1341,7 +1344,7 @@ polyxedit_seqed_clipboard_selection_received (GtkWidget *widget,
   if (-1 == polyxedit_seqed_wnd_integrate_sequence_at_point (fillGPA,
 							     editctxt))
     {
-      g_critical (_("%s@%d: failed integrating the selected "
+      g_critical (_("%s@%d: failed to integrate the selected "
 		    "sequence portion.\n"),
 	     __FILE__, __LINE__);
 
