@@ -122,7 +122,7 @@ polyxedit_seqed_kbd_key_press_event (GtkWidget *widget,
       if (FALSE == 
 	  polyxedit_seqed_kbd_del_last_char_elab_code (editctxt))
 	{
-	  g_error (_("%s@%d: failed deleting last char from elab code\n"),
+	  g_error (_("%s@%d: failed to delete last char from elab code\n"),
 		 __FILE__, __LINE__);
 	      
 	  return FALSE;
@@ -142,7 +142,7 @@ polyxedit_seqed_kbd_key_press_event (GtkWidget *widget,
       if (FALSE == 
 	  polyxedit_seqed_kbd_check_complete_elab_code (editctxt))
 	{
-	  g_error (_("%s@%d: failed checking complete elab code\n"),
+	  g_error (_("%s@%d: failed to check complete elab code\n"),
 		 __FILE__, __LINE__);
 	  
 	  return FALSE;
@@ -231,7 +231,7 @@ polyxedit_seqed_kbd_key_press_event (GtkWidget *widget,
   if (FALSE == polyxedit_seqed_kbd_alpha_handler (key_name,
 						  editctxt))
     {
-      g_error (_("%s@%d: failed handling alpha character\n"),
+      g_error (_("%s@%d: failed to handle alpha character\n"),
 	     __FILE__, __LINE__);
 	  
       return FALSE;
@@ -413,7 +413,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 						 seqeditorctxt->last_point_1_idx,
 						 editctxt))
 	    {
-	      err = g_strdup_printf ("failed eval code: '%s'",
+	      err = g_strdup_printf (_("failed to eval code: '%s'"),
 				     seqeditorctxt->eval_code);
 
 	      gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -428,13 +428,13 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 	     
 	      /* The elab_code is found erroneous, so we give the user
 	       * a chance to modify it so that it complies with the
-	       * codes of the polymer definition with which we are
-	       * working. To do that we remove the last character from
-	       * the elaborating code, so that the user may change it
-	       * into another character that completes a valid monomer
-	       * code. When this is done, we just ask that the
-	       * shortened elaborating monomer code be echoed to the
-	       * proper GtkEntry widget.
+	       * codes of the polymer chemistry definition with which
+	       * we are working. To do that we remove the last
+	       * character from the elaborating code, so that the user
+	       * may change it into another character that completes a
+	       * valid monomer code. When this is done, we just ask
+	       * that the shortened elaborating monomer code be echoed
+	       * to the proper GtkEntry widget.
 	       */
 	      polyxedit_seqed_kbd_del_last_char_elab_code (editctxt);
 	      polyxedit_seqed_kbd_echo_elab_code (editctxt);
@@ -496,7 +496,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 	   * starting with the currently parsed uppercase letter. This
 	   * is an error condition.
 	   */
-	  err = g_strdup_printf ("code already invalid: '%s'",
+	  err = g_strdup_printf (_("code already invalid: '%s'"),
 				 seqeditorctxt->elab_code);
 	  
 	  gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -526,7 +526,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 							  last_point_1_idx,
 							  editctxt))
 	    {
-	      err = g_strdup_printf ("failed eval code: '%s'",
+	      err = g_strdup_printf (_("failed to eval code: '%s'"),
 				     monomer->code);
 	      
 	      gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -610,7 +610,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 						 seqeditorctxt->last_point_1_idx,
 						 editctxt))
 	    {
-	      err = g_strdup_printf ("failed eval code: '%s'",
+	      err = g_strdup_printf (_("failed to eval code: '%s'"),
 				     seqeditorctxt->eval_code);
 	      
 	      gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -669,7 +669,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
        */
       if  (seqeditorctxt->kb_typed_chars == 0)
 	{
-	  err = g_strdup_printf ("cannot start a code with lowercase: '%s'",
+	  err = g_strdup_printf (_("cannot start a code with lowercase: '%s'"),
 				 key_name);
 	  
 	  gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -706,7 +706,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 	   * resembling seqeditorctxt->elab_code. This is an error
 	   * condition.
 	   */
-	  err = g_strdup_printf ("code already invalid: '%s'",
+	  err = g_strdup_printf (_("code already invalid: '%s'"),
 				 seqeditorctxt->elab_code);
 	  
 	  gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -736,7 +736,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 							  last_point_1_idx,
 							  editctxt))
 	    {
-	      err = g_strdup_printf ("failed eval code: '%s'",
+	      err = g_strdup_printf (_("failed eval code: '%s'"),
 				     monomer->code);
 	      
 	      gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -820,7 +820,7 @@ polyxedit_seqed_kbd_alpha_handler (gchar *key_name,
 						 seqeditorctxt->last_point_1_idx,
 						 editctxt))
 	    {
-	      err = g_strdup_printf ("failed eval code: '%s'",
+	      err = g_strdup_printf (_("failed eval code: '%s'"),
 				     seqeditorctxt->eval_code);
 	      
 	      gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -963,7 +963,7 @@ polyxedit_seqed_kbd_backspace_handler (PxmEditCtxt *editctxt)
        */
       if (-1 == polyxedit_seqed_wnd_remove_selected_oligomer (editctxt))
 	{
-	  g_critical (_("%s@%d: failed removing the selected oligomer\n"),
+	  g_critical (_("%s@%d: failed to remove the selected oligomer\n"),
 		 __FILE__, __LINE__);
 	  
 	  return FALSE;
@@ -1068,7 +1068,7 @@ polyxedit_seqed_kbd_delete_handler (PxmEditCtxt *editctxt)
        */
       if (-1 == polyxedit_seqed_wnd_remove_selected_oligomer (editctxt))
 	{
-	  g_error (_("%s@%d: failed removing the selected oligomer\n"),
+	  g_error (_("%s@%d: failed to remove the selected oligomer\n"),
 		 __FILE__, __LINE__);
 	  
 	  return FALSE;
@@ -1526,7 +1526,7 @@ polyxedit_seqed_kbd_home_handler (PxmEditCtxt *editctxt)
     target_idx = 0;
   else
     {
-      /* Compute the line number (position not index) on which the cursor
+      /* Calculate the line number (position not index) on which the cursor
 	 is currently located.
       */
       line = 
@@ -1732,7 +1732,7 @@ polyxedit_seqed_kbd_end_handler (PxmEditCtxt *editctxt)
     target_idx = length;
   else
     {
-      /* Compute the line number (position not index) on which the cursor
+      /* Calculate the line number (position not index) on which the cursor
 	 is currently located.
       */
       line = 
@@ -1927,7 +1927,7 @@ polyxedit_seqed_kbd_up_handler (PxmEditCtxt *editctxt)
      back in the sequence by monicons_per_line positions.
    */
 
-  /* Compute the number of monicons per line:
+  /* Calculate the number of monicons per line:
    */
   seqeditorctxt->monicons_per_line = 
     (seqeditorctxt->canvas_scroll_wnd_width - seqeditorctxt->left_margin)
@@ -2148,7 +2148,7 @@ polyxedit_seqed_kbd_down_handler (PxmEditCtxt *editctxt)
      forward in the sequence by monicons_per_line positions.
    */
 
-  /* Compute the number of monicons per line:
+  /* Calculate the number of monicons per line:
    */
   seqeditorctxt->monicons_per_line = 
     (seqeditorctxt->canvas_scroll_wnd_width - seqeditorctxt->left_margin)
@@ -2373,12 +2373,12 @@ polyxedit_seqed_kbd_page_up_handler (PxmEditCtxt *editctxt)
   /* If we want to scroll one page up, that means that we want to
      display some lines that currently are hidden on top of the
      window. But how many lines? The exact number of lines that
-     are currently displayed, which is computable:
+     are currently displayed, which is calculatable:
   */
   count_vis_lines = seqeditorctxt->canvas_scroll_wnd_height 
     / seqeditorctxt->monicon_size;
   
-  /* Compute the number of monicons per line:
+  /* Calculate the number of monicons per line:
    */
   seqeditorctxt->monicons_per_line = 
     (seqeditorctxt->canvas_scroll_wnd_width - seqeditorctxt->left_margin)
@@ -2417,7 +2417,7 @@ polyxedit_seqed_kbd_page_up_handler (PxmEditCtxt *editctxt)
       
       
       /* The selection does not change and cursor point neither, so do
-	 not ask that masses be recomputed.
+	 not ask that masses be recalculated.
       */
       return TRUE;
     }
@@ -2643,12 +2643,12 @@ polyxedit_seqed_kbd_page_down_handler (PxmEditCtxt *editctxt)
   /* If we want to scroll one page down, that means that we want to
      display some lines that currently are hidden on bottom of the
      window. But how many lines? The exact number of lines that
-     are currently displayed, which is computable:
+     are currently displayed, which is calculatable:
   */
   count_vis_lines = seqeditorctxt->canvas_scroll_wnd_height 
     / seqeditorctxt->monicon_size;
 
-  /* Compute the number of monicons per line:
+  /* Calculate the number of monicons per line:
    */
   seqeditorctxt->monicons_per_line = 
     (seqeditorctxt->canvas_scroll_wnd_width - seqeditorctxt->left_margin)
@@ -2694,7 +2694,7 @@ polyxedit_seqed_kbd_page_down_handler (PxmEditCtxt *editctxt)
       
       
       /* The selection does not change and cursor point neither, so do
-	 not ask that masses be recomputed.
+	 not ask that masses be recalculated.
       */
       return TRUE;
     }
@@ -3029,7 +3029,7 @@ polyxedit_seqed_kbd_check_complete_elab_code (PxmEditCtxt *editctxt)
 						      last_point_1_idx,
 						      editctxt))
 	{
-	  g_error (_("%s@%d: failed evaluating code: '%s'\n"),
+	  g_error (_("%s@%d: failed to evaluate code: '%s'\n"),
 		 __FILE__, __LINE__, monomer->code);
 	  
 	  g_ptr_array_free (fillGPA, TRUE);
@@ -3109,7 +3109,7 @@ polyxedit_seqed_kbd_force_complete_elab_code (PxmEditCtxt *editctxt)
        * resembling seqeditorctxt->elab_code. This is an error
        * condition.
        */
-      err = g_strdup_printf ("code already invalid: '%s'",
+      err = g_strdup_printf (_("code already invalid: '%s'"),
 			     seqeditorctxt->eval_code);
       
       gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -3129,7 +3129,7 @@ polyxedit_seqed_kbd_force_complete_elab_code (PxmEditCtxt *editctxt)
 						  seqeditorctxt->last_point_1_idx,
 						  editctxt))
     {
-      err = g_strdup_printf ("failed eval code: '%s'",
+      err = g_strdup_printf (_("failed eval code: '%s'"),
 			     monomer->code);
       
       gtk_entry_set_text (GTK_ENTRY (seqeditorctxt->error_code_entry),
@@ -3196,7 +3196,7 @@ polyxedit_seqed_kbd_evaluate_code (gchar *code, gint idx,
 
   if (-1 == pxmchem_monomer_get_index_by_code (code, refGPA))
     {
-      g_critical (_("%s@%d: monomer of code '%s' is not known\n"),
+      g_critical (_("%s@%d: monomer of code: '%s' is not known\n"),
 	     __FILE__, __LINE__, code);
       
       return FALSE;
@@ -3216,7 +3216,7 @@ polyxedit_seqed_kbd_evaluate_code (gchar *code, gint idx,
        */
       if (-1 == polyxedit_seqed_wnd_remove_selected_oligomer (editctxt))
 	{
-	  g_error (_("%s@%d: failed removing the selected oligomer\n"),
+	  g_error (_("%s@%d: failed to remove the selected oligomer\n"),
 		 __FILE__, __LINE__);
 	}
     }
@@ -3242,7 +3242,7 @@ polyxedit_seqed_kbd_evaluate_code (gchar *code, gint idx,
 							     idx,
 							     editctxt))
     {
-      g_critical (_("%s@%d: failed integrating new monomer '%s' in sequence\n"),
+      g_critical (_("%s@%d: failed to integrate new monomer: '%s' in sequence\n"),
 	     __FILE__, __LINE__, monomer->code);
       
       pxmchem_monomer_free (monomer);
