@@ -46,6 +46,9 @@
 #include "polyxedit-ui-findrep-options.h"
 #include "polyxedit-acidobasic.h"
 #include "polyxmass-ui-mz-ratio.h"
+#include "polyxedit-ui-reportopt.h"
+#include "polyxmass-ui-main.h"
+
 
 
 
@@ -156,15 +159,15 @@ polyxedit_seqed_window_menubar_setup (GladeXML *xml, PxmEditCtxt *editctxt)
 
   widget = 
     glade_xml_get_widget (xml, 
-			  "polyxedit_seqed_window_menu_edit_export_sound_playlist");
+			  "polyxedit_seqed_window_menu_edit_self_read_configuration");
   g_assert (widget != NULL);
   g_object_set_data 
     (G_OBJECT (seqed_menubar),
-     "polyxedit_seqed_window_menu_edit_export_sound_playlist", widget);
+     "polyxedit_seqed_window_menu_edit_self_read_configuration", widget);
   g_signal_connect (G_OBJECT (widget),
 		    "activate",
 		    G_CALLBACK 
-		    (polyxedit_seqed_window_menu_edit_export_sound_playlist),
+		    (polyxedit_seqed_window_menu_edit_self_read_configuration),
 		    editctxt);
 
 
@@ -326,17 +329,17 @@ polyxedit_seqed_window_menubar_setup (GladeXML *xml, PxmEditCtxt *editctxt)
   widget = 
     glade_xml_get_widget 
     (xml, 
-     "polyxedit_seqed_window_menu_chemistry_pka_ph_pi_computations");
+     "polyxedit_seqed_window_menu_chemistry_pka_ph_pi_calculations");
   g_assert (widget != NULL);
   g_object_set_data 
     (G_OBJECT (seqed_menubar),
-     "polyxedit_seqed_window_menu_chemistry_pka_ph_pi_computations", widget);
+     "polyxedit_seqed_window_menu_chemistry_pka_ph_pi_calculations", widget);
   
   g_signal_connect 
     (G_OBJECT (widget),
      "activate",
      G_CALLBACK 
-     (polyxedit_seqed_window_menu_chemistry_pka_ph_pi_computations),
+     (polyxedit_seqed_window_menu_chemistry_pka_ph_pi_calculations),
      editctxt);
   
   widget = 
@@ -367,6 +370,42 @@ polyxedit_seqed_window_menubar_setup (GladeXML *xml, PxmEditCtxt *editctxt)
 		    editctxt);
 
 
+  /* REPORT MENUITEM
+   */
+  widget = glade_xml_get_widget 
+    (xml, 
+     "polyxedit_seqed_window_menu_reports_report_options");
+
+  g_assert (widget != NULL);
+
+  g_object_set_data 
+    (G_OBJECT (seqed_menubar),
+     "polyxedit_seqed_window_menu_reports_report_options", widget);
+
+  g_signal_connect (G_OBJECT (widget),
+		    "activate",
+		    G_CALLBACK 
+		    (polyxedit_seqed_window_menu_reports_report_options),
+		    editctxt);
+
+  widget = glade_xml_get_widget 
+    (xml, 
+     "polyxedit_seqed_window_menu_reports_make_reports");
+
+  g_assert (widget != NULL);
+
+  g_object_set_data 
+    (G_OBJECT (seqed_menubar),
+     "polyxedit_seqed_window_menu_reports_make_reports", widget);
+
+  g_signal_connect (G_OBJECT (widget),
+		    "activate",
+		    G_CALLBACK 
+		    (polyxedit_seqed_window_menu_reports_make_reports),
+		    editctxt);
+
+
+
   return GTK_WIDGET (seqed_menubar);
 }
 
@@ -413,15 +452,15 @@ polyxedit_seqed_window_menu_file_save (GtkMenuItem *menuitem,
 				      editctxt->polymer->plminfo->file,
 				      NULL))
     {
-      g_critical (_("%s@%d: error saving polymer to file '%s'\n"),
+      g_critical (_("%s@%d: failed to save polymer sequence to file: '%s'\n"),
 	     __FILE__, __LINE__, 
 	     editctxt->polymer->plminfo->file);
       
       /* Echo a failure message to the user.
        */
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					     "file save failed",
-					     POLYXMASS_NORM_MSG_TIMEOUT);
+					_("Failed to save polymer sequence to file"),
+					POLYXMASS_NORM_MSG_TIMEOUT);
 
       return;
     }
@@ -435,8 +474,8 @@ polyxedit_seqed_window_menu_file_save (GtkMenuItem *menuitem,
   /* Echo a success message to the user.
    */
   polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					 "file save successful",
-					 POLYXMASS_NORM_MSG_TIMEOUT);
+				    _("Succeeded to save polymer sequence to file"),
+				    POLYXMASS_NORM_MSG_TIMEOUT);
   
   return;
 }
@@ -471,7 +510,7 @@ polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
 
   /* Create the file selector */
   dialog = 
-    gtk_file_chooser_dialog_new ("Save Polymer Sequence File",
+    gtk_file_chooser_dialog_new (_("Save Polymer Sequence File"),
 				 GTK_WINDOW (editctxt->seqeditorctxt->
 					     sequence_editor_wnd),
 				 GTK_FILE_CHOOSER_ACTION_SAVE,
@@ -485,7 +524,7 @@ polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
       
       if (TRUE == g_file_test (filename, G_FILE_TEST_EXISTS))
 	{
-	  g_critical ("%s@%d: file does exist already: '%s'\n",
+	  g_critical (_("%s@%d: file does exist already: '%s'\n"),
 		 __FILE__, __LINE__, filename);
 	  
 	  g_free (filename);
@@ -518,7 +557,7 @@ polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
   
   if (filep == NULL)
     {
-      g_critical (_("%s@%d: error with opening file %s\n"),
+      g_critical (_("%s@%d: failed to open file: '%s'\n"),
 	     __FILE__, __LINE__, filename);
       
       g_free (filename);
@@ -532,14 +571,14 @@ polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
 					    filename,
 					    NULL))
     {
-      g_critical (_("%s@%d: error saving polymer to file '%s'\n"),
+      g_critical (_("%s@%d: failed to save polymer sequence to file: '%s'\n"),
 	     __FILE__, __LINE__, filename);
       
       /* Echo a failure message to the user.
        */
       polyxmass_timeoutmsg_message_set 
 	((GtkWindow *) editctxt->seqeditorctxt->sequence_editor_wnd,
-	 "file save failed",
+	 _("Failed to save polymer sequence to file"),
 	 POLYXMASS_LONG_MSG_TIMEOUT);
       
       g_free (filename);
@@ -568,7 +607,7 @@ polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
    */
   polyxmass_timeoutmsg_message_set ((GtkWindow *) editctxt->seqeditorctxt->
 				    sequence_editor_wnd,
-				    "File save successful",
+				    _("Succeeded to save polymer sequence to file"),
 				    POLYXMASS_NORM_MSG_TIMEOUT);
 
 
@@ -655,8 +694,8 @@ polyxedit_seqed_window_menu_edit_paste (GtkMenuItem *menuitem,
 
 
 void
-polyxedit_seqed_window_menu_edit_export_sound_playlist (GtkMenuItem *menuitem,
-					 gpointer data)
+polyxedit_seqed_window_menu_edit_self_read_configuration (GtkMenuItem *menuitem,
+							  gpointer data)
 {
   /* The data parameter is editctxt.
    */
@@ -667,7 +706,7 @@ polyxedit_seqed_window_menu_edit_export_sound_playlist (GtkMenuItem *menuitem,
 
   /* Just call the function that's responsible for that work:
    */
-  polyxedit_seqed_wnd_export_sound_playlist (editctxt);
+  polyxedit_seqed_wnd_self_read_configuration (editctxt);
   
   return;
 }
@@ -709,7 +748,7 @@ polyxedit_seqed_window_menu_edit_find (GtkMenuItem *menuitem,
   */
   if (NULL == polyxedit_findrep_opt_setup_wnd (editctxt))
     {
-      g_critical (_("%s@%d: failed displaying the find-replace window.\n"),
+      g_critical (_("%s@%d: failed to display the find/replace window.\n"),
 	     __FILE__, __LINE__);
     }
 
@@ -735,8 +774,7 @@ polyxedit_seqed_window_menu_view_calculationsoptions (GtkMenuItem *menuitem,
   window = polyxedit_calculations_opt_wnd_setup (editctxt);
   
   if (NULL == window)
-    g_error (_("%s@%d: the calculations options window could not"
-	     "be created.\n"),
+    g_error (_("%s@%d: failed to create the calculations options window.\n"),
 	   __FILE__, __LINE__);
 }
 
@@ -752,7 +790,7 @@ polyxedit_seqed_window_menu_view_completionslist (GtkMenuItem *menuitem,
   g_assert (editctxt != NULL);
 
   if (FALSE == polyxedit_seqed_kbd_check_complete_elab_code (editctxt))
-    g_error (_("%s@%d: failed checking complete elab code\n"),
+    g_error (_("%s@%d: failed to check complete elab code\n"),
 	     __FILE__, __LINE__);
 }
 
@@ -774,7 +812,7 @@ polyxedit_seqed_window_menu_chemistry_modifs_monomer (GtkMenuItem *menuitem,
   g_assert (editctxt != NULL);
 
   if (NULL == polyxedit_ui_monomer_modif_setup_wnd (editctxt))
-    g_critical (_("%s@%d: failed opening the monomer modification window\n"),
+    g_critical (_("%s@%d: failed to open the monomer modification window\n"),
 	   __FILE__, __LINE__);
   
   return ;
@@ -793,7 +831,7 @@ polyxedit_seqed_window_menu_chemistry_modifs_polymer (GtkMenuItem *menuitem,
   g_assert (editctxt != NULL);
 
   if (NULL == polyxedit_ui_polymer_modif_setup_wnd (editctxt))
-    g_critical (_("%s@%d: failed opening the polymer modification window\n"),
+    g_critical (_("%s@%d: failed to open the polymer modification window\n"),
 	   __FILE__, __LINE__);
   
   return ;
@@ -813,7 +851,7 @@ polyxedit_seqed_window_menu_chemistry_cleave (GtkMenuItem *menuitem,
 
 
   if (NULL == polyxedit_cleave_opt_wnd_setup (editctxt))
-    g_critical (_("%s@%d: failed opening the cleavage options window\n"),
+    g_critical (_("%s@%d: failed to open the cleavage options window\n"),
 	   __FILE__, __LINE__);
   
   return ;
@@ -833,7 +871,7 @@ polyxedit_seqed_window_menu_chemistry_fragment (GtkMenuItem *menuitem,
 
 
   if (NULL == polyxedit_fragment_opt_wnd_setup (editctxt))
-    g_critical (_("%s@%d: failed opening the fragmentation options window\n"),
+    g_critical (_("%s@%d: failed to open the fragmentation options window\n"),
 	   __FILE__, __LINE__);
   
   return ;
@@ -848,14 +886,37 @@ polyxedit_seqed_window_menu_chemistry_compos_elem (GtkMenuItem *menuitem,
    */
   PxmEditCtxt *editctxt = data;
   
+  GtkWidget *window = NULL;
+  
   
   g_assert (editctxt != NULL);
+  g_assert (editctxt->seqeditorctxt->sequence_editor_wnd != NULL);
+
+
+  window = polyxedit_elemcompos_wnd_setup (editctxt);
   
-
-  if (NULL == polyxedit_elemcompos_wnd_setup (editctxt))
-    g_critical (_("%s@%d: failed opening the elemental composition window\n"),
-	   __FILE__, __LINE__);
-
+  if (window == NULL)
+    {
+      g_critical (_("%s@%d: failed to open the elemental composition window\n"),
+		  __FILE__, __LINE__);
+  
+      return;
+    }
+  
+  /* Register this results' window !
+   */
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXEDIT",
+       window,
+       editctxt->seqeditorctxt->sequence_editor_wnd,
+       editctxt,
+       _("Results of Elemental Composition"),
+       NULL,
+       TRUE,
+       polyxedit_elemcompos_wnd_make_report))
+    g_critical (_("%s@%d: failed to register the elemental composition "
+		  "results' window\n"),
+		__FILE__, __LINE__);
   return ;
 }
 
@@ -868,21 +929,45 @@ polyxedit_seqed_window_menu_chemistry_compos_mnm (GtkMenuItem *menuitem,
    */
   PxmEditCtxt *editctxt = data;
   
+  GtkWidget *window = NULL;
+  
   
   g_assert (editctxt != NULL);
+  g_assert (editctxt->seqeditorctxt->sequence_editor_wnd != NULL);
   
-
-  if (NULL == polyxedit_mnmcompos_wnd_setup (editctxt))
-    g_critical (_("%s@%d: failed opening the elemental composition window\n"),
-	   __FILE__, __LINE__);
+  window = polyxedit_mnmcompos_wnd_setup (editctxt);
   
+  if (window == NULL)
+    {
+      g_critical (_("%s@%d: failed to open the elemental "
+		    "composition window\n"),
+		  __FILE__, __LINE__);
+      
+      return;
+    }
+  
+  /* Register this results' window !
+   */
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXEDIT",
+       window,
+       editctxt->seqeditorctxt->sequence_editor_wnd,
+       editctxt,
+       _("Results of Monomeric Composition"),
+       NULL,
+       TRUE,
+       polyxedit_mnmcompos_wnd_make_report))
+    g_critical (_("%s@%d: failed to register the monomeric composition "
+		  "results' window\n"),
+		__FILE__, __LINE__);
   return ;
 }
 
 
 void
-polyxedit_seqed_window_menu_chemistry_pka_ph_pi_reload_data
-(GtkMenuItem *menuitem, gpointer data)
+polyxedit_seqed_window_menu_chemistry_pka_ph_pi_reload_data (GtkMenuItem *
+							     menuitem, 
+							     gpointer data)
 {
   /* The data parameter is editctxt.
    */
@@ -893,7 +978,7 @@ polyxedit_seqed_window_menu_chemistry_pka_ph_pi_reload_data
   
   if (FALSE == polyxedit_acidobasic_reload_data (editctxt))
     {
-      g_critical (_("%s@%d: failed reloading the acido-basic "
+      g_critical (_("%s@%d: failed to reload the acido-basicity "
 	       "data from xml file\n"),
 	     __FILE__, __LINE__);
     }
@@ -902,8 +987,9 @@ polyxedit_seqed_window_menu_chemistry_pka_ph_pi_reload_data
 }
 
 void
-polyxedit_seqed_window_menu_chemistry_pka_ph_pi_computations 
-(GtkMenuItem *menuitem, gpointer data)
+polyxedit_seqed_window_menu_chemistry_pka_ph_pi_calculations (GtkMenuItem *
+							      menuitem, 
+							      gpointer data)
 {
   /* The data parameter is editctxt.
    */
@@ -914,8 +1000,8 @@ polyxedit_seqed_window_menu_chemistry_pka_ph_pi_computations
   
   if (FALSE == polyxedit_acidobasic_setup_framework (editctxt))
     {
-      g_critical (_("%s@%d: failed setting up the acido-basic "
-	       "computing framework\n"),
+      g_critical (_("%s@%d: failed to set up the acido-basicity "
+	       "calculations framework\n"),
 	     __FILE__, __LINE__);
     }
 
@@ -935,7 +1021,7 @@ polyxedit_seqed_window_menu_chemistry_searchmass (GtkMenuItem *menuitem,
   
 
   if (NULL == polyxedit_searchmass_opt_setup_wnd (editctxt))
-    g_critical (_("%s@%d: failed opening the search mass options window\n"),
+    g_critical (_("%s@%d: failed to open the search mass options window\n"),
 	   __FILE__, __LINE__);
   
   return ;
@@ -950,31 +1036,117 @@ polyxedit_seqed_window_menu_chemistry_mz_ratio_calc (GtkMenuItem *menuitem,
    */
   PxmEditCtxt *editctxt = data;
   
+  GtkWidget *parent_wnd = NULL;
+  GtkWidget *window = NULL;
+
   GPtrArray *atomGPA = NULL;
   
-  GtkWindow *parent_wnd = NULL;
-  
-  
+
   g_assert (editctxt != NULL);
   
   atomGPA = editctxt->polchemdefctxt->polchemdef->atomGPA;
   g_assert (atomGPA != NULL);
   
-  parent_wnd = (GtkWindow *) editctxt->seqeditorctxt->sequence_editor_wnd;
+  parent_wnd = editctxt->seqeditorctxt->sequence_editor_wnd;
   g_assert (parent_wnd != NULL);
   
 
   /* We call the mz ratio calculator window with a number of
      parameters and not simply the editctxt pointer, because that same
      window might be called through the polyxcalc module.
+  */
+  window =  polyxmass_mz_ratio_wnd_setup (atomGPA, 
+					  editctxt->ionizerule,
+					  parent_wnd,
+					  "POLYXEDIT");
+ 
+  if (window == NULL)
+    {
+      g_critical (_("%s@%d: failed to open the m/z ratio calculator window\n"),
+		  __FILE__, __LINE__);
+      
+      return;
+    }
 
-     
+  /* Register this results' window !
    */
-  if (NULL == polyxmass_mz_ratio_wnd_setup (atomGPA, 
-					    editctxt->ionizerule,
-					    parent_wnd))
-    g_critical (_("%s@%d: failed opening the mz ratio calculator window\n"),
-	   __FILE__, __LINE__);
+  if (NULL == polyxmass_winmngmt_register_window 
+      ("POLYXEDIT",
+       window,
+       editctxt->seqeditorctxt->sequence_editor_wnd,
+       editctxt,
+       _("Results of m/z Calculations"),
+       NULL,
+       TRUE,
+       polyxmass_mz_ratio_wnd_make_report))
+    g_critical (_("%s@%d: failed to register the m/z calculations "
+		  "results' window\n"),
+		__FILE__, __LINE__);
+
+  return;
+}
+
+
+void
+polyxedit_seqed_window_menu_reports_report_options (GtkMenuItem *menuitem,
+					       gpointer data)
+{
+  /* The data parameter is editctxt.
+   */
+  PxmEditCtxt *editctxt = data;
+  
+  GtkWidget *report_opt_wnd = NULL;
+  
+  g_assert (editctxt != NULL);
+
+
+  /* We only setup a new report options window if it does not already
+     exist in the editctxt.
+   */
+  report_opt_wnd = g_object_get_data (G_OBJECT (editctxt->seqeditorctxt->
+						sequence_editor_wnd), 
+				      "report_opt_wnd");
+
+  if (report_opt_wnd == NULL)
+    {
+      report_opt_wnd = polyxedit_report_opt_wnd_setup (editctxt);
+      
+      if (NULL == report_opt_wnd)
+	{
+	  g_critical (_("%s@%d: failed to open the report options window\n"),
+		      __FILE__, __LINE__);
+	  return;
+	}
+    }
+  else
+    {
+      gtk_widget_show_all (GTK_WIDGET (report_opt_wnd));
+    }
+  
+  return;
+}
+
+void
+polyxedit_seqed_window_menu_reports_make_reports (GtkMenuItem *menuitem,
+					  gpointer data)
+{
+  /* The data parameter is editctxt. But we do not use it here.
+   */
+
+  GtkWidget *window = NULL;
+  
+
+  /* All we want to do is provide the user with the window that lists
+     all the registered windows, for her to choose the windows, for
+     which the reports have to be done.
+   */
+  window = (GtkWidget *)
+    on_polyxmass_polyxmass_view_window_management_activate (NULL,
+							    polyxmass_main_wnd);
+  
+  if (window == NULL)
+    g_critical (_("%s@%d: failed to create the window management window\n"),
+		__FILE__, __LINE__);
   
   return;
 }
