@@ -28,7 +28,7 @@
    Boston, MA 02111-1307, USA.
 */
 #include "polyxmass-polchemdefctxt.h"
-#include "polyxmass-self-speak.h"
+#include "polyxmass-self-read.h"
 
 
 
@@ -123,11 +123,11 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
   */
   if (ps == NULL)
     {
-      g_critical (_("%s@%d: could not retrieve polymer definition data"
-		    " for type '%s'. Please, make sure that the "
+      g_critical (_("%s@%d: failed to retrieve polymer chemistry definition"
+		    " data for type: '%s'. Please, make sure that the "
 		    "GNU polyxmass software suite is properly installed. "
 		    "In particular, is the GNU polyxmass-common package "
-		    "installed ?\n"),
+		    "installed?\n"),
 		  __FILE__, __LINE__, type);
 
       return FALSE;
@@ -160,7 +160,8 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
      monomer code entered at the keyboard... and for the
      modifications' monicons.
 
-     - properly load the polymer definition from its 'ps->file'.
+     - properly load the polymer chemistry definition from its
+       'ps->file'.
   */
 
   /* The monicons...
@@ -180,8 +181,8 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
     {
       /* This is really an error, as we cannot go on in any way.
        */
-      g_error (_("%s@%d: failed loading monomer monicon "
-		 "specs from file: %s\n"),
+      g_error (_("%s@%d: failed to load monomer monicon "
+		 "specs from file: '%s'\n"),
 	       __FILE__, __LINE__, dic);
     }
   
@@ -194,7 +195,7 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
     {
       /* This is really an error, as we cannot go on in any way.
        */
-      g_error (_("%s@%d: failed loading modif monicon specs from file: %s\n"),
+      g_error (_("%s@%d: failed to load modif monicon specs from file: '%s'\n"),
 	     __FILE__, __LINE__, dic);
     }
   
@@ -216,7 +217,7 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
     {
       /* This is really an error, as we cannot go on in any way.
        */
-      g_error (_("%s@%d: failed loading monomer sound specs from file: %s\n"),
+      g_error (_("%s@%d: failed to load monomer sound specs from file: '%s'\n"),
 	     __FILE__, __LINE__, dic);
     }
   
@@ -228,7 +229,7 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
     {
       /* This is really an error, as we cannot go on in any way.
        */
-      g_error (_("%s@%d: failed loading modif sounds specs from file: %s\n"),
+      g_error (_("%s@%d: failed to load modif sounds specs from file: '%s'\n"),
 	     __FILE__, __LINE__, dic);
     }
   
@@ -251,7 +252,7 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
   
   if (polchemdefctxt->polchemdef == NULL)
     {
-      g_critical (_("%s@%d: Could not render a polchemdef from file '%s'\n"),
+      g_critical (_("%s@%d: failed to render a polchemdef from file: '%s'\n"),
 	     __FILE__, __LINE__, ps->file);
       
       return FALSE;
@@ -260,7 +261,8 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
   /* We want that the polymer chemistry definition file be self-conscious
      of where its data are located in the system.
   */
-  /* Set the directory of the polymer definition-related data:
+  /* Set the directory of the polymer chemistry definition-related
+     data:
    */
   pxmchem_polchemdef_set_dir (polchemdefctxt->polchemdef, ps->dir);
   
@@ -277,11 +279,11 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
   
 #endif
   
-  /* Now that the polymer definition has been rendered into memory
-     from the xml-formatted file, we should make sure that each
+  /* Now that the polymer chemistry definition has been rendered into
+     memory from the xml-formatted file, we should make sure that each
      monomer object in the polchemdef->monomerGPA has a corresponding
      PxmMonomerSpec instance in the array that we had filled before
-     (by reading the monicons.dic file). 
+     (by reading the monicons.dic file).
 
      Also, it is of critical importance that both array do contain the
      same number of items, otherwise we would not know where is/are
@@ -354,8 +356,8 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
       */
       if (as == NULL)
 	{
-	  g_critical (_("%s@%d: failed finding a matching atom definition"
-		   " for polymer chemistry definition '%s'.\n"),
+	  g_critical (_("%s@%d: failed to find a matching atom definition"
+		   " for polymer chemistry definition: '%s'.\n"),
 		 __FILE__, __LINE__, polchemdefctxt->polchemdef->type);
       
 	  return FALSE;
@@ -369,8 +371,8 @@ polyxmass_polchemdefctxt_init_with_type (PxmPolchemdefCtxt *polchemdefctxt,
 					      polchemdefctxt->polchemdef->
 					      atomGPA))
 	{
-	  g_critical (_("%s@%d: failed parsing the atom definition "
-		   "file '%s'.\n"),
+	  g_critical (_("%s@%d: failed to parse the atom definition "
+		   "file: '%s'.\n"),
 		 __FILE__, __LINE__, as->file);
       
 	  return FALSE;
@@ -489,8 +491,8 @@ polyxmass_polchemdefctxt_unref (PxmPolchemdefCtxt *pdfctxt)
    */
   if (pdfctxt->refcount <= 0)
     {
-      g_message (_("%s@%d: closing last polymer definition context of type: "
-		   "'%s'\n"),
+      g_message (_("%s@%d: about to close last polymer chemistry "
+		   "definition context of type: '%s'\n"),
 		 __FILE__, __LINE__, 
 		 pdfctxt->polchemdef->type);
       
@@ -512,9 +514,9 @@ polyxmass_polchemdefctxt_unref (PxmPolchemdefCtxt *pdfctxt)
       return 0;
     }
   
-  /* If here, that means that this polymer definition context is in
-     use by at least one object. Return the refcount of this
-     polchemdefctxt.
+  /* If here, that means that this polymer chemistry definition
+     context is in use by at least one object. Return the refcount of
+     this polchemdefctxt.
    */
   return pdfctxt->refcount;
 }
@@ -534,7 +536,7 @@ polyxmass_polchemdefctxt_ref_from_type (GPtrArray *GPA, gchar *type)
     (pdfctxt->refcount)++;
   else
     {
-      g_critical (_("%s@%d: polymer definition not found: '%s'\n"),
+      g_critical (_("%s@%d: polymer chemistry definition not found: '%s'\n"),
 	     __FILE__, __LINE__, 
 	     type);
       
@@ -559,7 +561,7 @@ polyxmass_polchemdefctxt_unref_from_type (GPtrArray *GPA, gchar *type)
     (pdfctxt->refcount)--;
   else
     {
-      g_critical (_("%s@%d: polymer definition not found: '%s'\n"),
+      g_critical (_("%s@%d: polymer chemistry definition not found: '%s'\n"),
 	     __FILE__, __LINE__, type);
       
       return -1;
@@ -571,7 +573,7 @@ polyxmass_polchemdefctxt_unref_from_type (GPtrArray *GPA, gchar *type)
    */
   if (pdfctxt->refcount <= 0)
     {
-      g_message (_("%s@%d: closing last polymer definition of type: '%s'\n"),
+      g_message (_("%s@%d: about to close last polymer chemistry definition of type: '%s'\n"),
 		 __FILE__, __LINE__, 
 		 type);
       
@@ -586,9 +588,9 @@ polyxmass_polchemdefctxt_unref_from_type (GPtrArray *GPA, gchar *type)
       return 0;
     }
   
-  /* If here, that means that this polymer definition context is in
-     use by at least one object. Return the refcount of this
-     polchemdefctxt.
+  /* If here, that means that this polymer chemistry definition
+     context is in use by at least one object. Return the refcount of
+     this polchemdefctxt.
    */
   return pdfctxt->refcount;
 }
@@ -604,7 +606,7 @@ polyxmass_polchemdefctxt_remove_from_GPA (GPtrArray *GPA,
 
   if (FALSE == g_ptr_array_remove (GPA, pdfctxt))
     {
-      g_warning (_("%s@%d: failed removing polymer definition "
+      g_warning (_("%s@%d: failed to remove polymer chemistry definition "
 		   "of type: '%s'\n"),
 		 __FILE__, __LINE__, 
 		 pdfctxt->polchemdef->type);
