@@ -35,6 +35,7 @@
 #include "polyxdef-main.h"
 #include "polyxedit-main.h"
 #include "polyxedit-ui-masses-display-wnd.h"
+#include "polyxmass-ui-window-mngmt.h"
 
 
 GtkWindow*
@@ -56,7 +57,7 @@ polyxmass_ui_main_setup_wnd (void)
 
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -65,7 +66,7 @@ polyxmass_ui_main_setup_wnd (void)
   
   if (polyxmass_main_wnd == NULL)
     {
-      g_error (_("%s@%d: failed creating the program window\n"),
+      g_error (_("%s@%d: failed to create the program window\n"),
 	     __FILE__, __LINE__);
     }
   
@@ -106,6 +107,19 @@ polyxmass_ui_main_setup_wnd (void)
 		    polyxmass_main_wnd);
 
 
+  widget = glade_xml_get_widget (xml, "polyxmass_view_window_management");
+  g_assert (widget != NULL);
+
+  g_object_set_data (G_OBJECT (polyxmass_main_wnd),
+		     "polyxmass_view_window_management", widget);
+
+  g_signal_connect (G_OBJECT (widget),
+		    "activate",
+		    G_CALLBACK 
+		    (on_polyxmass_polyxmass_view_window_management_activate),
+		    polyxmass_main_wnd);
+
+
 
   /* polyxdef menu (Atom Definition).
    */
@@ -308,7 +322,7 @@ on_polyxmass_console_window_visible_activate (GtkWidget *widget,
   if (FALSE == 
       GTK_WIDGET_VISIBLE (GTK_WIDGET (polyxmass_console_wnd)))
     {    
-      gtk_widget_show (GTK_WIDGET (polyxmass_console_wnd));
+      gtk_window_present (GTK_WINDOW (polyxmass_console_wnd));
       gtk_check_menu_item_set_active  ((GtkCheckMenuItem *) widget,
 				       TRUE);
     }
@@ -322,6 +336,42 @@ on_polyxmass_console_window_visible_activate (GtkWidget *widget,
 }
 
 
+GtkWidget *
+on_polyxmass_polyxmass_view_window_management_activate (GtkWidget *widget,
+						  gpointer data)
+{
+  GtkWidget *parent = data;
+  GtkWidget *window = NULL;
+
+  /* We do not use the widget parameter. Do not forget that this
+     function can be called by other menus, like the menu of the
+     polymer sequence editor. We only want one window like this one.
+  */
+  g_assert (parent != NULL);
+
+  window = g_object_get_data (G_OBJECT (parent), "window_mngmt_wnd");
+  
+  if (window != NULL)
+    {
+      gtk_window_present (GTK_WINDOW (window));
+  
+      return window;
+    }
+  
+  window = polyxmass_window_mngmt_wnd_setup (parent);
+  
+  if (window == NULL)
+    g_critical (_("%s@%d: failed to create the window management window\n"),
+		__FILE__, __LINE__);
+  else
+    {
+      g_object_set_data (G_OBJECT (parent), "window_mngmt_wnd", window);
+    }
+  
+  return window;
+}
+
+
 
 /* polyxdef menu (Atom Definition)..
  */
@@ -358,8 +408,8 @@ on_polyxdef_open_atom_definition_activate (GtkWidget *widget,
   */
   if (NULL == polyxdef_main_prepare_new_context (filename,
 						 ATOM_DEF))
-    g_critical (_("%s@%d: failed creating an atom definition context"
-	     " for file '%s'.\n"),
+    g_critical (_("%s@%d: failed to create an atom definition context"
+	     " for file: '%s'.\n"),
 	   __FILE__, __LINE__, filename);
   
   /* The filename was set to this window as a full datum with name
@@ -382,7 +432,7 @@ on_polyxdef_new_atom_definition_activate (GtkWidget *widget,
   */
   if (NULL == polyxdef_main_prepare_new_context (NULL,
 						 ATOM_DEF))
-    g_critical (_("%s@%d: failed creating an atom definition context\n"),
+    g_critical (_("%s@%d: failed to create an atom definition context\n"),
 	   __FILE__, __LINE__);
   
   return 1;
@@ -398,8 +448,8 @@ on_polyxdef_open_polymer_definition_activate (GtkWidget *widget,
   GtkWidget *parent = data;
   GtkWidget *window = NULL;
 
-  gchar *filename = NULL;
-    
+  PxmPolchemdefSpec *ps = NULL;
+
   
   g_assert (parent != NULL);
   
@@ -408,9 +458,9 @@ on_polyxdef_open_polymer_definition_activate (GtkWidget *widget,
 					    | PXM_FILE_CHOOSE_GTK);
   g_assert (window != NULL);
 
-  filename = g_object_get_data (G_OBJECT (parent), "polchemdefs_filename");
+  ps = g_object_get_data (G_OBJECT (parent), "polchemdefspec");
 
-  if (filename == NULL)
+  if (ps == NULL)
     {
       /*
 	debug_printf (("nothing\n"));
@@ -418,24 +468,30 @@ on_polyxdef_open_polymer_definition_activate (GtkWidget *widget,
       return 0;
     }
 
+  /*
+    debug_printf (("ps has type value: '%s' and file value: '%s'\n", 
+    ps->type, ps->file));
+  */
+
+
   /* At this time we can start the creation of a new 
      polymer chemistry definition context...
   */
-  if (NULL == polyxdef_main_prepare_new_context (filename,
+  if (NULL == polyxdef_main_prepare_new_context (ps->file,
 						 POLCHEM_DEF))
-    g_critical (_("%s@%d: failed creating an polymer chemistry "
-	     "definition context for file '%s'.\n"),
-	   __FILE__, __LINE__, filename);
+    g_critical (_("%s@%d: failed to create an polymer chemistry "
+	     "definition context for file: '%s'.\n"),
+	   __FILE__, __LINE__, ps->file);
   
 
-  /* The filename was set to this window as a full datum with name
-     "polchemdefs_filename"... Which means tha we MUST NOT free it
-     using g_free() but by setting to the same window ('parent')
-     either a NULL pointer, or doing nothing: in that latter case, the
-     memory stays occupied until overwritten by another "opening
-     process".
+  /* The allocated ps object was set to this window as a full datum
+     with name "polchemdefspec"... Which means tha we MUST NOT free it
+     using libpolyxmass_polchemdefspec_free() but by setting to the
+     same window ('parent') either a NULL pointer, or doing nothing:
+     in that latter case, the memory stays occupied until overwritten
+     by another "opening process".
   */
-  g_object_set_data (G_OBJECT (parent), "polchemdefs_filename", NULL);
+  g_object_set_data (G_OBJECT (parent), "polchemdefspec", NULL);
   
   return 1;
 }
@@ -448,7 +504,7 @@ on_polyxdef_new_polymer_definition_activate (GtkWidget *widget,
   */
   if (NULL == polyxdef_main_prepare_new_context (NULL,
 						 POLCHEM_DEF))
-    g_critical (_("%s@%d: failed creating a new polymer"
+    g_critical (_("%s@%d: failed to create a new polymer"
 	     " chemistry definition context\n"),
 	   __FILE__, __LINE__);
   
@@ -468,7 +524,7 @@ on_polyxcalc_new_calculator_without_polchemdef_activate (GtkWidget *widget,
   
   if (calcctxt == NULL)
     {
-      g_critical (_("%s@%d: failed creating a new mass calculator context.\n"),
+      g_critical (_("%s@%d: failed to create a new mass calculator context.\n"),
 	     __FILE__, __LINE__);
       
       return 0;
@@ -498,10 +554,6 @@ on_polyxcalc_new_calculator_with_polchemdef_activate (GtkWidget *widget,
   
   ps = g_object_get_data (G_OBJECT (parent), "polchemdefspec");
 
-  /*
-    debug_printf (("ps has type value '%s'\n", ps->type));
-  */
-  
   if (ps == NULL)
     {
       /*
@@ -511,19 +563,28 @@ on_polyxcalc_new_calculator_with_polchemdef_activate (GtkWidget *widget,
     }
 
   /*
-    debug_printf (("ps has type value '%s'\n", ps->type));
+    debug_printf (("ps has type value: '%s'\n", ps->type));
   */
 
   calcctxt = polyxcalc_main_prepare_new_context (ps);
   
   if (calcctxt == NULL)
     {
-      g_critical (_("%s@%d: failed creating a new mass calculator context.\n"),
+      g_critical (_("%s@%d: failed to create a new mass calculator context.\n"),
 	     __FILE__, __LINE__);
       
       return 0;
     }
   
+  /* The allocated ps object was set to this window as a full datum
+     with name "polchemdefspec"... Which means tha we MUST NOT free it
+     using libpolyxmass_polchemdefspec_free() but by setting to the
+     same window ('parent') either a NULL pointer, or doing nothing:
+     in that latter case, the memory stays occupied until overwritten
+     by another "opening process".
+  */
+  g_object_set_data (G_OBJECT (parent), "polchemdefspec", NULL);
+
   return 1;
 }
 
@@ -543,7 +604,7 @@ on_polyxedit_open_sequence_file_activate (GtkWidget *widget,
   g_assert (parent != NULL);
   
   
-  dialog = gtk_file_chooser_dialog_new ("Open Polymer Sequence File",
+  dialog = gtk_file_chooser_dialog_new (_("Open Polymer Sequence File"),
 					GTK_WINDOW (parent),
 					GTK_FILE_CHOOSER_ACTION_OPEN,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -574,8 +635,8 @@ on_polyxedit_open_sequence_file_activate (GtkWidget *widget,
      editing context...
   */
   if (NULL == polyxedit_main_prepare_new_context_open_file (filename))
-    g_critical (_("%s@%d: failed creating a polymer sequence editor "
-	     "context for file '%s'.\n"),
+    g_critical (_("%s@%d: failed to create a polymer sequence editor "
+	     "context for file: '%s'.\n"),
 	   __FILE__, __LINE__, filename);
 
   g_free (filename);
@@ -592,8 +653,8 @@ on_polyxedit_new_sequence_file_activate (GtkWidget *widget,
 {
   
   if (NULL == polyxedit_main_prepare_new_context_new_file ())
-    g_critical (_("%s@%d: failed creating a new polymer sequence editor"
-	     "context.\n"),
+    g_critical (_("%s@%d: failed to create a new polymer sequence editor"
+	     " context.\n"),
 	   __FILE__, __LINE__);
   
   return 1;
@@ -641,7 +702,7 @@ on_polyxmass_about_activate (GtkWidget *widget,
   
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
   
     return FALSE;
@@ -651,7 +712,7 @@ on_polyxmass_about_activate (GtkWidget *widget,
   
   if (window == NULL)
     {
-      g_error (_("%s@%d: failed creating the version-showing window\n"),
+      g_error (_("%s@%d: failed to create the program version display window\n"),
 	     __FILE__, __LINE__);
     
     return FALSE;
