@@ -35,7 +35,8 @@
 GtkWidget *
 polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
 			      PxmIonizerule *ionizerule,
-			      GtkWindow *parent_wnd)
+			      GtkWidget *parent_wnd,
+			      gchar *module)
 {
   GtkWidget *widget = NULL;
   GtkWidget *window = NULL;
@@ -57,6 +58,7 @@ polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
   g_assert (parent_wnd != NULL);
 
 
+  g_assert (module != NULL);
 
   gui_file = 
     g_strdup_printf ("%s/polyxmass-mz-ratio.glade", userspec->gladedir);
@@ -68,7 +70,7 @@ polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
   
   if (xml == NULL)
     {
-      g_error (_("%s@%d: failed loading the interface\n"),
+      g_error (_("%s@%d: failed to load the interface\n"),
 	     __FILE__, __LINE__);
 
       g_free (gui_file);
@@ -80,8 +82,8 @@ polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
   
   if (window == NULL)
     {
-      g_critical (_("%s@%d: failed creating the m-to-z ratio calculator "
-	       "config window\n"),
+      g_critical (_("%s@%d: failed to create the m/z ratio calculations "
+	       "configuration window\n"),
 	     __FILE__, __LINE__);
       
       g_object_unref (G_OBJECT (xml));
@@ -98,8 +100,19 @@ polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
    */
   g_object_set_data (G_OBJECT (window), "atomGPA", atomGPA);
 
+  /* Depending on the module that has called this function
+     ("POLYXEDIT" or POLYXCALC"), we have to calculate a title string.
+   */
+  if (0 == strcmp ("POLYXEDIT", module))
+    help = g_strdup ("polyxedit: m/z Calculations");
+  else if (0 == strcmp ("POLYXCALC", module))
+    help = g_strdup ("polyxcalc: m/z Calculations");
+  else
+    g_assert_not_reached ();
+  
+
   /* Allocate the array where the different masspair objects,
-     corresponding to the various m/z ratios computed for different
+     corresponding to the various m/z ratios calculated for different
      charge levels are going to be stored.
   */
   masspairGPA = g_ptr_array_new ();
@@ -208,15 +221,15 @@ polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
   gtk_entry_set_text (GTK_ENTRY (widget), help);
   g_free (help);
 
-  widget = glade_xml_get_widget (xml, "compute_net_charge_button");
+  widget = glade_xml_get_widget (xml, "calculate_net_charge_button");
   g_assert (widget != NULL);
   g_object_set_data (G_OBJECT (window),
-		     "compute_net_charge_button", widget);
+		     "calculate_net_charge_button", widget);
 
   g_signal_connect (G_OBJECT (widget),
 		    "clicked",
 		    G_CALLBACK 
-		    (polyxmass_mz_ratio_wnd_compute_mz_ratio_button), 
+		    (polyxmass_mz_ratio_wnd_calculate_mz_ratio_button), 
 		    window);
 
 
@@ -282,7 +295,7 @@ polyxmass_mz_ratio_wnd_setup (GPtrArray *atomGPA,
    processed.
  */
 gint
-polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
+polyxmass_mz_ratio_wnd_calculate_mz_ratio_button (GtkWidget *button,
 						gpointer data)
 {
   GtkWidget *window = data;
@@ -325,7 +338,7 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
      values to the true molecular mass of the analyte.
 
      When we have the molecular mass of the analyte, then we can start
-     computing the new asked m/z values for the z in the
+     calculating the new asked m/z values for the z in the
      [start_mz-end_mz] range.
    */  
   result = polyxmass_mz_ratio_wnd_update_initial_ionizerule (window);
@@ -333,8 +346,8 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
   if (FALSE == result)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Failed getting the initial "
-					"ionization data",
+					_("Failed to get the initial "
+					"ionization data"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return -1;
     }
@@ -345,8 +358,8 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
   if (FALSE == result)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Failed getting the requested"
-					"ionization data",
+					_("Failed to get the requested "
+					"ionization data"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return -1;
     }
@@ -357,8 +370,8 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
   if (FALSE == result)
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Failed getting the initial "
-					"mono/avg m/z values",
+					_("Failed to get the initial "
+					"mono/avg m/z values"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return -1;
     }
@@ -385,10 +398,10 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
   g_assert (dest_ionizerule != NULL);
 
 
-  /* Now we should compute the molecular mass of the analyte, based on
+  /* Now we should calculate the molecular mass of the analyte, based on
      the provided m/z values and on the provided initial_ionizerule
      data. Once we have the molecular mass of the analyte, we can
-     start computing new m/z ratios according to the ionization level
+     start calculating new m/z ratios according to the ionization level
      range asked by the user.
   */
   if (FALSE == pxmchem_masscalc_decount_ionizerule (initial_ionizerule,
@@ -396,7 +409,7 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
 						    atomGPA))
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Failed de-ionizing the analyte",
+					_("Failed to de-ionize the analyte"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return -1;
     }
@@ -428,7 +441,7 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
   /* At this point we should perform the actual calculations requested
      by the user. Note that we will always keep 'initial_masspair'
      untouched, as we'll use its data to initialize the 'masspair'
-     object in which the computations are performed.
+     object in which the calculatations are performed.
   */
   
   for (iter = start_mz; iter <= end_mz; iter++)
@@ -453,7 +466,7 @@ polyxmass_mz_ratio_wnd_compute_mz_ratio_button (GtkWidget *button,
 							atomGPA))
 	{
 	  polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					    "Failed ionizing the analyte",
+					    _("Failed to ionize the analyte"),
 					    POLYXMASS_MEDI_MSG_TIMEOUT);
 
 	  libpolyxmass_masspair_free (masspair);
@@ -517,8 +530,8 @@ polyxmass_mz_ratio_wnd_update_initial_ionizerule (GtkWidget *window)
   if (FALSE == pxmchem_actform_check (help, atomGPA))
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Failed checking the initial"
-					"ionization actform",
+					_("Failed to check the initial "
+					"ionization actform"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return FALSE;
     }
@@ -587,8 +600,8 @@ polyxmass_mz_ratio_wnd_update_dest_ionizerule (GtkWidget *window)
   if (FALSE == pxmchem_actform_check (help, atomGPA))
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Failed checking the asked"
-					"ionization actform",
+					_("Failed to check the asked "
+					"ionization actform"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return FALSE;
     }
@@ -608,7 +621,7 @@ polyxmass_mz_ratio_wnd_update_dest_ionizerule (GtkWidget *window)
   /* Here the situation is a bit tricky as to what pertains to the
      ionization level, as the user asks for a range of levels, from a
      starting ionization level to an ending ionization level. m/z
-     ratios will have to be computed for all the levels in the range,
+     ratios will have to be calculated for all the levels in the range,
      borders comprised.
 
      So we do not do that work here, we keep it for another place.
@@ -619,7 +632,7 @@ polyxmass_mz_ratio_wnd_update_dest_ionizerule (GtkWidget *window)
   
   /* GREAT, we have finished qualifying the ionizerule object which
      describes most precisely how the new m/z values are to be
-     computed with the ionization levels displayed at the bottom of
+     calculated with the ionization levels displayed at the bottom of
      the window. We can return TRUE proudly.
   */
   return TRUE;
@@ -654,7 +667,7 @@ polyxmass_mz_ratio_wnd_update_initial_masspair (GtkWidget *window)
   if (FALSE == libpolyxmass_globals_strtod (help, &initial_masspair->mono))
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Bad initial mono m/z value",
+					_("Initial mono m/z value is incorrect"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return FALSE;
     }
@@ -670,7 +683,7 @@ polyxmass_mz_ratio_wnd_update_initial_masspair (GtkWidget *window)
   if (FALSE == libpolyxmass_globals_strtod (help, &initial_masspair->avg))
     {
       polyxmass_timeoutmsg_message_set ((GtkWindow *) window,
-					"Bad initial avg m/z value",
+					_("Initial avg m/z value is incorrect"),
 					POLYXMASS_MEDI_MSG_TIMEOUT);
       return FALSE;
     }
@@ -822,7 +835,7 @@ polyxmass_mz_ratio_wnd_setup_mz_ratios_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Unit. Charge",
+    gtk_tree_view_column_new_with_attributes (_("Unit. Charge"),
 					      
 					      renderer, 
 					      
@@ -842,7 +855,7 @@ polyxmass_mz_ratio_wnd_setup_mz_ratios_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Ioniz. Level",
+    gtk_tree_view_column_new_with_attributes (_("Ioniz. Level"),
 					      
 					      renderer, 
 					      
@@ -863,7 +876,7 @@ polyxmass_mz_ratio_wnd_setup_mz_ratios_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Mono Mass",
+    gtk_tree_view_column_new_with_attributes (_("Mono Mass"),
 					      
 					      renderer, 
 					      
@@ -883,7 +896,7 @@ polyxmass_mz_ratio_wnd_setup_mz_ratios_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
 
   column = 
-    gtk_tree_view_column_new_with_attributes ("Avg Mass",
+    gtk_tree_view_column_new_with_attributes (_("Avg Mass"),
 					      
 					      renderer, 
 					      
@@ -904,7 +917,7 @@ polyxmass_mz_ratio_wnd_setup_mz_ratios_treeview (GtkWidget *window,
   renderer = gtk_cell_renderer_text_new ();
   
   column = 
-    gtk_tree_view_column_new_with_attributes ("Masspair Pointer",
+    gtk_tree_view_column_new_with_attributes (_("Masspair Pointer"),
 					      
 					      renderer,
 					      
@@ -1016,6 +1029,194 @@ polyxmass_mz_ratio_wnd_update_mz_ratios_treeview (GtkWidget *window)
 }
 
 
+/* REPORTING FUNCTIONS.
+ */
+gchar *
+polyxmass_mz_ratio_wnd_make_report (PxmReportOpt* reportopt,
+					  PxmWinMngmt* winmngmt)
+{
+  
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  g_assert (winmngmt->editctxt != NULL);
+  g_assert (winmngmt->wnd != NULL);
+
+  /* Great, we are able to start doing the report. We need to know what
+     kind of report we want : text or LaTeX.
+  */
+  if (reportopt->export_format == EXPORT_FORMAT_TEXT)
+    return polyxmass_mz_ratio_wnd_make_report_text_format (reportopt,
+							    winmngmt);
+  else if (reportopt->export_format == EXPORT_FORMAT_LATEX)
+    return polyxmass_mz_ratio_wnd_make_report_latex_format (reportopt,
+							     winmngmt);
+  else
+    g_assert_not_reached ();
+  
+  return NULL;
+}
+
+
+
+gchar *
+polyxmass_mz_ratio_wnd_make_report_text_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+  GtkWidget *window = NULL;
+
+  gchar *report = NULL;
+  
+  GString *report_gs = NULL;
+
+  PxmIonizerule *initial_ionizerule = NULL;
+  PxmIonizerule *dest_ionizerule = NULL;
+
+  PxmMasspair *initial_masspair = NULL;
+  PxmMasspair *iter_masspair = NULL;
+
+  gint charge = 0;
+  gint level = 0;
+    
+  GtkTreeView *treeview = NULL;
+  GtkTreeStore *model;
+  GtkTreeIter treeiter;
+
+
+  g_assert (winmngmt != NULL);
+  g_assert (reportopt != NULL);
+  
+  /* This assertion, while valid when dealing with windows opened in a 
+     POLYXEDIT context, is no more valid when the window is opened in a 
+     POLYXCALC context.
+  
+     g_assert (winmngmt->editctxt != NULL);
+  */
+  window = winmngmt->wnd ;
+  g_assert (window != NULL);
+  
+  
+  report_gs = g_string_new ("");
+
+
+  initial_ionizerule = g_object_get_data (G_OBJECT (window), 
+					  "initial_ionizerule");
+  g_assert (initial_ionizerule != NULL);
+
+  g_string_append_printf (report_gs, 
+			  _("Initial Ionizerule: %s, Charge: %d Level: %d\n\n"),
+			  initial_ionizerule->actform,
+			  initial_ionizerule->charge,
+			  initial_ionizerule->level);
+  
+
+  initial_masspair = g_object_get_data (G_OBJECT (window), 
+					"initial_masspair");
+  g_assert (initial_masspair != NULL);
+
+  g_string_append_printf (report_gs, 
+			  _("Initial Masses: Mono = %.5lf Avg = %.5lf\n\n"),
+			  initial_masspair->mono, initial_masspair->avg);
+  
+
+  dest_ionizerule = g_object_get_data (G_OBJECT (window), 
+				       "dest_ionizerule");
+  g_assert (dest_ionizerule != NULL);
+
+  g_string_append_printf (report_gs, 
+			  _("Destination Ionizerule: %s, Charge: %d Level: %d\n\n"),
+			  dest_ionizerule->actform,
+			  dest_ionizerule->charge,
+			  dest_ionizerule->level);
+  
+
+  /* Finally do the report work, with the items in the treeview sorted in the
+     way the user wanted them to be sorted...
+  */
+
+  /* Get the treeview that was setup the very first time the window was
+     opended. After, get the model and with the associated model.
+  */
+  treeview = (GtkTreeView *) g_object_get_data (G_OBJECT (window), 
+						"treeview");
+  
+  model = (GtkTreeStore *) gtk_tree_view_get_model (treeview);
+  
+  if (FALSE == gtk_tree_model_get_iter_first ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      g_warning (_("%s@%d: treeview is empty, nothing to report\n"),
+		 __FILE__, __LINE__);
+
+      report_gs = 
+	g_string_append (report_gs, _("Treeview is empty, nothing to report\n"));
+      
+      report = report_gs->str;
+      g_string_free (report_gs, FALSE);
+      
+      return report;
+    }
+  else
+    {
+      /* We have the first item of the list here. Use it !
+       */
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_CHARGE, &charge,
+			  
+			  COLUMN_LEVEL, &level,
+			  
+			  COLUMN_MASSPAIR_POINTER, &iter_masspair,
+			  -1);
+      
+      g_string_append_printf (report_gs, 
+			      "%-15s %-15s %-15s %-15s\n\n",
+			      _("charge"), _("level"), _("mono"), _("avg"));
+      
+      g_string_append_printf (report_gs, 
+			      "%-15d %-15d %-15.5lf %-15.5lf\n",
+			      charge, level, 
+			      iter_masspair->mono, iter_masspair->avg);
+    }
+  
+  /* And now continue to the remaining one in the while loop.
+   */
+  while (TRUE == gtk_tree_model_iter_next ((GtkTreeModel *) model,
+					      &treeiter))
+    {
+      gtk_tree_model_get ((GtkTreeModel *) model, &treeiter,
+
+			  COLUMN_CHARGE, &charge,
+			  
+			  COLUMN_LEVEL, &level,
+			  
+			  COLUMN_MASSPAIR_POINTER, &iter_masspair,
+			  -1);
+      
+      g_string_append_printf (report_gs, 
+			      "%-15d %-15d %-15.5lf %-15.5lf\n",
+			      charge, level, 
+			      iter_masspair->mono, iter_masspair->avg);
+    }
+  
+  report = report_gs->str;
+  g_string_free (report_gs, FALSE);
+  
+  return report;
+}
+
+
+gchar *
+polyxmass_mz_ratio_wnd_make_report_latex_format (PxmReportOpt* reportopt,
+						  PxmWinMngmt* winmngmt)
+{
+
+  return NULL;
+  
+}
+
 
 
 
@@ -1036,8 +1237,6 @@ polyxmass_mz_ratio_wnd_update_mz_ratios_treeview (GtkWidget *window)
 void
 polyxmass_mz_ratio_wnd_really_close (GtkWidget *window)
 {
-  gint count = 0;
-
   PxmIonizerule *initial_ionizerule = NULL;
   PxmMasspair *initial_masspair = NULL;
   PxmIonizerule *dest_ionizerule = NULL;
@@ -1048,13 +1247,99 @@ polyxmass_mz_ratio_wnd_really_close (GtkWidget *window)
   g_assert (window != NULL);
   
 
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
   /* 
      Prior to closing the window, we want to make sure that no
      pending timed-out messages are there...
   */
-  count = polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
-   
-  /* And that both the masspair and ionizerule objects get freed !
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  
+  /* Both the masspair and ionizerule objects have to be freed !
+   */
+  initial_masspair = g_object_get_data (G_OBJECT (window), 
+					"initial_masspair");
+  g_assert (initial_masspair != NULL);
+  libpolyxmass_masspair_free (initial_masspair);
+  /*
+    debug_printf (("freed initial_masspair\n"));
+  */
+
+  initial_ionizerule = g_object_get_data (G_OBJECT (window), 
+					  "initial_ionizerule");
+  g_assert (initial_ionizerule != NULL);
+  pxmchem_ionizerule_free (initial_ionizerule);
+  /*
+    debug_printf (("freed initial_ionizerule\n"));
+  */
+
+  dest_ionizerule = g_object_get_data (G_OBJECT (window), "dest_ionizerule");
+  g_assert (dest_ionizerule != NULL);
+  pxmchem_ionizerule_free (dest_ionizerule);
+  /*
+    debug_printf (("freed dest_ionizerule\n"));
+  */
+
+  masspairGPA = g_object_get_data (G_OBJECT (window), "masspairGPA");
+  g_assert (masspairGPA != NULL);
+
+  libpolyxmass_masspair_GPA_free (masspairGPA);
+  /*
+    debug_printf (("freed masspairGPA\n"));
+  */
+
+  gtk_widget_destroy (window);
+}
+
+
+gint
+polyxmass_mz_ratio_wnd_delete_event  (GtkWidget *window, 
+				      GdkEventAny *event, 
+				      gpointer data)
+{
+  PxmIonizerule *initial_ionizerule = NULL;
+  PxmMasspair *initial_masspair = NULL;
+  PxmIonizerule *dest_ionizerule = NULL;
+  
+  GPtrArray *masspairGPA = NULL;
+
+  GtkWindow *parent_wnd = data;
+  
+  gchar *help = NULL;
+  
+  g_assert (window != NULL);
+  g_assert (parent_wnd != NULL);
+
+
+
+  
+
+  help = g_strdup_printf ("mz_ratio_wnd-%p", window);
+  
+
+  /* This function is called as a GDestroyNotify callback function when
+     the sequence editor window gets closed.
+  */
+  
+  /* As a first step we want to un_register this window.
+   */
+  polyxmass_winmngmt_un_register_window (window, "POLYXEDIT");
+  
+  /* 
+     Prior to closing the window, we want to make sure that no
+     pending timed-out messages are there...
+  */
+  polyxmass_timeoutmsg_messages_remove ((GtkWindow *) window);
+  
+  
+  /* Both the masspair and ionizerule objects have to be freed !
    */
   initial_masspair = g_object_get_data (G_OBJECT (window), 
 					"initial_masspair");
@@ -1088,35 +1373,19 @@ polyxmass_mz_ratio_wnd_really_close (GtkWidget *window)
   */
 
 
-  gtk_widget_destroy (window);
-}
-
-
-gint
-polyxmass_mz_ratio_wnd_delete_event  (GtkWidget *window, 
-				      GdkEventAny *event, 
-				      gpointer data)
-{
-  GtkWindow *parent_wnd = data;
-  
-  gchar *help = NULL;
-  
-  g_assert (window != NULL);
-  g_assert (parent_wnd != NULL);
-  
-
+  /* This window pointer was set as a full datum to the sequence editor
+     window, which means that we have to remove that pointer, without
+     triggering the callback function call.
+  */
   help = g_strdup_printf ("mz_ratio_wnd-%p", window);
   
-
-  /* We set the datum to NULL, then the GDestroyNotify callback that
-     was specified when the datum was set first (that is
-     xxx_wnd_really_close () function above) will be called,
-     thus destroying *this window, which is exactly what we want !
-  */
-  g_object_set_data (G_OBJECT (parent_wnd), help, NULL);
+  window = g_object_steal_data (G_OBJECT (parent_wnd), help);
+  
   g_free (help);
-    
-  return TRUE;
+  
+  /* Let Gtk+ do the rest of the work.
+   */
+  return FALSE;
 }
 
 
